(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    318688,       5113]
NotebookOptionsPosition[    312994,       5021]
NotebookOutlinePosition[    313348,       5037]
CellTagsIndexPosition[    313305,       5034]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[
 RowBox[{"AustenExtended", ":=", 
  "\"\<Sir Walter Elliot, of Kellynch Hall, in Somersetshire, was a man who, \
for his own amusement, never took up any book but the Baronetage; there he \
found occupation for an idle hour, and consolation in a distressed one; there \
his faculties were roused into admiration and respect, by contemplating the \
limited remnant of the earliest patents; there any unwelcome sensations, \
arising from domestic affairs changed naturally into pity and contempt as he \
turned over the almost endless creations of the last century; and there, if \
every other leaf were powerless, he could read his own history with an \
interest which never failed. This was the page at which the favourite volume \
always opened: \\\"ELLIOT OF KELLYNCH HALL. \\\"Walter Elliot, born March 1, \
1760, married, July 15, 1784, Elizabeth, daughter of James Stevenson, Esq. of \
South Park, in the county of Gloucester, by which lady (who died 1800) he has \
issue Elizabeth, born June 1, 1785; Anne, born August 9, 1787; a still-born \
son, November 5, 1789; Mary, born November 20, 1791.\\\" Precisely such had \
the paragraph originally stood from the printer's hands; but Sir Walter had \
improved it by adding, for the information of himself and his family, these \
words, after the date of Mary's birth-- \\\"Married, December 16, 1810, \
Charles, son and heir of Charles Musgrove, Esq. of Uppercross, in the county \
of Somerset,\\\" and by inserting most accurately the day of the month on \
which he had lost his wife. Then followed the history and rise of the ancient \
and respectable family, in the usual terms; how it had been first settled in \
Cheshire; how mentioned in Dugdale, serving the office of high sheriff, \
representing a borough in three successive parliaments, exertions of loyalty, \
and dignity of baronet, in the first year of Charles II, with all the Marys \
and Elizabeths they had married; forming altogether two handsome duodecimo \
pages, and concluding with the arms and motto:--\\\"Principal seat, Kellynch \
Hall, in the county of Somerset,\\\" and Sir Walter's handwriting again in \
this finale:-- \\\"Heir presumptive, William Walter Elliot, Esq., great \
grandson of the second Sir Walter.\\\" Vanity was the beginning and the end \
of Sir Walter Elliot's character; vanity of person and of situation. He had \
been remarkably handsome in his youth; and, at fifty-four, was still a very \
fine man. Few women could think more of their personal appearance than he \
did, nor could the valet of any new made lord be more delighted with the \
place he held in society. He considered the blessing of beauty as inferior \
only to the blessing of a baronetcy; and the Sir Walter Elliot, who united \
these gifts, was the constant object of his warmest respect and devotion. His \
good looks and his rank had one fair claim on his attachment; since to them \
he must have owed a wife of very superior character to any thing deserved by \
his own. Lady Elliot had been an excellent woman, sensible and amiable; whose \
judgement and conduct, if they might be pardoned the youthful infatuation \
which made her Lady Elliot, had never required indulgence afterwards.--She \
had humoured, or softened, or concealed his failings, and promoted his real \
respectability for seventeen years; and though not the very happiest being in \
the world herself, had found enough in her duties, her friends, and her \
children, to attach her to life, and make it no matter of indifference to her \
when she was called on to quit them.--Three girls, the two eldest sixteen and \
fourteen, was an awful legacy for a mother to bequeath, an awful charge \
rather, to confide to the authority and guidance of a conceited, silly \
father. She had, however, one very intimate friend, a sensible, deserving \
woman, who had been brought, by strong attachment to herself, to settle close \
by her, in the village of Kellynch; and on her kindness and advice, Lady \
Elliot mainly relied for the best help and maintenance of the good principles \
and instruction which she had been anxiously giving her daughters. This \
friend, and Sir Walter, did not marry, whatever might have been anticipated \
on that head by their acquaintance. Thirteen years had passed away since Lady \
Elliot's death, and they were still near neighbours and intimate friends, and \
one remained a widower, the other a widow. That Lady Russell, of steady age \
and character, and extremely well provided for, should have no thought of a \
second marriage, needs no apology to the public, which is rather apt to be \
unreasonably discontented when a woman does marry again, than when she does \
not; but Sir Walter's continuing in singleness requires explanation. Be it \
known then, that Sir Walter, like a good father, (having met with one or two \
private disappointments in very unreasonable applications), prided himself on \
remaining single for his dear daughters' sake. For one daughter, his eldest, \
he would really have given up any thing, which he had not been very much \
tempted to do. Elizabeth had succeeded, at sixteen, to all that was possible, \
of her mother's rights and consequence; and being very handsome, and very \
like himself, her influence had always been great, and they had gone on \
together most happily. His two other children were of very inferior value. \
Mary had acquired a little artificial importance, by becoming Mrs Charles \
Musgrove; but Anne, with an elegance of mind and sweetness of character, \
which must have placed her high with any people of real understanding, was \
nobody with either father or sister; her word had no weight, her convenience \
was always to give way--she was only Anne. To Lady Russell, indeed, she was a \
most dear and highly valued god-daughter, favourite, and friend. Lady Russell \
loved them all; but it was only in Anne that she could fancy the mother to \
revive again. A few years before, Anne Elliot had been a very pretty girl, \
but her bloom had vanished early; and as even in its height, her father had \
found little to admire in her, (so totally different were her delicate \
features and mild dark eyes from his own), there could be nothing in them, \
now that she was faded and thin, to excite his esteem. He had never indulged \
much hope, he had now none, of ever reading her name in any other page of his \
favourite work. All equality of alliance must rest with Elizabeth, for Mary \
had merely connected herself with an old country family of respectability and \
large fortune, and had therefore given all the honour and received none: \
Elizabeth would, one day or other, marry suitably. It sometimes happens that \
a woman is handsomer at twenty-nine than she was ten years before; and, \
generally speaking, if there has been neither ill health nor anxiety, it is a \
time of life at which scarcely any charm is lost. It was so with Elizabeth, \
still the same handsome Miss Elliot that she had begun to be thirteen years \
ago, and Sir Walter might be excused, therefore, in forgetting her age, or, \
at least, be deemed only half a fool, for thinking himself and Elizabeth as \
blooming as ever, amidst the wreck of the good looks of everybody else; for \
he could plainly see how old all the rest of his family and acquaintance were \
growing. Anne haggard, Mary coarse, every face in the neighbourhood worsting, \
and the rapid increase of the crow's foot about Lady Russell's temples had \
long been a distress to him. Elizabeth did not quite equal her father in \
personal contentment. Thirteen years had seen her mistress of Kellynch Hall, \
presiding and directing with a self-possession and decision which could never \
have given the idea of her being younger than she was. For thirteen years had \
she been doing the honours, and laying down the domestic law at home, and \
leading the way to the chaise and four, and walking immediately after Lady \
Russell out of all the drawing-rooms and dining-rooms in the country. \
Thirteen winters' revolving frosts had seen her opening every ball of credit \
which a scanty neighbourhood afforded, and thirteen springs shewn their \
blossoms, as she travelled up to London with her father, for a few weeks' \
annual enjoyment of the great world. She had the remembrance of all this, she \
had the consciousness of being nine-and-twenty to give her some regrets and \
some apprehensions; she was fully satisfied of being still quite as handsome \
as ever, but she felt her approach to the years of danger, and would have \
rejoiced to be certain of being properly solicited by baronet-blood within \
the next twelvemonth or two. Then might she again take up the book of books \
with as much enjoyment as in her early youth, but now she liked it not. \
Always to be presented with the date of her own birth and see no marriage \
follow but that of a youngest sister, made the book an evil; and more than \
once, when her father had left it open on the table near her, had she closed \
it, with averted eyes, and pushed it away. She had had a disappointment, \
moreover, which that book, and especially the history of her own family, must \
ever present the remembrance of. The heir presumptive, the very William \
Walter Elliot, Esq., whose rights had been so generously supported by her \
father, had disappointed her. She had, while a very young girl, as soon as \
she had known him to be, in the event of her having no brother, the future \
baronet, meant to marry him, and her father had always meant that she should. \
He had not been known to them as a boy; but soon after Lady Elliot's death, \
Sir Walter had sought the acquaintance, and though his overtures had not been \
met with any warmth, he had persevered in seeking it, making allowance for \
the modest drawing-back of youth; and, in one of their spring excursions to \
London, when Elizabeth was in her first bloom, Mr Elliot had been forced into \
the introduction. He was at that time a very young man, just engaged in the \
study of the law; and Elizabeth found him extremely agreeable, and every plan \
in his favour was confirmed. He was invited to Kellynch Hall; he was talked \
of and expected all the rest of the year; but he never came. The following \
spring he was seen again in town, found equally agreeable, again encouraged, \
invited, and expected, and again he did not come; and the next tidings were \
that he was married. Instead of pushing his fortune in the line marked out \
for the heir of the house of Elliot, he had purchased independence by uniting \
himself to a rich woman of inferior birth. Sir Walter had resented it. As the \
head of the house, he felt that he ought to have been consulted, especially \
after taking the young man so publicly by the hand; \\\"For they must have \
been seen together,\\\" he observed, \\\"once at Tattersall's, and twice in \
the lobby of the House of Commons.\\\" His disapprobation was expressed, but \
apparently very little regarded. Mr Elliot had attempted no apology, and \
shewn himself as unsolicitous of being longer noticed by the family, as Sir \
Walter considered him unworthy of it: all acquaintance between them had \
ceased. This very awkward history of Mr Elliot was still, after an interval \
of several years, felt with anger by Elizabeth, who had liked the man for \
himself, and still more for being her father's heir, and whose strong family \
pride could see only in him a proper match for Sir Walter Elliot's eldest \
daughter. There was not a baronet from A to Z whom her feelings could have so \
willingly acknowledged as an equal. Yet so miserably had he conducted \
himself, that though she was at this present time (the summer of 1814) \
wearing black ribbons for his wife, she could not admit him to be worth \
thinking of again. The disgrace of his first marriage might, perhaps, as \
there was no reason to suppose it perpetuated by offspring, have been got \
over, had he not done worse; but he had, as by the accustomary intervention \
of kind friends, they had been informed, spoken most disrespectfully of them \
all, most slightingly and contemptuously of the very blood he belonged to, \
and the honours which were hereafter to be his own. This could not be \
pardoned.\>\""}]], "Input",
 CellChangeTimes->{{3.7812494370789137`*^9, 3.7812495379679193`*^9}, {
  3.7812495836192493`*^9, 3.781249584528303*^9}},
 CellLabel->
  "In[191]:=",ExpressionUUID->"ca43ca79-3cbf-492d-a91a-2d6676f17e21"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AustenExtendedFrequencies", "=", 
  RowBox[{
   RowBox[{"SortBy", "[", 
    RowBox[{
     RowBox[{"Tally", "[", 
      RowBox[{"Characters", "[", "AustenExtended", "]"}], "]"}], ",", 
     RowBox[{
      RowBox[{"#", "[", 
       RowBox[{"[", "2", "]"}], "]"}], "&"}]}], "]"}], "//", 
   "Reverse"}]}]], "Input",
 CellChangeTimes->{{3.7771864491285*^9, 3.777186460352173*^9}, {
  3.777186508486236*^9, 3.777186550610654*^9}, {3.777186653381482*^9, 
  3.777186667367276*^9}, {3.779690731662415*^9, 3.779690785500227*^9}, {
  3.7812495737130537`*^9, 3.7812495772465477`*^9}},
 CellLabel->
  "In[192]:=",ExpressionUUID->"055b2af6-c91e-4396-bcc4-2606540ba4bf"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\<\" \"\>", ",", "2054"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"e\"\>", ",", "1222"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"a\"\>", ",", "768"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"t\"\>", ",", "749"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"n\"\>", ",", "692"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"o\"\>", ",", "659"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"h\"\>", ",", "626"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"i\"\>", ",", "611"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"r\"\>", ",", "583"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"s\"\>", ",", "511"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"d\"\>", ",", "435"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"l\"\>", ",", "414"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"f\"\>", ",", "243"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\",\"\>", ",", "213"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"u\"\>", ",", "208"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"c\"\>", ",", "207"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"y\"\>", ",", "205"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"m\"\>", ",", "205"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"g\"\>", ",", "190"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"w\"\>", ",", "187"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"b\"\>", ",", "161"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"p\"\>", ",", "129"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"v\"\>", ",", "104"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\".\"\>", ",", "58"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"k\"\>", ",", "42"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"E\"\>", ",", "36"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\";\"\>", ",", "36"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"S\"\>", ",", "24"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"-\"\>", ",", "23"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"q\"\>", ",", "20"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"W\"\>", ",", "19"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"T\"\>", ",", "18"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"L\"\>", ",", "18"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"x\"\>", ",", "17"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"H\"\>", ",", "17"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"1\"\>", ",", "16"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"'\"\>", ",", "16"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"M\"\>", ",", "15"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"A\"\>", ",", "13"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"\\\"\"\>", ",", "13"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"z\"\>", ",", "12"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"C\"\>", ",", "7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"8\"\>", ",", "7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"7\"\>", ",", "7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"K\"\>", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"j\"\>", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"I\"\>", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"R\"\>", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"F\"\>", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"0\"\>", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\":\"\>", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\")\"\>", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"(\"\>", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"P\"\>", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"N\"\>", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"J\"\>", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"9\"\>", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"5\"\>", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Y\"\>", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"O\"\>", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"D\"\>", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"B\"\>", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"6\"\>", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"4\"\>", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Z\"\>", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"V\"\>", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"U\"\>", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"G\"\>", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"2\"\>", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.779690776895575*^9, 3.779690785866495*^9}, 
   3.779691316958555*^9, 3.780157593053241*^9, 3.780215626527788*^9, 
   3.7802301866740417`*^9, {3.780230289317748*^9, 3.780230313438253*^9}, 
   3.78023034353164*^9, 3.780230701955037*^9, 3.780414297719297*^9, 
   3.780582015135666*^9, 3.780894787444477*^9, 3.7812453094892178`*^9, {
   3.781249577809647*^9, 3.781249590300411*^9}, 3.782308630149974*^9},
 CellLabel->
  "Out[192]=",ExpressionUUID->"d61eda2e-afe9-44b8-a639-31b931ddb359"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AustenProbabilities", "=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"n", "=", 
      RowBox[{"Length", "[", 
       RowBox[{"Characters", "[", "AustenExtended", "]"}], "]"}]}], "}"}], 
    ",", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"#", "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"#", "[", 
           RowBox[{"[", "2", "]"}], "]"}], "/", "n"}], "//", "N"}]}], "}"}], 
      "&"}], "/@", "AustenExtendedFrequencies"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7771865837270613`*^9, 3.7771866329318247`*^9}, {
   3.7771866708986397`*^9, 3.777186697369362*^9}, {3.777187639933984*^9, 
   3.777187650609503*^9}, 3.779690788488057*^9, {3.779691000287889*^9, 
   3.77969100067276*^9}, {3.781249594354452*^9, 3.781249599824288*^9}},
 CellLabel->
  "In[193]:=",ExpressionUUID->"8e8a74dc-09f6-4a3b-8b54-0faed7229f8b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\<\" \"\>", ",", "0.1727792732166891`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"e\"\>", ",", "0.10279273216689098`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"a\"\>", ",", "0.06460296096904442`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"t\"\>", ",", "0.06300471063257065`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"n\"\>", ",", "0.05820995962314939`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"o\"\>", ",", "0.05543405114401077`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"h\"\>", ",", "0.05265814266487214`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"i\"\>", ",", "0.05139636608344549`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"r\"\>", ",", "0.04904104979811575`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"s\"\>", ",", "0.04298452220726783`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"d\"\>", ",", "0.036591520861372816`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"l\"\>", ",", "0.034825033647375506`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"f\"\>", ",", "0.02044078061911171`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\",\"\>", ",", "0.01791722745625841`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"u\"\>", ",", "0.017496635262449527`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"c\"\>", ",", "0.017412516823687753`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"y\"\>", ",", "0.0172442799461642`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"m\"\>", ",", "0.0172442799461642`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"g\"\>", ",", "0.01598250336473755`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"w\"\>", ",", "0.01573014804845222`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"b\"\>", ",", "0.01354306864064603`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"p\"\>", ",", "0.010851278600269179`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"v\"\>", ",", "0.008748317631224764`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\".\"\>", ",", "0.004878869448183042`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"k\"\>", ",", "0.0035329744279946162`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"E\"\>", ",", "0.003028263795423957`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\";\"\>", ",", "0.003028263795423957`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"S\"\>", ",", "0.002018842530282638`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"-\"\>", ",", "0.0019347240915208613`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"q\"\>", ",", "0.0016823687752355316`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"W\"\>", ",", "0.001598250336473755`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"T\"\>", ",", "0.0015141318977119785`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"L\"\>", ",", "0.0015141318977119785`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"x\"\>", ",", "0.0014300134589502018`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"H\"\>", ",", "0.0014300134589502018`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"1\"\>", ",", "0.0013458950201884253`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"'\"\>", ",", "0.0013458950201884253`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"M\"\>", ",", "0.0012617765814266486`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"A\"\>", ",", "0.0010935397039030955`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"\\\"\"\>", ",", "0.0010935397039030955`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"z\"\>", ",", "0.001009421265141319`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"C\"\>", ",", "0.0005888290713324361`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"8\"\>", ",", "0.0005888290713324361`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"7\"\>", ",", "0.0005888290713324361`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"K\"\>", ",", "0.0005047106325706595`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"j\"\>", ",", "0.0005047106325706595`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"I\"\>", ",", "0.0005047106325706595`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"R\"\>", ",", "0.0004205921938088829`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"F\"\>", ",", "0.0004205921938088829`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"0\"\>", ",", "0.0004205921938088829`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\":\"\>", ",", "0.0004205921938088829`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\")\"\>", ",", "0.00033647375504710633`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"(\"\>", ",", "0.00033647375504710633`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"P\"\>", ",", "0.00025235531628532975`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"N\"\>", ",", "0.00025235531628532975`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"J\"\>", ",", "0.00025235531628532975`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"9\"\>", ",", "0.00025235531628532975`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"5\"\>", ",", "0.00025235531628532975`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Y\"\>", ",", "0.00016823687752355316`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"O\"\>", ",", "0.00016823687752355316`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"D\"\>", ",", "0.00016823687752355316`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"B\"\>", ",", "0.00016823687752355316`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"6\"\>", ",", "0.00016823687752355316`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"4\"\>", ",", "0.00016823687752355316`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Z\"\>", ",", "0.00008411843876177658`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"V\"\>", ",", "0.00008411843876177658`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"U\"\>", ",", "0.00008411843876177658`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"G\"\>", ",", "0.00008411843876177658`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"2\"\>", ",", "0.00008411843876177658`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.7796907928230963`*^9, 3.779691001216156*^9, 3.779691317061199*^9, 
   3.780157593135363*^9, 3.7802156266337223`*^9, 3.780230186802148*^9, {
   3.78023028943618*^9, 3.780230313556209*^9}, 3.780230343662272*^9, 
   3.780230702075786*^9, 3.780414297820396*^9, 3.780582015237646*^9, 
   3.7808947881299257`*^9, 3.781245309593363*^9, 3.78124960069098*^9, 
   3.782308630208197*^9},
 CellLabel->
  "Out[193]=",ExpressionUUID->"5bfc31ed-e6d4-48d1-9e98-24adb395135c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AustenExtendedCode", "=", 
  RowBox[{
   RowBox[{"HuffmanCode", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"#", "[", 
        RowBox[{"[", "2", "]"}], "]"}], "&"}], "/@", "AustenProbabilities"}], 
     ",", 
     RowBox[{
      RowBox[{
       RowBox[{"#", "[", 
        RowBox[{"[", "1", "]"}], "]"}], "&"}], "/@", 
      "AustenProbabilities"}]}], "]"}], "//", "Sort"}]}]], "Input",
 CellChangeTimes->{{3.777186701546236*^9, 3.777186705873397*^9}, {
  3.7771876331898947`*^9, 3.777187633973756*^9}, {3.779690803700303*^9, 
  3.7796908098748827`*^9}, {3.779690923552145*^9, 3.779691019041192*^9}, {
  3.781249608433177*^9, 3.781249609376523*^9}},
 CellLabel->
  "In[194]:=",ExpressionUUID->"cd7bfc99-319a-4f76-8c86-f656467f0087"],

Cell[BoxData[
 RowBox[{"HuffmanCode", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "0.1727792732166891`", ",", "0.10279273216689098`", ",", 
     "0.06460296096904442`", ",", "0.06300471063257065`", ",", 
     "0.05820995962314939`", ",", "0.05543405114401077`", ",", 
     "0.05265814266487214`", ",", "0.05139636608344549`", ",", 
     "0.04904104979811575`", ",", "0.04298452220726783`", ",", 
     "0.036591520861372816`", ",", "0.034825033647375506`", ",", 
     "0.02044078061911171`", ",", "0.01791722745625841`", ",", 
     "0.017496635262449527`", ",", "0.017412516823687753`", ",", 
     "0.0172442799461642`", ",", "0.0172442799461642`", ",", 
     "0.01598250336473755`", ",", "0.01573014804845222`", ",", 
     "0.01354306864064603`", ",", "0.010851278600269179`", ",", 
     "0.008748317631224764`", ",", "0.004878869448183042`", ",", 
     "0.0035329744279946162`", ",", "0.003028263795423957`", ",", 
     "0.003028263795423957`", ",", "0.002018842530282638`", ",", 
     "0.0019347240915208613`", ",", "0.0016823687752355316`", ",", 
     "0.001598250336473755`", ",", "0.0015141318977119785`", ",", 
     "0.0015141318977119785`", ",", "0.0014300134589502018`", ",", 
     "0.0014300134589502018`", ",", "0.0013458950201884253`", ",", 
     "0.0013458950201884253`", ",", "0.0012617765814266486`", ",", 
     "0.0010935397039030955`", ",", "0.0010935397039030955`", ",", 
     "0.001009421265141319`", ",", "0.0005888290713324361`", ",", 
     "0.0005888290713324361`", ",", "0.0005888290713324361`", ",", 
     "0.0005047106325706595`", ",", "0.0005047106325706595`", ",", 
     "0.0005047106325706595`", ",", "0.0004205921938088829`", ",", 
     "0.0004205921938088829`", ",", "0.0004205921938088829`", ",", 
     "0.0004205921938088829`", ",", "0.00033647375504710633`", ",", 
     "0.00033647375504710633`", ",", "0.00025235531628532975`", ",", 
     "0.00025235531628532975`", ",", "0.00025235531628532975`", ",", 
     "0.00025235531628532975`", ",", "0.00025235531628532975`", ",", 
     "0.00016823687752355316`", ",", "0.00016823687752355316`", ",", 
     "0.00016823687752355316`", ",", "0.00016823687752355316`", ",", 
     "0.00016823687752355316`", ",", "0.00016823687752355316`", ",", 
     "0.00008411843876177658`", ",", "0.00008411843876177658`", ",", 
     "0.00008411843876177658`", ",", "0.00008411843876177658`", ",", 
     "0.00008411843876177658`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\" \"\>", ",", "\<\"e\"\>", ",", "\<\"a\"\>", ",", "\<\"t\"\>",
      ",", "\<\"n\"\>", ",", "\<\"o\"\>", ",", "\<\"h\"\>", ",", "\<\"i\"\>", 
     ",", "\<\"r\"\>", ",", "\<\"s\"\>", ",", "\<\"d\"\>", ",", "\<\"l\"\>", 
     ",", "\<\"f\"\>", ",", "\<\",\"\>", ",", "\<\"u\"\>", ",", "\<\"c\"\>", 
     ",", "\<\"y\"\>", ",", "\<\"m\"\>", ",", "\<\"g\"\>", ",", "\<\"w\"\>", 
     ",", "\<\"b\"\>", ",", "\<\"p\"\>", ",", "\<\"v\"\>", ",", "\<\".\"\>", 
     ",", "\<\"k\"\>", ",", "\<\"E\"\>", ",", "\<\";\"\>", ",", "\<\"S\"\>", 
     ",", "\<\"-\"\>", ",", "\<\"q\"\>", ",", "\<\"W\"\>", ",", "\<\"T\"\>", 
     ",", "\<\"L\"\>", ",", "\<\"x\"\>", ",", "\<\"H\"\>", ",", "\<\"1\"\>", 
     ",", "\<\"'\"\>", ",", "\<\"M\"\>", ",", "\<\"A\"\>", 
     ",", "\<\"\\\"\"\>", ",", "\<\"z\"\>", ",", "\<\"C\"\>", 
     ",", "\<\"8\"\>", ",", "\<\"7\"\>", ",", "\<\"K\"\>", ",", "\<\"j\"\>", 
     ",", "\<\"I\"\>", ",", "\<\"R\"\>", ",", "\<\"F\"\>", ",", "\<\"0\"\>", 
     ",", "\<\":\"\>", ",", "\<\")\"\>", ",", "\<\"(\"\>", ",", "\<\"P\"\>", 
     ",", "\<\"N\"\>", ",", "\<\"J\"\>", ",", "\<\"9\"\>", ",", "\<\"5\"\>", 
     ",", "\<\"Y\"\>", ",", "\<\"O\"\>", ",", "\<\"D\"\>", ",", "\<\"B\"\>", 
     ",", "\<\"6\"\>", ",", "\<\"4\"\>", ",", "\<\"Z\"\>", ",", "\<\"V\"\>", 
     ",", "\<\"U\"\>", ",", "\<\"G\"\>", ",", "\<\"2\"\>"}], "}"}]}], 
  "]"}]], "Output",
 CellChangeTimes->{
  3.777186706234165*^9, {3.777187634433206*^9, 3.7771876537687263`*^9}, 
   3.77718791907071*^9, 3.7771881932300653`*^9, 3.778348917692519*^9, 
   3.778504468514462*^9, 3.77886559464443*^9, 3.779631171548894*^9, 
   3.779690586298937*^9, 3.779690810759231*^9, 3.779690924551676*^9, {
   3.7796909581454067`*^9, 3.7796909893564577`*^9}, 3.779691019566349*^9, 
   3.779691317162208*^9, 3.7801575932357893`*^9, 3.780215626733185*^9, 
   3.780230186929237*^9, {3.780230289554788*^9, 3.7802303136853724`*^9}, 
   3.78023034379707*^9, 3.78023070222125*^9, 3.78041429791474*^9, 
   3.780582015356579*^9, 3.7808947883237143`*^9, 3.781245309694653*^9, 
   3.781249612742002*^9, 3.7823086302782307`*^9},
 CellLabel->
  "Out[194]=",ExpressionUUID->"8c4d314e-e590-450c-9775-2bdaa431c900"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AustenExtendedHuffmanEncoded", "=", 
  RowBox[{"Join", "@@", 
   RowBox[{"AustenExtendedCode", "/@", 
    RowBox[{"Characters", "[", "AustenExtended", "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.7771880589631147`*^9, 3.777188115281012*^9}, {
  3.77969102811954*^9, 3.779691029335285*^9}, {3.7796914201229057`*^9, 
  3.7796914561279984`*^9}, {3.781249686264838*^9, 3.781249709556501*^9}},
 CellLabel->
  "In[195]:=",ExpressionUUID->"e810dc29-2d40-4d10-9301-f88c5a06e3fa"],

Cell[BoxData[
 RowBox[{
  RowBox[{"HuffmanCode", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "0.1727792732166891`", ",", "0.10279273216689098`", ",", 
      "0.06460296096904442`", ",", "0.06300471063257065`", ",", 
      "0.05820995962314939`", ",", "0.05543405114401077`", ",", 
      "0.05265814266487214`", ",", "0.05139636608344549`", ",", 
      "0.04904104979811575`", ",", "0.04298452220726783`", ",", 
      "0.036591520861372816`", ",", "0.034825033647375506`", ",", 
      "0.02044078061911171`", ",", "0.01791722745625841`", ",", 
      "0.017496635262449527`", ",", "0.017412516823687753`", ",", 
      "0.0172442799461642`", ",", "0.0172442799461642`", ",", 
      "0.01598250336473755`", ",", "0.01573014804845222`", ",", 
      "0.01354306864064603`", ",", "0.010851278600269179`", ",", 
      "0.008748317631224764`", ",", "0.004878869448183042`", ",", 
      "0.0035329744279946162`", ",", "0.003028263795423957`", ",", 
      "0.003028263795423957`", ",", "0.002018842530282638`", ",", 
      "0.0019347240915208613`", ",", "0.0016823687752355316`", ",", 
      "0.001598250336473755`", ",", "0.0015141318977119785`", ",", 
      "0.0015141318977119785`", ",", "0.0014300134589502018`", ",", 
      "0.0014300134589502018`", ",", "0.0013458950201884253`", ",", 
      "0.0013458950201884253`", ",", "0.0012617765814266486`", ",", 
      "0.0010935397039030955`", ",", "0.0010935397039030955`", ",", 
      "0.001009421265141319`", ",", "0.0005888290713324361`", ",", 
      "0.0005888290713324361`", ",", "0.0005888290713324361`", ",", 
      "0.0005047106325706595`", ",", "0.0005047106325706595`", ",", 
      "0.0005047106325706595`", ",", "0.0004205921938088829`", ",", 
      "0.0004205921938088829`", ",", "0.0004205921938088829`", ",", 
      "0.0004205921938088829`", ",", "0.00033647375504710633`", ",", 
      "0.00033647375504710633`", ",", "0.00025235531628532975`", ",", 
      "0.00025235531628532975`", ",", "0.00025235531628532975`", ",", 
      "0.00025235531628532975`", ",", "0.00025235531628532975`", ",", 
      "0.00016823687752355316`", ",", "0.00016823687752355316`", ",", 
      "0.00016823687752355316`", ",", "0.00016823687752355316`", ",", 
      "0.00016823687752355316`", ",", "0.00016823687752355316`", ",", 
      "0.00008411843876177658`", ",", "0.00008411843876177658`", ",", 
      "0.00008411843876177658`", ",", "0.00008411843876177658`", ",", 
      "0.00008411843876177658`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\<\" \"\>", ",", "\<\"e\"\>", ",", "\<\"a\"\>", 
      ",", "\<\"t\"\>", ",", "\<\"n\"\>", ",", "\<\"o\"\>", ",", "\<\"h\"\>", 
      ",", "\<\"i\"\>", ",", "\<\"r\"\>", ",", "\<\"s\"\>", ",", "\<\"d\"\>", 
      ",", "\<\"l\"\>", ",", "\<\"f\"\>", ",", "\<\",\"\>", ",", "\<\"u\"\>", 
      ",", "\<\"c\"\>", ",", "\<\"y\"\>", ",", "\<\"m\"\>", ",", "\<\"g\"\>", 
      ",", "\<\"w\"\>", ",", "\<\"b\"\>", ",", "\<\"p\"\>", ",", "\<\"v\"\>", 
      ",", "\<\".\"\>", ",", "\<\"k\"\>", ",", "\<\"E\"\>", ",", "\<\";\"\>", 
      ",", "\<\"S\"\>", ",", "\<\"-\"\>", ",", "\<\"q\"\>", ",", "\<\"W\"\>", 
      ",", "\<\"T\"\>", ",", "\<\"L\"\>", ",", "\<\"x\"\>", ",", "\<\"H\"\>", 
      ",", "\<\"1\"\>", ",", "\<\"'\"\>", ",", "\<\"M\"\>", ",", "\<\"A\"\>", 
      ",", "\<\"\\\"\"\>", ",", "\<\"z\"\>", ",", "\<\"C\"\>", 
      ",", "\<\"8\"\>", ",", "\<\"7\"\>", ",", "\<\"K\"\>", ",", "\<\"j\"\>", 
      ",", "\<\"I\"\>", ",", "\<\"R\"\>", ",", "\<\"F\"\>", ",", "\<\"0\"\>", 
      ",", "\<\":\"\>", ",", "\<\")\"\>", ",", "\<\"(\"\>", ",", "\<\"P\"\>", 
      ",", "\<\"N\"\>", ",", "\<\"J\"\>", ",", "\<\"9\"\>", ",", "\<\"5\"\>", 
      ",", "\<\"Y\"\>", ",", "\<\"O\"\>", ",", "\<\"D\"\>", ",", "\<\"B\"\>", 
      ",", "\<\"6\"\>", ",", "\<\"4\"\>", ",", "\<\"Z\"\>", ",", "\<\"V\"\>", 
      ",", "\<\"U\"\>", ",", "\<\"G\"\>", ",", "\<\"2\"\>"}], "}"}]}], "]"}], 
  "[", 
  RowBox[{"\<\"S\"\>", ",", "\<\"i\"\>", ",", "\<\"r\"\>", ",", "\<\" \"\>", 
   ",", "\<\"W\"\>", ",", "\<\"a\"\>", ",", "\<\"l\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"E\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"l\"\>", ",", "\<\"i\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"t\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", 
   ",", "\<\"f\"\>", ",", "\<\" \"\>", ",", "\<\"K\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"l\"\>", ",", "\<\"y\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"c\"\>", ",", "\<\"h\"\>", ",", "\<\" \"\>", ",", "\<\"H\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"l\"\>", ",", "\<\"l\"\>", ",", "\<\",\"\>", 
   ",", "\<\" \"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", 
   ",", "\<\"S\"\>", ",", "\<\"o\"\>", ",", "\<\"m\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"s\"\>", ",", "\<\"e\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"s\"\>", ",", "\<\"h\"\>", ",", "\<\"i\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"e\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"w\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", 
   ",", "\<\" \"\>", ",", "\<\"m\"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", 
   ",", "\<\" \"\>", ",", "\<\"w\"\>", ",", "\<\"h\"\>", ",", "\<\"o\"\>", 
   ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"f\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"w\"\>", 
   ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"m\"\>", 
   ",", "\<\"u\"\>", ",", "\<\"s\"\>", ",", "\<\"e\"\>", ",", "\<\"m\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"n\"\>", ",", "\<\"t\"\>", ",", "\<\",\"\>", 
   ",", "\<\" \"\>", ",", "\<\"n\"\>", ",", "\<\"e\"\>", ",", "\<\"v\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"o\"\>", ",", "\<\"k\"\>", ",", "\<\" \"\>", 
   ",", "\<\"u\"\>", ",", "\<\"p\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"b\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"o\"\>", ",", "\<\"k\"\>", ",", "\<\" \"\>", 
   ",", "\<\"b\"\>", ",", "\<\"u\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", 
   ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"B\"\>", ",", "\<\"a\"\>", ",", "\<\"r\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"e\"\>", ",", "\<\"t\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"g\"\>", ",", "\<\"e\"\>", ",", "\<\";\"\>", ",", "\<\" \"\>", 
   ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"f\"\>", ",", "\<\"o\"\>", ",", "\<\"u\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", 
   ",", "\<\"c\"\>", ",", "\<\"c\"\>", ",", "\<\"u\"\>", ",", "\<\"p\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"t\"\>", ",", "\<\"i\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"f\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", 
   ",", "\<\" \"\>", ",", "\<\"i\"\>", ",", "\<\"d\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"u\"\>", ",", "\<\"r\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", 
   ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", 
   ",", "\<\"c\"\>", ",", "\<\"o\"\>", ",", "\<\"n\"\>", ",", "\<\"s\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"l\"\>", ",", "\<\"a\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"o\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", 
   ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", 
   ",", "\<\" \"\>", ",", "\<\"d\"\>", ",", "\<\"i\"\>", ",", "\<\"s\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"r\"\>", ",", "\<\"e\"\>", ",", "\<\"s\"\>", 
   ",", "\<\"s\"\>", ",", "\<\"e\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", 
   ",", "\<\"o\"\>", ",", "\<\"n\"\>", ",", "\<\"e\"\>", ",", "\<\";\"\>", 
   ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"f\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"c\"\>", ",", "\<\"u\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"i\"\>", ",", "\<\"e\"\>", ",", "\<\"s\"\>", 
   ",", "\<\" \"\>", ",", "\<\"w\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"r\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"u\"\>", ",", "\<\"s\"\>", ",", "\<\"e\"\>", ",", "\<\"d\"\>", 
   ",", "\<\" \"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"o\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"d\"\>", 
   ",", "\<\"m\"\>", ",", "\<\"i\"\>", ",", "\<\"r\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"i\"\>", ",", "\<\"o\"\>", ",", "\<\"n\"\>", 
   ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"d\"\>", 
   ",", "\<\" \"\>", ",", "\<\"r\"\>", ",", "\<\"e\"\>", ",", "\<\"s\"\>", 
   ",", "\<\"p\"\>", ",", "\<\"e\"\>", ",", "\<\"c\"\>", ",", "\<\"t\"\>", 
   ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"b\"\>", ",", "\<\"y\"\>", 
   ",", "\<\" \"\>", ",", "\<\"c\"\>", ",", "\<\"o\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"e\"\>", ",", "\<\"m\"\>", ",", "\<\"p\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"a\"\>", ",", "\<\"t\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"g\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", 
   ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"l\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"m\"\>", ",", "\<\"i\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"r\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"m\"\>", ",", "\<\"n\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", 
   ",", "\<\"f\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"e\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"l\"\>", ",", "\<\"i\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"s\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", ",", "\<\"p\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"t\"\>", ",", "\<\"e\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"s\"\>", ",", "\<\";\"\>", ",", "\<\" \"\>", 
   ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"u\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"w\"\>", ",", "\<\"e\"\>", ",", "\<\"l\"\>", ",", "\<\"c\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"m\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"s\"\>", ",", "\<\"e\"\>", ",", "\<\"n\"\>", ",", "\<\"s\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"t\"\>", ",", "\<\"i\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"s\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", 
   ",", "\<\"a\"\>", ",", "\<\"r\"\>", ",", "\<\"i\"\>", ",", "\<\"s\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\"g\"\>", ",", "\<\" \"\>", 
   ",", "\<\"f\"\>", ",", "\<\"r\"\>", ",", "\<\"o\"\>", ",", "\<\"m\"\>", 
   ",", "\<\" \"\>", ",", "\<\"d\"\>", ",", "\<\"o\"\>", ",", "\<\"m\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"s\"\>", ",", "\<\"t\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"c\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"f\"\>", 
   ",", "\<\"f\"\>", ",", "\<\"a\"\>", ",", "\<\"i\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"c\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"g\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"n\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"u\"\>", ",", "\<\"r\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"l\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", 
   ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\"t\"\>", ",", "\<\"o\"\>", 
   ",", "\<\" \"\>", ",", "\<\"p\"\>", ",", "\<\"i\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"c\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"t\"\>", ",", "\<\"e\"\>", ",", "\<\"m\"\>", 
   ",", "\<\"p\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", 
   ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"u\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"e\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", 
   ",", "\<\"o\"\>", ",", "\<\"v\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", 
   ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"l\"\>", ",", "\<\"m\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"s\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", 
   ",", "\<\"e\"\>", ",", "\<\"n\"\>", ",", "\<\"d\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"s\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", 
   ",", "\<\"c\"\>", ",", "\<\"r\"\>", ",", "\<\"e\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"i\"\>", ",", "\<\"o\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"f\"\>", 
   ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"l\"\>", ",", "\<\"a\"\>", ",", "\<\"s\"\>", 
   ",", "\<\"t\"\>", ",", "\<\" \"\>", ",", "\<\"c\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"t\"\>", ",", "\<\"u\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"y\"\>", ",", "\<\";\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", 
   ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\"e\"\>", 
   ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"i\"\>", ",", "\<\"f\"\>", 
   ",", "\<\" \"\>", ",", "\<\"e\"\>", ",", "\<\"v\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", 
   ",", "\<\" \"\>", ",", "\<\"l\"\>", ",", "\<\"e\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"f\"\>", ",", "\<\" \"\>", ",", "\<\"w\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"p\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"w\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"e\"\>", ",", "\<\"s\"\>", ",", "\<\"s\"\>", 
   ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"c\"\>", ",", "\<\"o\"\>", ",", "\<\"u\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"r\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"a\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", 
   ",", "\<\"h\"\>", ",", "\<\"i\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", 
   ",", "\<\"o\"\>", ",", "\<\"w\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", 
   ",", "\<\"h\"\>", ",", "\<\"i\"\>", ",", "\<\"s\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"r\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", 
   ",", "\<\"w\"\>", ",", "\<\"i\"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", 
   ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", 
   ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\"t\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"e\"\>", ",", "\<\"s\"\>", ",", "\<\"t\"\>", 
   ",", "\<\" \"\>", ",", "\<\"w\"\>", ",", "\<\"h\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"c\"\>", ",", "\<\"h\"\>", ",", "\<\" \"\>", ",", "\<\"n\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"v\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", 
   ",", "\<\" \"\>", ",", "\<\"f\"\>", ",", "\<\"a\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"e\"\>", ",", "\<\"d\"\>", ",", "\<\".\"\>", 
   ",", "\<\" \"\>", ",", "\<\"T\"\>", ",", "\<\"h\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"w\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"p\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"g\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", 
   ",", "\<\"t\"\>", ",", "\<\" \"\>", ",", "\<\"w\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"c\"\>", ",", "\<\"h\"\>", ",", "\<\" \"\>", 
   ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"f\"\>", ",", "\<\"a\"\>", ",", "\<\"v\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"u\"\>", ",", "\<\"r\"\>", ",", "\<\"i\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"v\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"u\"\>", ",", "\<\"m\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"l\"\>", ",", "\<\"w\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"y\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", 
   ",", "\<\"o\"\>", ",", "\<\"p\"\>", ",", "\<\"e\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"d\"\>", ",", "\<\":\"\>", ",", "\<\" \"\>", 
   ",", "\<\"\\\"\"\>", ",", "\<\"E\"\>", ",", "\<\"L\"\>", ",", "\<\"L\"\>", 
   ",", "\<\"I\"\>", ",", "\<\"O\"\>", ",", "\<\"T\"\>", ",", "\<\" \"\>", 
   ",", "\<\"O\"\>", ",", "\<\"F\"\>", ",", "\<\" \"\>", ",", "\<\"K\"\>", 
   ",", "\<\"E\"\>", ",", "\<\"L\"\>", ",", "\<\"L\"\>", ",", "\<\"Y\"\>", 
   ",", "\<\"N\"\>", ",", "\<\"C\"\>", ",", "\<\"H\"\>", ",", "\<\" \"\>", 
   ",", "\<\"H\"\>", ",", "\<\"A\"\>", ",", "\<\"L\"\>", ",", "\<\"L\"\>", 
   ",", "\<\".\"\>", ",", "\<\" \"\>", ",", "\<\"\\\"\"\>", ",", "\<\"W\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"l\"\>", ",", "\<\"t\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"E\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"i\"\>", ",", "\<\"o\"\>", ",", "\<\"t\"\>", 
   ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"b\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"M\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"r\"\>", ",", "\<\"c\"\>", ",", "\<\"h\"\>", 
   ",", "\<\" \"\>", ",", "\<\"1\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", 
   ",", "\<\"1\"\>", ",", "\<\"7\"\>", ",", "\<\"6\"\>", ",", "\<\"0\"\>", 
   ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"m\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"r\"\>", ",", "\<\"i\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"d\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"J\"\>", 
   ",", "\<\"u\"\>", ",", "\<\"l\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", 
   ",", "\<\"1\"\>", ",", "\<\"5\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", 
   ",", "\<\"1\"\>", ",", "\<\"7\"\>", ",", "\<\"8\"\>", ",", "\<\"4\"\>", 
   ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"E\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"z\"\>", ",", "\<\"a\"\>", ",", "\<\"b\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\",\"\>", 
   ",", "\<\" \"\>", ",", "\<\"d\"\>", ",", "\<\"a\"\>", ",", "\<\"u\"\>", 
   ",", "\<\"g\"\>", ",", "\<\"h\"\>", ",", "\<\"t\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"f\"\>", 
   ",", "\<\" \"\>", ",", "\<\"J\"\>", ",", "\<\"a\"\>", ",", "\<\"m\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"S\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"e\"\>", ",", "\<\"v\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"s\"\>", ",", "\<\"o\"\>", ",", "\<\"n\"\>", 
   ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"E\"\>", ",", "\<\"s\"\>", 
   ",", "\<\"q\"\>", ",", "\<\".\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", 
   ",", "\<\"f\"\>", ",", "\<\" \"\>", ",", "\<\"S\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"u\"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\" \"\>", 
   ",", "\<\"P\"\>", ",", "\<\"a\"\>", ",", "\<\"r\"\>", ",", "\<\"k\"\>", 
   ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", 
   ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"c\"\>", ",", "\<\"o\"\>", ",", "\<\"u\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"t\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", 
   ",", "\<\"o\"\>", ",", "\<\"f\"\>", ",", "\<\" \"\>", ",", "\<\"G\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"o\"\>", ",", "\<\"u\"\>", ",", "\<\"c\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"s\"\>", ",", "\<\"t\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"r\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"b\"\>", 
   ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"w\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"c\"\>", ",", "\<\"h\"\>", ",", "\<\" \"\>", 
   ",", "\<\"l\"\>", ",", "\<\"a\"\>", ",", "\<\"d\"\>", ",", "\<\"y\"\>", 
   ",", "\<\" \"\>", ",", "\<\"(\"\>", ",", "\<\"w\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"o\"\>", ",", "\<\" \"\>", ",", "\<\"d\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"1\"\>", 
   ",", "\<\"8\"\>", ",", "\<\"0\"\>", ",", "\<\"0\"\>", ",", "\<\")\"\>", 
   ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"h\"\>", ",", "\<\"a\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", 
   ",", "\<\"i\"\>", ",", "\<\"s\"\>", ",", "\<\"s\"\>", ",", "\<\"u\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"E\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"z\"\>", ",", "\<\"a\"\>", ",", "\<\"b\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\",\"\>", 
   ",", "\<\" \"\>", ",", "\<\"b\"\>", ",", "\<\"o\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"J\"\>", ",", "\<\"u\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"1\"\>", 
   ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"1\"\>", ",", "\<\"7\"\>", 
   ",", "\<\"8\"\>", ",", "\<\"5\"\>", ",", "\<\";\"\>", ",", "\<\" \"\>", 
   ",", "\<\"A\"\>", ",", "\<\"n\"\>", ",", "\<\"n\"\>", ",", "\<\"e\"\>", 
   ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"b\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"A\"\>", 
   ",", "\<\"u\"\>", ",", "\<\"g\"\>", ",", "\<\"u\"\>", ",", "\<\"s\"\>", 
   ",", "\<\"t\"\>", ",", "\<\" \"\>", ",", "\<\"9\"\>", ",", "\<\",\"\>", 
   ",", "\<\" \"\>", ",", "\<\"1\"\>", ",", "\<\"7\"\>", ",", "\<\"8\"\>", 
   ",", "\<\"7\"\>", ",", "\<\";\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", 
   ",", "\<\" \"\>", ",", "\<\"s\"\>", ",", "\<\"t\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"l\"\>", ",", "\<\"-\"\>", ",", "\<\"b\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"r\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", 
   ",", "\<\"s\"\>", ",", "\<\"o\"\>", ",", "\<\"n\"\>", ",", "\<\",\"\>", 
   ",", "\<\" \"\>", ",", "\<\"N\"\>", ",", "\<\"o\"\>", ",", "\<\"v\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"m\"\>", ",", "\<\"b\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"5\"\>", ",", "\<\",\"\>", 
   ",", "\<\" \"\>", ",", "\<\"1\"\>", ",", "\<\"7\"\>", ",", "\<\"8\"\>", 
   ",", "\<\"9\"\>", ",", "\<\";\"\>", ",", "\<\" \"\>", ",", "\<\"M\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"r\"\>", ",", "\<\"y\"\>", ",", "\<\",\"\>", 
   ",", "\<\" \"\>", ",", "\<\"b\"\>", ",", "\<\"o\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"N\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"v\"\>", ",", "\<\"e\"\>", ",", "\<\"m\"\>", ",", "\<\"b\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"2\"\>", 
   ",", "\<\"0\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"1\"\>", 
   ",", "\<\"7\"\>", ",", "\<\"9\"\>", ",", "\<\"1\"\>", ",", "\<\".\"\>", 
   ",", "\<\"\\\"\"\>", ",", "\<\" \"\>", ",", "\<\"P\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"c\"\>", ",", "\<\"i\"\>", ",", "\<\"s\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"l\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", 
   ",", "\<\"s\"\>", ",", "\<\"u\"\>", ",", "\<\"c\"\>", ",", "\<\"h\"\>", 
   ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"a\"\>", ",", "\<\"d\"\>", 
   ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"p\"\>", ",", "\<\"a\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"g\"\>", ",", "\<\"r\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"p\"\>", ",", "\<\"h\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"i\"\>", ",", "\<\"g\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"a\"\>", ",", "\<\"l\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"s\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"o\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", 
   ",", "\<\"f\"\>", ",", "\<\"r\"\>", ",", "\<\"o\"\>", ",", "\<\"m\"\>", 
   ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"p\"\>", ",", "\<\"r\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"t\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"'\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"d\"\>", ",", "\<\"s\"\>", 
   ",", "\<\";\"\>", ",", "\<\" \"\>", ",", "\<\"b\"\>", ",", "\<\"u\"\>", 
   ",", "\<\"t\"\>", ",", "\<\" \"\>", ",", "\<\"S\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"W\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"t\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", 
   ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"a\"\>", ",", "\<\"d\"\>", 
   ",", "\<\" \"\>", ",", "\<\"i\"\>", ",", "\<\"m\"\>", ",", "\<\"p\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"o\"\>", ",", "\<\"v\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"i\"\>", ",", "\<\"t\"\>", 
   ",", "\<\" \"\>", ",", "\<\"b\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", 
   ",", "\<\"a\"\>", ",", "\<\"d\"\>", ",", "\<\"d\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"g\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", 
   ",", "\<\"f\"\>", ",", "\<\"o\"\>", ",", "\<\"r\"\>", ",", "\<\" \"\>", 
   ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\"f\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"m\"\>", ",", "\<\"a\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"o\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", 
   ",", "\<\"o\"\>", ",", "\<\"f\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"m\"\>", ",", "\<\"s\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"f\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"f\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"m\"\>", ",", "\<\"i\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"y\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", 
   ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\"s\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"w\"\>", ",", "\<\"o\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"d\"\>", ",", "\<\"s\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", 
   ",", "\<\"a\"\>", ",", "\<\"f\"\>", ",", "\<\"t\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"d\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", 
   ",", "\<\"f\"\>", ",", "\<\" \"\>", ",", "\<\"M\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"y\"\>", ",", "\<\"'\"\>", ",", "\<\"s\"\>", 
   ",", "\<\" \"\>", ",", "\<\"b\"\>", ",", "\<\"i\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"-\"\>", ",", "\<\"-\"\>", 
   ",", "\<\" \"\>", ",", "\<\"\\\"\"\>", ",", "\<\"M\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"r\"\>", ",", "\<\"i\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"d\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"D\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"c\"\>", ",", "\<\"e\"\>", ",", "\<\"m\"\>", 
   ",", "\<\"b\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\" \"\>", 
   ",", "\<\"1\"\>", ",", "\<\"6\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", 
   ",", "\<\"1\"\>", ",", "\<\"8\"\>", ",", "\<\"1\"\>", ",", "\<\"0\"\>", 
   ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"C\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"r\"\>", ",", "\<\"l\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"s\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"s\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"i\"\>", ",", "\<\"r\"\>", ",", "\<\" \"\>", 
   ",", "\<\"o\"\>", ",", "\<\"f\"\>", ",", "\<\" \"\>", ",", "\<\"C\"\>", 
   ",", "\<\"h\"\>", ",", "\<\"a\"\>", ",", "\<\"r\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"M\"\>", 
   ",", "\<\"u\"\>", ",", "\<\"s\"\>", ",", "\<\"g\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"v\"\>", ",", "\<\"e\"\>", ",", "\<\",\"\>", 
   ",", "\<\" \"\>", ",", "\<\"E\"\>", ",", "\<\"s\"\>", ",", "\<\"q\"\>", 
   ",", "\<\".\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"f\"\>", 
   ",", "\<\" \"\>", ",", "\<\"U\"\>", ",", "\<\"p\"\>", ",", "\<\"p\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\"c\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"s\"\>", ",", "\<\"s\"\>", ",", "\<\",\"\>", 
   ",", "\<\" \"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", 
   ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"c\"\>", ",", "\<\"o\"\>", ",", "\<\"u\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", 
   ",", "\<\"f\"\>", ",", "\<\" \"\>", ",", "\<\"S\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"m\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\"s\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"t\"\>", ",", "\<\",\"\>", ",", "\<\"\\\"\"\>", 
   ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"d\"\>", 
   ",", "\<\" \"\>", ",", "\<\"b\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", 
   ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\"s\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"t\"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"g\"\>", ",", "\<\" \"\>", ",", "\<\"m\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"s\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", 
   ",", "\<\"c\"\>", ",", "\<\"c\"\>", ",", "\<\"u\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"t\"\>", ",", "\<\"e\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"d\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"f\"\>", 
   ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"m\"\>", ",", "\<\"o\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", 
   ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"w\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"c\"\>", ",", "\<\"h\"\>", ",", "\<\" \"\>", 
   ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"l\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"s\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", 
   ",", "\<\"h\"\>", ",", "\<\"i\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", 
   ",", "\<\"w\"\>", ",", "\<\"i\"\>", ",", "\<\"f\"\>", ",", "\<\"e\"\>", 
   ",", "\<\".\"\>", ",", "\<\" \"\>", ",", "\<\"T\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"f\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"l\"\>", ",", "\<\"l\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"w\"\>", ",", "\<\"e\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", 
   ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"h\"\>", ",", "\<\"i\"\>", ",", "\<\"s\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"r\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", 
   ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", 
   ",", "\<\"r\"\>", ",", "\<\"i\"\>", ",", "\<\"s\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"f\"\>", ",", "\<\" \"\>", 
   ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"c\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"n\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", 
   ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", 
   ",", "\<\"r\"\>", ",", "\<\"e\"\>", ",", "\<\"s\"\>", ",", "\<\"p\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"c\"\>", ",", "\<\"t\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"b\"\>", ",", "\<\"l\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"f\"\>", ",", "\<\"a\"\>", ",", "\<\"m\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"y\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", 
   ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", 
   ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"u\"\>", 
   ",", "\<\"s\"\>", ",", "\<\"u\"\>", ",", "\<\"a\"\>", ",", "\<\"l\"\>", 
   ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"m\"\>", ",", "\<\"s\"\>", ",", "\<\";\"\>", ",", "\<\" \"\>", 
   ",", "\<\"h\"\>", ",", "\<\"o\"\>", ",", "\<\"w\"\>", ",", "\<\" \"\>", 
   ",", "\<\"i\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"b\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"e\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", 
   ",", "\<\"f\"\>", ",", "\<\"i\"\>", ",", "\<\"r\"\>", ",", "\<\"s\"\>", 
   ",", "\<\"t\"\>", ",", "\<\" \"\>", ",", "\<\"s\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"t\"\>", ",", "\<\"l\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", 
   ",", "\<\" \"\>", ",", "\<\"C\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"s\"\>", ",", "\<\"h\"\>", ",", "\<\"i\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"e\"\>", ",", "\<\";\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"w\"\>", ",", "\<\" \"\>", ",", "\<\"m\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"n\"\>", ",", "\<\"t\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"n\"\>", ",", "\<\"e\"\>", ",", "\<\"d\"\>", 
   ",", "\<\" \"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", 
   ",", "\<\"D\"\>", ",", "\<\"u\"\>", ",", "\<\"g\"\>", ",", "\<\"d\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"l\"\>", ",", "\<\"e\"\>", ",", "\<\",\"\>", 
   ",", "\<\" \"\>", ",", "\<\"s\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"v\"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\"g\"\>", 
   ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"f\"\>", ",", "\<\"f\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"c\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"o\"\>", ",", "\<\"f\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"g\"\>", ",", "\<\"h\"\>", ",", "\<\" \"\>", 
   ",", "\<\"s\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"f\"\>", ",", "\<\"f\"\>", ",", "\<\",\"\>", 
   ",", "\<\" \"\>", ",", "\<\"r\"\>", ",", "\<\"e\"\>", ",", "\<\"p\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"e\"\>", ",", "\<\"s\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"t\"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"g\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\" \"\>", 
   ",", "\<\"b\"\>", ",", "\<\"o\"\>", ",", "\<\"r\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"u\"\>", ",", "\<\"g\"\>", ",", "\<\"h\"\>", ",", "\<\" \"\>", 
   ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", 
   ",", "\<\"h\"\>", ",", "\<\"r\"\>", ",", "\<\"e\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"s\"\>", ",", "\<\"u\"\>", ",", "\<\"c\"\>", 
   ",", "\<\"c\"\>", ",", "\<\"e\"\>", ",", "\<\"s\"\>", ",", "\<\"s\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"v\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"p\"\>", ",", "\<\"a\"\>", ",", "\<\"r\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"a\"\>", ",", "\<\"m\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"t\"\>", ",", "\<\"s\"\>", ",", "\<\",\"\>", 
   ",", "\<\" \"\>", ",", "\<\"e\"\>", ",", "\<\"x\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"t\"\>", ",", "\<\"i\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", 
   ",", "\<\"f\"\>", ",", "\<\" \"\>", ",", "\<\"l\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"y\"\>", ",", "\<\"a\"\>", ",", "\<\"l\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"y\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"d\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"g\"\>", ",", "\<\"n\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", 
   ",", "\<\"f\"\>", ",", "\<\" \"\>", ",", "\<\"b\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"o\"\>", ",", "\<\"n\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"t\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"i\"\>", 
   ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"f\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"s\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", 
   ",", "\<\"y\"\>", ",", "\<\"e\"\>", ",", "\<\"a\"\>", ",", "\<\"r\"\>", 
   ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"f\"\>", ",", "\<\" \"\>", 
   ",", "\<\"C\"\>", ",", "\<\"h\"\>", ",", "\<\"a\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"e\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", 
   ",", "\<\"I\"\>", ",", "\<\"I\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", 
   ",", "\<\"w\"\>", ",", "\<\"i\"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", 
   ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"l\"\>", ",", "\<\"l\"\>", 
   ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"M\"\>", ",", "\<\"a\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"y\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"E\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"i\"\>", ",", "\<\"z\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"b\"\>", ",", "\<\"e\"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"m\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"r\"\>", ",", "\<\"r\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"d\"\>", ",", "\<\";\"\>", ",", "\<\" \"\>", 
   ",", "\<\"f\"\>", ",", "\<\"o\"\>", ",", "\<\"r\"\>", ",", "\<\"m\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\"g\"\>", ",", "\<\" \"\>", 
   ",", "\<\"a\"\>", ",", "\<\"l\"\>", ",", "\<\"t\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"g\"\>", ",", "\<\"e\"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", 
   ",", "\<\"w\"\>", ",", "\<\"o\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"d\"\>", ",", "\<\"s\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"m\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"d\"\>", ",", "\<\"u\"\>", ",", "\<\"o\"\>", ",", "\<\"d\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"c\"\>", ",", "\<\"i\"\>", ",", "\<\"m\"\>", 
   ",", "\<\"o\"\>", ",", "\<\" \"\>", ",", "\<\"p\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"g\"\>", ",", "\<\"e\"\>", ",", "\<\"s\"\>", ",", "\<\",\"\>", 
   ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"d\"\>", 
   ",", "\<\" \"\>", ",", "\<\"c\"\>", ",", "\<\"o\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"c\"\>", ",", "\<\"l\"\>", ",", "\<\"u\"\>", ",", "\<\"d\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\"g\"\>", ",", "\<\" \"\>", 
   ",", "\<\"w\"\>", ",", "\<\"i\"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", 
   ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"r\"\>", ",", "\<\"m\"\>", 
   ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"m\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"t\"\>", ",", "\<\"o\"\>", ",", "\<\":\"\>", 
   ",", "\<\"-\"\>", ",", "\<\"-\"\>", ",", "\<\"\\\"\"\>", ",", "\<\"P\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\"c\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"p\"\>", ",", "\<\"a\"\>", ",", "\<\"l\"\>", 
   ",", "\<\" \"\>", ",", "\<\"s\"\>", ",", "\<\"e\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"t\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"K\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"l\"\>", ",", "\<\"l\"\>", ",", "\<\"y\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"c\"\>", ",", "\<\"h\"\>", ",", "\<\" \"\>", 
   ",", "\<\"H\"\>", ",", "\<\"a\"\>", ",", "\<\"l\"\>", ",", "\<\"l\"\>", 
   ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", 
   ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"c\"\>", ",", "\<\"o\"\>", ",", "\<\"u\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"t\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", 
   ",", "\<\"o\"\>", ",", "\<\"f\"\>", ",", "\<\" \"\>", ",", "\<\"S\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"m\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"s\"\>", ",", "\<\"e\"\>", ",", "\<\"t\"\>", ",", "\<\",\"\>", 
   ",", "\<\"\\\"\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"S\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"W\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"t\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"'\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"d\"\>", ",", "\<\"w\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"i\"\>", ",", "\<\"t\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"g\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", 
   ",", "\<\"g\"\>", ",", "\<\"a\"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", 
   ",", "\<\" \"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", 
   ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"i\"\>", ",", "\<\"s\"\>", 
   ",", "\<\" \"\>", ",", "\<\"f\"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"l\"\>", ",", "\<\"e\"\>", ",", "\<\":\"\>", 
   ",", "\<\"-\"\>", ",", "\<\"-\"\>", ",", "\<\" \"\>", ",", "\<\"\\\"\"\>", 
   ",", "\<\"H\"\>", ",", "\<\"e\"\>", ",", "\<\"i\"\>", ",", "\<\"r\"\>", 
   ",", "\<\" \"\>", ",", "\<\"p\"\>", ",", "\<\"r\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"s\"\>", ",", "\<\"u\"\>", ",", "\<\"m\"\>", ",", "\<\"p\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"i\"\>", ",", "\<\"v\"\>", ",", "\<\"e\"\>", 
   ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"W\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"l\"\>", ",", "\<\"i\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"m\"\>", ",", "\<\" \"\>", ",", "\<\"W\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"t\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", 
   ",", "\<\" \"\>", ",", "\<\"E\"\>", ",", "\<\"l\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"o\"\>", ",", "\<\"t\"\>", ",", "\<\",\"\>", 
   ",", "\<\" \"\>", ",", "\<\"E\"\>", ",", "\<\"s\"\>", ",", "\<\"q\"\>", 
   ",", "\<\".\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"g\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"e\"\>", ",", "\<\"a\"\>", ",", "\<\"t\"\>", 
   ",", "\<\" \"\>", ",", "\<\"g\"\>", ",", "\<\"r\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"d\"\>", ",", "\<\"s\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"f\"\>", 
   ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"s\"\>", ",", "\<\"e\"\>", ",", "\<\"c\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"n\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", 
   ",", "\<\"S\"\>", ",", "\<\"i\"\>", ",", "\<\"r\"\>", ",", "\<\" \"\>", 
   ",", "\<\"W\"\>", ",", "\<\"a\"\>", ",", "\<\"l\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\".\"\>", ",", "\<\"\\\"\"\>", 
   ",", "\<\" \"\>", ",", "\<\"V\"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"t\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", 
   ",", "\<\"w\"\>", ",", "\<\"a\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", 
   ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"b\"\>", ",", "\<\"e\"\>", ",", "\<\"g\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"n\"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"g\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"e\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"f\"\>", 
   ",", "\<\" \"\>", ",", "\<\"S\"\>", ",", "\<\"i\"\>", ",", "\<\"r\"\>", 
   ",", "\<\" \"\>", ",", "\<\"W\"\>", ",", "\<\"a\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\" \"\>", 
   ",", "\<\"E\"\>", ",", "\<\"l\"\>", ",", "\<\"l\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"t\"\>", ",", "\<\"'\"\>", ",", "\<\"s\"\>", 
   ",", "\<\" \"\>", ",", "\<\"c\"\>", ",", "\<\"h\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"a\"\>", ",", "\<\"c\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\";\"\>", ",", "\<\" \"\>", 
   ",", "\<\"v\"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", 
   ",", "\<\"f\"\>", ",", "\<\" \"\>", ",", "\<\"p\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"s\"\>", ",", "\<\"o\"\>", ",", "\<\"n\"\>", 
   ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"d\"\>", 
   ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"f\"\>", ",", "\<\" \"\>", 
   ",", "\<\"s\"\>", ",", "\<\"i\"\>", ",", "\<\"t\"\>", ",", "\<\"u\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"t\"\>", ",", "\<\"i\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"n\"\>", ",", "\<\".\"\>", ",", "\<\" \"\>", ",", "\<\"H\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"b\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"r\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"m\"\>", ",", "\<\"a\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"k\"\>", ",", "\<\"a\"\>", ",", "\<\"b\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"d\"\>", ",", "\<\"s\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"m\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"i\"\>", 
   ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"y\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"u\"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\";\"\>", 
   ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"d\"\>", 
   ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"t\"\>", 
   ",", "\<\" \"\>", ",", "\<\"f\"\>", ",", "\<\"i\"\>", ",", "\<\"f\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"y\"\>", ",", "\<\"-\"\>", ",", "\<\"f\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"u\"\>", ",", "\<\"r\"\>", ",", "\<\",\"\>", 
   ",", "\<\" \"\>", ",", "\<\"w\"\>", ",", "\<\"a\"\>", ",", "\<\"s\"\>", 
   ",", "\<\" \"\>", ",", "\<\"s\"\>", ",", "\<\"t\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"l\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", 
   ",", "\<\" \"\>", ",", "\<\"v\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"f\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"m\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\".\"\>", ",", "\<\" \"\>", 
   ",", "\<\"F\"\>", ",", "\<\"e\"\>", ",", "\<\"w\"\>", ",", "\<\" \"\>", 
   ",", "\<\"w\"\>", ",", "\<\"o\"\>", ",", "\<\"m\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"c\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"u\"\>", ",", "\<\"l\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", 
   ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"k\"\>", ",", "\<\" \"\>", ",", "\<\"m\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", 
   ",", "\<\"f\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"i\"\>", ",", "\<\"r\"\>", ",", "\<\" \"\>", 
   ",", "\<\"p\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\"s\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"n\"\>", ",", "\<\"a\"\>", ",", "\<\"l\"\>", 
   ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"p\"\>", ",", "\<\"p\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"a\"\>", ",", "\<\"r\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"c\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", 
   ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"d\"\>", ",", "\<\"i\"\>", ",", "\<\"d\"\>", ",", "\<\",\"\>", 
   ",", "\<\" \"\>", ",", "\<\"n\"\>", ",", "\<\"o\"\>", ",", "\<\"r\"\>", 
   ",", "\<\" \"\>", ",", "\<\"c\"\>", ",", "\<\"o\"\>", ",", "\<\"u\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", 
   ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"v\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"l\"\>", ",", "\<\"e\"\>", ",", "\<\"t\"\>", 
   ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"f\"\>", ",", "\<\" \"\>", 
   ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", 
   ",", "\<\"n\"\>", ",", "\<\"e\"\>", ",", "\<\"w\"\>", ",", "\<\" \"\>", 
   ",", "\<\"m\"\>", ",", "\<\"a\"\>", ",", "\<\"d\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"l\"\>", ",", "\<\"o\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"b\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"m\"\>", ",", "\<\"o\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"d\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"i\"\>", ",", "\<\"g\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"e\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", 
   ",", "\<\"w\"\>", ",", "\<\"i\"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", 
   ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"p\"\>", ",", "\<\"l\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"c\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"i\"\>", 
   ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"s\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"c\"\>", ",", "\<\"i\"\>", ",", "\<\"e\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"y\"\>", ",", "\<\".\"\>", ",", "\<\" \"\>", ",", "\<\"H\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"c\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"s\"\>", ",", "\<\"i\"\>", ",", "\<\"d\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\"e\"\>", ",", "\<\"d\"\>", 
   ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"b\"\>", ",", "\<\"l\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"s\"\>", ",", "\<\"s\"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"g\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"f\"\>", 
   ",", "\<\" \"\>", ",", "\<\"b\"\>", ",", "\<\"e\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"u\"\>", ",", "\<\"t\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", 
   ",", "\<\"a\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"i\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"f\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"o\"\>", ",", "\<\"r\"\>", ",", "\<\" \"\>", 
   ",", "\<\"o\"\>", ",", "\<\"n\"\>", ",", "\<\"l\"\>", ",", "\<\"y\"\>", 
   ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"o\"\>", ",", "\<\" \"\>", 
   ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"b\"\>", ",", "\<\"l\"\>", ",", "\<\"e\"\>", ",", "\<\"s\"\>", 
   ",", "\<\"s\"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\"g\"\>", 
   ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"f\"\>", ",", "\<\" \"\>", 
   ",", "\<\"a\"\>", ",", "\<\" \"\>", ",", "\<\"b\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"o\"\>", ",", "\<\"n\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"c\"\>", ",", "\<\"y\"\>", ",", "\<\";\"\>", 
   ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"d\"\>", 
   ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"S\"\>", ",", "\<\"i\"\>", ",", "\<\"r\"\>", 
   ",", "\<\" \"\>", ",", "\<\"W\"\>", ",", "\<\"a\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\" \"\>", 
   ",", "\<\"E\"\>", ",", "\<\"l\"\>", ",", "\<\"l\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"t\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", 
   ",", "\<\"w\"\>", ",", "\<\"h\"\>", ",", "\<\"o\"\>", ",", "\<\" \"\>", 
   ",", "\<\"u\"\>", ",", "\<\"n\"\>", ",", "\<\"i\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", 
   ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\"s\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"g\"\>", ",", "\<\"i\"\>", ",", "\<\"f\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"s\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", 
   ",", "\<\"w\"\>", ",", "\<\"a\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", 
   ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"c\"\>", ",", "\<\"o\"\>", ",", "\<\"n\"\>", ",", "\<\"s\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"t\"\>", 
   ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"b\"\>", ",", "\<\"j\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"c\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", 
   ",", "\<\"o\"\>", ",", "\<\"f\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"w\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"r\"\>", ",", "\<\"m\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"s\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", ",", "\<\"r\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"s\"\>", ",", "\<\"p\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"c\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"d\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"v\"\>", ",", "\<\"o\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"o\"\>", ",", "\<\"n\"\>", ",", "\<\".\"\>", 
   ",", "\<\" \"\>", ",", "\<\"H\"\>", ",", "\<\"i\"\>", ",", "\<\"s\"\>", 
   ",", "\<\" \"\>", ",", "\<\"g\"\>", ",", "\<\"o\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"l\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"k\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", 
   ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", 
   ",", "\<\"h\"\>", ",", "\<\"i\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", 
   ",", "\<\"r\"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"k\"\>", 
   ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"a\"\>", ",", "\<\"d\"\>", 
   ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"n\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"f\"\>", ",", "\<\"a\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"c\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"i\"\>", ",", "\<\"m\"\>", ",", "\<\" \"\>", 
   ",", "\<\"o\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"t\"\>", ",", "\<\"a\"\>", ",", "\<\"c\"\>", 
   ",", "\<\"h\"\>", ",", "\<\"m\"\>", ",", "\<\"e\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"t\"\>", ",", "\<\";\"\>", ",", "\<\" \"\>", ",", "\<\"s\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\"c\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"o\"\>", ",", "\<\" \"\>", 
   ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\"m\"\>", 
   ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"m\"\>", ",", "\<\"u\"\>", ",", "\<\"s\"\>", ",", "\<\"t\"\>", 
   ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"a\"\>", ",", "\<\"v\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"w\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", 
   ",", "\<\" \"\>", ",", "\<\"w\"\>", ",", "\<\"i\"\>", ",", "\<\"f\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"f\"\>", 
   ",", "\<\" \"\>", ",", "\<\"v\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"s\"\>", ",", "\<\"u\"\>", 
   ",", "\<\"p\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"c\"\>", 
   ",", "\<\"h\"\>", ",", "\<\"a\"\>", ",", "\<\"r\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"c\"\>", ",", "\<\"t\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", 
   ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"o\"\>", ",", "\<\" \"\>", 
   ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", 
   ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"g\"\>", ",", "\<\" \"\>", ",", "\<\"d\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"s\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\"v\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"b\"\>", 
   ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"w\"\>", 
   ",", "\<\"n\"\>", ",", "\<\".\"\>", ",", "\<\" \"\>", ",", "\<\"L\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"d\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", 
   ",", "\<\"E\"\>", ",", "\<\"l\"\>", ",", "\<\"l\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"b\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"e\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", 
   ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"e\"\>", 
   ",", "\<\"x\"\>", ",", "\<\"c\"\>", ",", "\<\"e\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"e\"\>", ",", "\<\"n\"\>", ",", "\<\"t\"\>", 
   ",", "\<\" \"\>", ",", "\<\"w\"\>", ",", "\<\"o\"\>", ",", "\<\"m\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", 
   ",", "\<\"s\"\>", ",", "\<\"e\"\>", ",", "\<\"n\"\>", ",", "\<\"s\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"b\"\>", ",", "\<\"l\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"d\"\>", 
   ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"m\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"b\"\>", ",", "\<\"l\"\>", ",", "\<\"e\"\>", 
   ",", "\<\";\"\>", ",", "\<\" \"\>", ",", "\<\"w\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"s\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"j\"\>", ",", "\<\"u\"\>", ",", "\<\"d\"\>", ",", "\<\"g\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"m\"\>", ",", "\<\"e\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"t\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"c\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"d\"\>", ",", "\<\"u\"\>", ",", "\<\"c\"\>", 
   ",", "\<\"t\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"i\"\>", 
   ",", "\<\"f\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"m\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"g\"\>", ",", "\<\"h\"\>", ",", "\<\"t\"\>", 
   ",", "\<\" \"\>", ",", "\<\"b\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"p\"\>", ",", "\<\"a\"\>", ",", "\<\"r\"\>", ",", "\<\"d\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"n\"\>", ",", "\<\"e\"\>", ",", "\<\"d\"\>", 
   ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"y\"\>", ",", "\<\"o\"\>", ",", "\<\"u\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"f\"\>", ",", "\<\"u\"\>", 
   ",", "\<\"l\"\>", ",", "\<\" \"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"f\"\>", ",", "\<\"a\"\>", ",", "\<\"t\"\>", ",", "\<\"u\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"t\"\>", ",", "\<\"i\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"w\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"c\"\>", ",", "\<\"h\"\>", ",", "\<\" \"\>", 
   ",", "\<\"m\"\>", ",", "\<\"a\"\>", ",", "\<\"d\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", 
   ",", "\<\" \"\>", ",", "\<\"L\"\>", ",", "\<\"a\"\>", ",", "\<\"d\"\>", 
   ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"E\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"i\"\>", ",", "\<\"o\"\>", ",", "\<\"t\"\>", 
   ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"n\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"v\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\" \"\>", 
   ",", "\<\"r\"\>", ",", "\<\"e\"\>", ",", "\<\"q\"\>", ",", "\<\"u\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"r\"\>", ",", "\<\"e\"\>", ",", "\<\"d\"\>", 
   ",", "\<\" \"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\"d\"\>", 
   ",", "\<\"u\"\>", ",", "\<\"l\"\>", ",", "\<\"g\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"c\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"a\"\>", ",", "\<\"f\"\>", ",", "\<\"t\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"w\"\>", ",", "\<\"a\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"d\"\>", ",", "\<\"s\"\>", ",", "\<\".\"\>", ",", "\<\"-\"\>", 
   ",", "\<\"-\"\>", ",", "\<\"S\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"a\"\>", ",", "\<\"d\"\>", 
   ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"u\"\>", ",", "\<\"m\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"u\"\>", ",", "\<\"r\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"d\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", 
   ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"s\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"f\"\>", ",", "\<\"t\"\>", ",", "\<\"e\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"d\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", 
   ",", "\<\"o\"\>", ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"c\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"n\"\>", ",", "\<\"c\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"l\"\>", ",", "\<\"e\"\>", ",", "\<\"d\"\>", 
   ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"i\"\>", ",", "\<\"s\"\>", 
   ",", "\<\" \"\>", ",", "\<\"f\"\>", ",", "\<\"a\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\"g\"\>", 
   ",", "\<\"s\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"p\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"o\"\>", ",", "\<\"m\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"e\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", 
   ",", "\<\"h\"\>", ",", "\<\"i\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", 
   ",", "\<\"r\"\>", ",", "\<\"e\"\>", ",", "\<\"a\"\>", ",", "\<\"l\"\>", 
   ",", "\<\" \"\>", ",", "\<\"r\"\>", ",", "\<\"e\"\>", ",", "\<\"s\"\>", 
   ",", "\<\"p\"\>", ",", "\<\"e\"\>", ",", "\<\"c\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"b\"\>", ",", "\<\"i\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"t\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", 
   ",", "\<\"f\"\>", ",", "\<\"o\"\>", ",", "\<\"r\"\>", ",", "\<\" \"\>", 
   ",", "\<\"s\"\>", ",", "\<\"e\"\>", ",", "\<\"v\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"t\"\>", ",", "\<\"e\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"y\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"r\"\>", ",", "\<\"s\"\>", ",", "\<\";\"\>", 
   ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"d\"\>", 
   ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"u\"\>", ",", "\<\"g\"\>", ",", "\<\"h\"\>", ",", "\<\" \"\>", 
   ",", "\<\"n\"\>", ",", "\<\"o\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", 
   ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"v\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\"y\"\>", 
   ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"a\"\>", ",", "\<\"p\"\>", 
   ",", "\<\"p\"\>", ",", "\<\"i\"\>", ",", "\<\"e\"\>", ",", "\<\"s\"\>", 
   ",", "\<\"t\"\>", ",", "\<\" \"\>", ",", "\<\"b\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\"g\"\>", ",", "\<\" \"\>", 
   ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", 
   ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"w\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"r\"\>", ",", "\<\"l\"\>", ",", "\<\"d\"\>", 
   ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"s\"\>", ",", "\<\"e\"\>", ",", "\<\"l\"\>", ",", "\<\"f\"\>", 
   ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"f\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"u\"\>", ",", "\<\"n\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", 
   ",", "\<\"e\"\>", ",", "\<\"n\"\>", ",", "\<\"o\"\>", ",", "\<\"u\"\>", 
   ",", "\<\"g\"\>", ",", "\<\"h\"\>", ",", "\<\" \"\>", ",", "\<\"i\"\>", 
   ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"d\"\>", ",", "\<\"u\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"i\"\>", ",", "\<\"e\"\>", ",", "\<\"s\"\>", 
   ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"f\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"e\"\>", ",", "\<\"n\"\>", ",", "\<\"d\"\>", 
   ",", "\<\"s\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"c\"\>", 
   ",", "\<\"h\"\>", ",", "\<\"i\"\>", ",", "\<\"l\"\>", ",", "\<\"d\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"e\"\>", ",", "\<\"n\"\>", ",", "\<\",\"\>", 
   ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"o\"\>", ",", "\<\" \"\>", 
   ",", "\<\"a\"\>", ",", "\<\"t\"\>", ",", "\<\"t\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"c\"\>", ",", "\<\"h\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", 
   ",", "\<\"o\"\>", ",", "\<\" \"\>", ",", "\<\"l\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"f\"\>", ",", "\<\"e\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", 
   ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", 
   ",", "\<\"m\"\>", ",", "\<\"a\"\>", ",", "\<\"k\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"i\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", 
   ",", "\<\"n\"\>", ",", "\<\"o\"\>", ",", "\<\" \"\>", ",", "\<\"m\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"t\"\>", ",", "\<\"t\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"f\"\>", 
   ",", "\<\" \"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\"d\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"f\"\>", ",", "\<\"f\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"e\"\>", ",", "\<\"n\"\>", ",", "\<\"c\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"o\"\>", 
   ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", 
   ",", "\<\" \"\>", ",", "\<\"w\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"s\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"w\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"c\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"l\"\>", ",", "\<\"e\"\>", ",", "\<\"d\"\>", 
   ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", 
   ",", "\<\"t\"\>", ",", "\<\"o\"\>", ",", "\<\" \"\>", ",", "\<\"q\"\>", 
   ",", "\<\"u\"\>", ",", "\<\"i\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", 
   ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\"m\"\>", 
   ",", "\<\".\"\>", ",", "\<\"-\"\>", ",", "\<\"-\"\>", ",", "\<\"T\"\>", 
   ",", "\<\"h\"\>", ",", "\<\"r\"\>", ",", "\<\"e\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"g\"\>", ",", "\<\"i\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"s\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", 
   ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"t\"\>", ",", "\<\"w\"\>", ",", "\<\"o\"\>", ",", "\<\" \"\>", 
   ",", "\<\"e\"\>", ",", "\<\"l\"\>", ",", "\<\"d\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"s\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", ",", "\<\"s\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"x\"\>", ",", "\<\"t\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"f\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"u\"\>", ",", "\<\"r\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"e\"\>", ",", "\<\"n\"\>", ",", "\<\",\"\>", 
   ",", "\<\" \"\>", ",", "\<\"w\"\>", ",", "\<\"a\"\>", ",", "\<\"s\"\>", 
   ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", 
   ",", "\<\"a\"\>", ",", "\<\"w\"\>", ",", "\<\"f\"\>", ",", "\<\"u\"\>", 
   ",", "\<\"l\"\>", ",", "\<\" \"\>", ",", "\<\"l\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"g\"\>", ",", "\<\"a\"\>", ",", "\<\"c\"\>", ",", "\<\"y\"\>", 
   ",", "\<\" \"\>", ",", "\<\"f\"\>", ",", "\<\"o\"\>", ",", "\<\"r\"\>", 
   ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\" \"\>", ",", "\<\"m\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"o\"\>", 
   ",", "\<\" \"\>", ",", "\<\"b\"\>", ",", "\<\"e\"\>", ",", "\<\"q\"\>", 
   ",", "\<\"u\"\>", ",", "\<\"e\"\>", ",", "\<\"a\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"h\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", 
   ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"w\"\>", 
   ",", "\<\"f\"\>", ",", "\<\"u\"\>", ",", "\<\"l\"\>", ",", "\<\" \"\>", 
   ",", "\<\"c\"\>", ",", "\<\"h\"\>", ",", "\<\"a\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"g\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"r\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"r\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", 
   ",", "\<\"o\"\>", ",", "\<\" \"\>", ",", "\<\"c\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"f\"\>", ",", "\<\"i\"\>", ",", "\<\"d\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"o\"\>", 
   ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"u\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"h\"\>", ",", "\<\"o\"\>", ",", "\<\"r\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"g\"\>", 
   ",", "\<\"u\"\>", ",", "\<\"i\"\>", ",", "\<\"d\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"c\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"o\"\>", ",", "\<\"f\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", 
   ",", "\<\" \"\>", ",", "\<\"c\"\>", ",", "\<\"o\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"c\"\>", ",", "\<\"e\"\>", ",", "\<\"i\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"d\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", 
   ",", "\<\"s\"\>", ",", "\<\"i\"\>", ",", "\<\"l\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"f\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", 
   ",", "\<\".\"\>", ",", "\<\" \"\>", ",", "\<\"S\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"d\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"w\"\>", ",", "\<\"e\"\>", ",", "\<\"v\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", 
   ",", "\<\"o\"\>", ",", "\<\"n\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"v\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\"y\"\>", 
   ",", "\<\" \"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"m\"\>", ",", "\<\"a\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"f\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"e\"\>", ",", "\<\"n\"\>", ",", "\<\"d\"\>", 
   ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\" \"\>", 
   ",", "\<\"s\"\>", ",", "\<\"e\"\>", ",", "\<\"n\"\>", ",", "\<\"s\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"b\"\>", ",", "\<\"l\"\>", ",", "\<\"e\"\>", 
   ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"d\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"s\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\"v\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\"g\"\>", ",", "\<\" \"\>", 
   ",", "\<\"w\"\>", ",", "\<\"o\"\>", ",", "\<\"m\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"n\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"w\"\>", 
   ",", "\<\"h\"\>", ",", "\<\"o\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"b\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"e\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", 
   ",", "\<\"b\"\>", ",", "\<\"r\"\>", ",", "\<\"o\"\>", ",", "\<\"u\"\>", 
   ",", "\<\"g\"\>", ",", "\<\"h\"\>", ",", "\<\"t\"\>", ",", "\<\",\"\>", 
   ",", "\<\" \"\>", ",", "\<\"b\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", 
   ",", "\<\"s\"\>", ",", "\<\"t\"\>", ",", "\<\"r\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"g\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"t\"\>", ",", "\<\"a\"\>", ",", "\<\"c\"\>", 
   ",", "\<\"h\"\>", ",", "\<\"m\"\>", ",", "\<\"e\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"t\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"o\"\>", 
   ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"s\"\>", ",", "\<\"e\"\>", ",", "\<\"l\"\>", ",", "\<\"f\"\>", 
   ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"o\"\>", 
   ",", "\<\" \"\>", ",", "\<\"s\"\>", ",", "\<\"e\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"l\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"c\"\>", ",", "\<\"l\"\>", ",", "\<\"o\"\>", ",", "\<\"s\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"b\"\>", ",", "\<\"y\"\>", 
   ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", 
   ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", 
   ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"v\"\>", ",", "\<\"i\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"a\"\>", ",", "\<\"g\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"f\"\>", ",", "\<\" \"\>", 
   ",", "\<\"K\"\>", ",", "\<\"e\"\>", ",", "\<\"l\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"y\"\>", ",", "\<\"n\"\>", ",", "\<\"c\"\>", ",", "\<\"h\"\>", 
   ",", "\<\";\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"n\"\>", 
   ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", 
   ",", "\<\" \"\>", ",", "\<\"k\"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"d\"\>", ",", "\<\"n\"\>", ",", "\<\"e\"\>", ",", "\<\"s\"\>", 
   ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"d\"\>", 
   ",", "\<\"v\"\>", ",", "\<\"i\"\>", ",", "\<\"c\"\>", ",", "\<\"e\"\>", 
   ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"L\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"d\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"E\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"l\"\>", ",", "\<\"i\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"t\"\>", ",", "\<\" \"\>", ",", "\<\"m\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\"l\"\>", ",", "\<\"y\"\>", 
   ",", "\<\" \"\>", ",", "\<\"r\"\>", ",", "\<\"e\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"e\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", 
   ",", "\<\"f\"\>", ",", "\<\"o\"\>", ",", "\<\"r\"\>", ",", "\<\" \"\>", 
   ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"b\"\>", ",", "\<\"e\"\>", ",", "\<\"s\"\>", ",", "\<\"t\"\>", 
   ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"p\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"m\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\"t\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"c\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"f\"\>", 
   ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"g\"\>", ",", "\<\"o\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"p\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\"c\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"p\"\>", ",", "\<\"l\"\>", ",", "\<\"e\"\>", ",", "\<\"s\"\>", 
   ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"d\"\>", 
   ",", "\<\" \"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\"s\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"r\"\>", ",", "\<\"u\"\>", ",", "\<\"c\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"i\"\>", ",", "\<\"o\"\>", ",", "\<\"n\"\>", 
   ",", "\<\" \"\>", ",", "\<\"w\"\>", ",", "\<\"h\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"c\"\>", ",", "\<\"h\"\>", ",", "\<\" \"\>", ",", "\<\"s\"\>", 
   ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"b\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"e\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", 
   ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"x\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"u\"\>", ",", "\<\"s\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"g\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"v\"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\"g\"\>", 
   ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", 
   ",", "\<\" \"\>", ",", "\<\"d\"\>", ",", "\<\"a\"\>", ",", "\<\"u\"\>", 
   ",", "\<\"g\"\>", ",", "\<\"h\"\>", ",", "\<\"t\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"s\"\>", ",", "\<\".\"\>", ",", "\<\" \"\>", 
   ",", "\<\"T\"\>", ",", "\<\"h\"\>", ",", "\<\"i\"\>", ",", "\<\"s\"\>", 
   ",", "\<\" \"\>", ",", "\<\"f\"\>", ",", "\<\"r\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"n\"\>", ",", "\<\"d\"\>", ",", "\<\",\"\>", 
   ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"d\"\>", 
   ",", "\<\" \"\>", ",", "\<\"S\"\>", ",", "\<\"i\"\>", ",", "\<\"r\"\>", 
   ",", "\<\" \"\>", ",", "\<\"W\"\>", ",", "\<\"a\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\",\"\>", 
   ",", "\<\" \"\>", ",", "\<\"d\"\>", ",", "\<\"i\"\>", ",", "\<\"d\"\>", 
   ",", "\<\" \"\>", ",", "\<\"n\"\>", ",", "\<\"o\"\>", ",", "\<\"t\"\>", 
   ",", "\<\" \"\>", ",", "\<\"m\"\>", ",", "\<\"a\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"y\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", 
   ",", "\<\"w\"\>", ",", "\<\"h\"\>", ",", "\<\"a\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"v\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", 
   ",", "\<\" \"\>", ",", "\<\"m\"\>", ",", "\<\"i\"\>", ",", "\<\"g\"\>", 
   ",", "\<\"h\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"v\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"b\"\>", ",", "\<\"e\"\>", ",", "\<\"e\"\>", ",", "\<\"n\"\>", 
   ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"c\"\>", ",", "\<\"i\"\>", ",", "\<\"p\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"t\"\>", ",", "\<\"e\"\>", ",", "\<\"d\"\>", 
   ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", 
   ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"a\"\>", ",", "\<\"t\"\>", 
   ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"b\"\>", ",", "\<\"y\"\>", 
   ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", 
   ",", "\<\"c\"\>", ",", "\<\"q\"\>", ",", "\<\"u\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\"t\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"c\"\>", ",", "\<\"e\"\>", ",", "\<\".\"\>", 
   ",", "\<\" \"\>", ",", "\<\"T\"\>", ",", "\<\"h\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"t\"\>", ",", "\<\"e\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"y\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"r\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", 
   ",", "\<\"h\"\>", ",", "\<\"a\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", 
   ",", "\<\"p\"\>", ",", "\<\"a\"\>", ",", "\<\"s\"\>", ",", "\<\"s\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", 
   ",", "\<\"w\"\>", ",", "\<\"a\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", 
   ",", "\<\"s\"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\"c\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"L\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"d\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"E\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"l\"\>", ",", "\<\"i\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"'\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", 
   ",", "\<\"d\"\>", ",", "\<\"e\"\>", ",", "\<\"a\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"h\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", 
   ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", 
   ",", "\<\"w\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"s\"\>", ",", "\<\"t\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"l\"\>", ",", "\<\" \"\>", ",", "\<\"n\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"a\"\>", ",", "\<\"r\"\>", ",", "\<\" \"\>", 
   ",", "\<\"n\"\>", ",", "\<\"e\"\>", ",", "\<\"i\"\>", ",", "\<\"g\"\>", 
   ",", "\<\"h\"\>", ",", "\<\"b\"\>", ",", "\<\"o\"\>", ",", "\<\"u\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"i\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"t\"\>", ",", "\<\"i\"\>", ",", "\<\"m\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"t\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"f\"\>", ",", "\<\"r\"\>", ",", "\<\"i\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"d\"\>", ",", "\<\"s\"\>", ",", "\<\",\"\>", 
   ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"d\"\>", 
   ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"n\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"r\"\>", ",", "\<\"e\"\>", ",", "\<\"m\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\" \"\>", 
   ",", "\<\"w\"\>", ",", "\<\"i\"\>", ",", "\<\"d\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"w\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\",\"\>", 
   ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", 
   ",", "\<\" \"\>", ",", "\<\"w\"\>", ",", "\<\"i\"\>", ",", "\<\"d\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"w\"\>", ",", "\<\".\"\>", ",", "\<\" \"\>", 
   ",", "\<\"T\"\>", ",", "\<\"h\"\>", ",", "\<\"a\"\>", ",", "\<\"t\"\>", 
   ",", "\<\" \"\>", ",", "\<\"L\"\>", ",", "\<\"a\"\>", ",", "\<\"d\"\>", 
   ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"R\"\>", ",", "\<\"u\"\>", 
   ",", "\<\"s\"\>", ",", "\<\"s\"\>", ",", "\<\"e\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"l\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", 
   ",", "\<\"f\"\>", ",", "\<\" \"\>", ",", "\<\"s\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"a\"\>", ",", "\<\"d\"\>", ",", "\<\"y\"\>", 
   ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"g\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"d\"\>", 
   ",", "\<\" \"\>", ",", "\<\"c\"\>", ",", "\<\"h\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"a\"\>", ",", "\<\"c\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", 
   ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", 
   ",", "\<\"e\"\>", ",", "\<\"x\"\>", ",", "\<\"t\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"m\"\>", ",", "\<\"e\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"w\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"l\"\>", ",", "\<\" \"\>", ",", "\<\"p\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"o\"\>", ",", "\<\"v\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"d\"\>", ",", "\<\"e\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", 
   ",", "\<\"f\"\>", ",", "\<\"o\"\>", ",", "\<\"r\"\>", ",", "\<\",\"\>", 
   ",", "\<\" \"\>", ",", "\<\"s\"\>", ",", "\<\"h\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"u\"\>", ",", "\<\"l\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", 
   ",", "\<\"h\"\>", ",", "\<\"a\"\>", ",", "\<\"v\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"n\"\>", ",", "\<\"o\"\>", ",", "\<\" \"\>", 
   ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"o\"\>", ",", "\<\"u\"\>", 
   ",", "\<\"g\"\>", ",", "\<\"h\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", 
   ",", "\<\"o\"\>", ",", "\<\"f\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", 
   ",", "\<\" \"\>", ",", "\<\"s\"\>", ",", "\<\"e\"\>", ",", "\<\"c\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"n\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", 
   ",", "\<\"m\"\>", ",", "\<\"a\"\>", ",", "\<\"r\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"a\"\>", ",", "\<\"g\"\>", ",", "\<\"e\"\>", 
   ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"n\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"d\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", 
   ",", "\<\"n\"\>", ",", "\<\"o\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", 
   ",", "\<\"p\"\>", ",", "\<\"o\"\>", ",", "\<\"l\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"g\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", 
   ",", "\<\"o\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"p\"\>", ",", "\<\"u\"\>", 
   ",", "\<\"b\"\>", ",", "\<\"l\"\>", ",", "\<\"i\"\>", ",", "\<\"c\"\>", 
   ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"w\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"c\"\>", ",", "\<\"h\"\>", ",", "\<\" \"\>", 
   ",", "\<\"i\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"r\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"p\"\>", 
   ",", "\<\"t\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"o\"\>", 
   ",", "\<\" \"\>", ",", "\<\"b\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"u\"\>", ",", "\<\"n\"\>", ",", "\<\"r\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"s\"\>", ",", "\<\"o\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"b\"\>", ",", "\<\"l\"\>", ",", "\<\"y\"\>", 
   ",", "\<\" \"\>", ",", "\<\"d\"\>", ",", "\<\"i\"\>", ",", "\<\"s\"\>", 
   ",", "\<\"c\"\>", ",", "\<\"o\"\>", ",", "\<\"n\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"n\"\>", ",", "\<\"t\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"w\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", 
   ",", "\<\" \"\>", ",", "\<\"w\"\>", ",", "\<\"o\"\>", ",", "\<\"m\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"d\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"e\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", 
   ",", "\<\"m\"\>", ",", "\<\"a\"\>", ",", "\<\"r\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"g\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\",\"\>", 
   ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"w\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"s\"\>", 
   ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"d\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"e\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", 
   ",", "\<\"n\"\>", ",", "\<\"o\"\>", ",", "\<\"t\"\>", ",", "\<\";\"\>", 
   ",", "\<\" \"\>", ",", "\<\"b\"\>", ",", "\<\"u\"\>", ",", "\<\"t\"\>", 
   ",", "\<\" \"\>", ",", "\<\"S\"\>", ",", "\<\"i\"\>", ",", "\<\"r\"\>", 
   ",", "\<\" \"\>", ",", "\<\"W\"\>", ",", "\<\"a\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\"'\"\>", 
   ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"c\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"t\"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"u\"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\"g\"\>", 
   ",", "\<\" \"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", 
   ",", "\<\"s\"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\"g\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"e\"\>", ",", "\<\"n\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"s\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"r\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"q\"\>", ",", "\<\"u\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"e\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", 
   ",", "\<\"e\"\>", ",", "\<\"x\"\>", ",", "\<\"p\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"a\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"o\"\>", ",", "\<\"n\"\>", ",", "\<\".\"\>", 
   ",", "\<\" \"\>", ",", "\<\"B\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"i\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", ",", "\<\"k\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"o\"\>", ",", "\<\"w\"\>", ",", "\<\"n\"\>", 
   ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"n\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", 
   ",", "\<\"h\"\>", ",", "\<\"a\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", 
   ",", "\<\"S\"\>", ",", "\<\"i\"\>", ",", "\<\"r\"\>", ",", "\<\" \"\>", 
   ",", "\<\"W\"\>", ",", "\<\"a\"\>", ",", "\<\"l\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", 
   ",", "\<\"l\"\>", ",", "\<\"i\"\>", ",", "\<\"k\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\" \"\>", ",", "\<\"g\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"o\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", 
   ",", "\<\"f\"\>", ",", "\<\"a\"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", 
   ",", "\<\"(\"\>", ",", "\<\"h\"\>", ",", "\<\"a\"\>", ",", "\<\"v\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\"g\"\>", ",", "\<\" \"\>", 
   ",", "\<\"m\"\>", ",", "\<\"e\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", 
   ",", "\<\"w\"\>", ",", "\<\"i\"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", 
   ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"n\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"r\"\>", ",", "\<\" \"\>", 
   ",", "\<\"t\"\>", ",", "\<\"w\"\>", ",", "\<\"o\"\>", ",", "\<\" \"\>", 
   ",", "\<\"p\"\>", ",", "\<\"r\"\>", ",", "\<\"i\"\>", ",", "\<\"v\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"t\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"d\"\>", ",", "\<\"i\"\>", ",", "\<\"s\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"p\"\>", ",", "\<\"p\"\>", ",", "\<\"o\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"t\"\>", ",", "\<\"m\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"t\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", 
   ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"v\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", 
   ",", "\<\"u\"\>", ",", "\<\"n\"\>", ",", "\<\"r\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"s\"\>", ",", "\<\"o\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"b\"\>", ",", "\<\"l\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"p\"\>", ",", "\<\"p\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"i\"\>", ",", "\<\"c\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"i\"\>", ",", "\<\"o\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"s\"\>", ",", "\<\")\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", 
   ",", "\<\"p\"\>", ",", "\<\"r\"\>", ",", "\<\"i\"\>", ",", "\<\"d\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"m\"\>", ",", "\<\"s\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"f\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", 
   ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"r\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"m\"\>", ",", "\<\"a\"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\"g\"\>", ",", "\<\" \"\>", 
   ",", "\<\"s\"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\"g\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"f\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"d\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"a\"\>", ",", "\<\"r\"\>", ",", "\<\" \"\>", 
   ",", "\<\"d\"\>", ",", "\<\"a\"\>", ",", "\<\"u\"\>", ",", "\<\"g\"\>", 
   ",", "\<\"h\"\>", ",", "\<\"t\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"s\"\>", ",", "\<\"'\"\>", ",", "\<\" \"\>", ",", "\<\"s\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"k\"\>", ",", "\<\"e\"\>", ",", "\<\".\"\>", 
   ",", "\<\" \"\>", ",", "\<\"F\"\>", ",", "\<\"o\"\>", ",", "\<\"r\"\>", 
   ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"n\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"d\"\>", ",", "\<\"a\"\>", ",", "\<\"u\"\>", 
   ",", "\<\"g\"\>", ",", "\<\"h\"\>", ",", "\<\"t\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"r\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"e\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"d\"\>", ",", "\<\"e\"\>", ",", "\<\"s\"\>", 
   ",", "\<\"t\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"w\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"u\"\>", ",", "\<\"l\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", 
   ",", "\<\"r\"\>", ",", "\<\"e\"\>", ",", "\<\"a\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"v\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"g\"\>", ",", "\<\"i\"\>", ",", "\<\"v\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"u\"\>", ",", "\<\"p\"\>", 
   ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"y\"\>", 
   ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"g\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", 
   ",", "\<\"w\"\>", ",", "\<\"h\"\>", ",", "\<\"i\"\>", ",", "\<\"c\"\>", 
   ",", "\<\"h\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"a\"\>", ",", "\<\"d\"\>", 
   ",", "\<\" \"\>", ",", "\<\"n\"\>", ",", "\<\"o\"\>", ",", "\<\"t\"\>", 
   ",", "\<\" \"\>", ",", "\<\"b\"\>", ",", "\<\"e\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"v\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"m\"\>", 
   ",", "\<\"u\"\>", ",", "\<\"c\"\>", ",", "\<\"h\"\>", ",", "\<\" \"\>", 
   ",", "\<\"t\"\>", ",", "\<\"e\"\>", ",", "\<\"m\"\>", ",", "\<\"p\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"e\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", 
   ",", "\<\"t\"\>", ",", "\<\"o\"\>", ",", "\<\" \"\>", ",", "\<\"d\"\>", 
   ",", "\<\"o\"\>", ",", "\<\".\"\>", ",", "\<\" \"\>", ",", "\<\"E\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"i\"\>", ",", "\<\"z\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"b\"\>", ",", "\<\"e\"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", 
   ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"a\"\>", ",", "\<\"d\"\>", 
   ",", "\<\" \"\>", ",", "\<\"s\"\>", ",", "\<\"u\"\>", ",", "\<\"c\"\>", 
   ",", "\<\"c\"\>", ",", "\<\"e\"\>", ",", "\<\"e\"\>", ",", "\<\"d\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"d\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", 
   ",", "\<\"a\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", ",", "\<\"s\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"x\"\>", ",", "\<\"t\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"n\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", 
   ",", "\<\"t\"\>", ",", "\<\"o\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"l\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", 
   ",", "\<\"h\"\>", ",", "\<\"a\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", 
   ",", "\<\"w\"\>", ",", "\<\"a\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", 
   ",", "\<\"p\"\>", ",", "\<\"o\"\>", ",", "\<\"s\"\>", ",", "\<\"s\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"b\"\>", ",", "\<\"l\"\>", ",", "\<\"e\"\>", 
   ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"f\"\>", 
   ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", 
   ",", "\<\" \"\>", ",", "\<\"m\"\>", ",", "\<\"o\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\"'\"\>", 
   ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"r\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"g\"\>", ",", "\<\"h\"\>", ",", "\<\"t\"\>", ",", "\<\"s\"\>", 
   ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"d\"\>", 
   ",", "\<\" \"\>", ",", "\<\"c\"\>", ",", "\<\"o\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"s\"\>", ",", "\<\"e\"\>", ",", "\<\"q\"\>", ",", "\<\"u\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"n\"\>", ",", "\<\"c\"\>", ",", "\<\"e\"\>", 
   ",", "\<\";\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"b\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\"g\"\>", ",", "\<\" \"\>", 
   ",", "\<\"v\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\"y\"\>", 
   ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"d\"\>", ",", "\<\"s\"\>", ",", "\<\"o\"\>", ",", "\<\"m\"\>", 
   ",", "\<\"e\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"v\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", 
   ",", "\<\"l\"\>", ",", "\<\"i\"\>", ",", "\<\"k\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"i\"\>", ",", "\<\"m\"\>", 
   ",", "\<\"s\"\>", ",", "\<\"e\"\>", ",", "\<\"l\"\>", ",", "\<\"f\"\>", 
   ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"f\"\>", ",", "\<\"l\"\>", ",", "\<\"u\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"c\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"h\"\>", ",", "\<\"a\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", 
   ",", "\<\"a\"\>", ",", "\<\"l\"\>", ",", "\<\"w\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"y\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"b\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"e\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", 
   ",", "\<\"g\"\>", ",", "\<\"r\"\>", ",", "\<\"e\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"t\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", 
   ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", 
   ",", "\<\"h\"\>", ",", "\<\"a\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", 
   ",", "\<\"g\"\>", ",", "\<\"o\"\>", ",", "\<\"n\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", 
   ",", "\<\"t\"\>", ",", "\<\"o\"\>", ",", "\<\"g\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", 
   ",", "\<\" \"\>", ",", "\<\"m\"\>", ",", "\<\"o\"\>", ",", "\<\"s\"\>", 
   ",", "\<\"t\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"p\"\>", ",", "\<\"p\"\>", ",", "\<\"i\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"y\"\>", ",", "\<\".\"\>", ",", "\<\" \"\>", ",", "\<\"H\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", 
   ",", "\<\"w\"\>", ",", "\<\"o\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", 
   ",", "\<\" \"\>", ",", "\<\"c\"\>", ",", "\<\"h\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"d\"\>", ",", "\<\"r\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"w\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", 
   ",", "\<\"f\"\>", ",", "\<\" \"\>", ",", "\<\"v\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"i\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"f\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"o\"\>", ",", "\<\"r\"\>", ",", "\<\" \"\>", 
   ",", "\<\"v\"\>", ",", "\<\"a\"\>", ",", "\<\"l\"\>", ",", "\<\"u\"\>", 
   ",", "\<\"e\"\>", ",", "\<\".\"\>", ",", "\<\" \"\>", ",", "\<\"M\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"r\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", 
   ",", "\<\"h\"\>", ",", "\<\"a\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", 
   ",", "\<\"a\"\>", ",", "\<\"c\"\>", ",", "\<\"q\"\>", ",", "\<\"u\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"r\"\>", ",", "\<\"e\"\>", ",", "\<\"d\"\>", 
   ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\" \"\>", ",", "\<\"l\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"t\"\>", ",", "\<\"t\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"i\"\>", ",", "\<\"f\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"c\"\>", ",", "\<\"i\"\>", ",", "\<\"a\"\>", ",", "\<\"l\"\>", 
   ",", "\<\" \"\>", ",", "\<\"i\"\>", ",", "\<\"m\"\>", ",", "\<\"p\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"r\"\>", ",", "\<\"t\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"c\"\>", ",", "\<\"e\"\>", ",", "\<\",\"\>", 
   ",", "\<\" \"\>", ",", "\<\"b\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", 
   ",", "\<\"b\"\>", ",", "\<\"e\"\>", ",", "\<\"c\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"m\"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\"g\"\>", 
   ",", "\<\" \"\>", ",", "\<\"M\"\>", ",", "\<\"r\"\>", ",", "\<\"s\"\>", 
   ",", "\<\" \"\>", ",", "\<\"C\"\>", ",", "\<\"h\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"l\"\>", ",", "\<\"e\"\>", ",", "\<\"s\"\>", 
   ",", "\<\" \"\>", ",", "\<\"M\"\>", ",", "\<\"u\"\>", ",", "\<\"s\"\>", 
   ",", "\<\"g\"\>", ",", "\<\"r\"\>", ",", "\<\"o\"\>", ",", "\<\"v\"\>", 
   ",", "\<\"e\"\>", ",", "\<\";\"\>", ",", "\<\" \"\>", ",", "\<\"b\"\>", 
   ",", "\<\"u\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", ",", "\<\"A\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"n\"\>", ",", "\<\"e\"\>", ",", "\<\",\"\>", 
   ",", "\<\" \"\>", ",", "\<\"w\"\>", ",", "\<\"i\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"h\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", 
   ",", "\<\" \"\>", ",", "\<\"e\"\>", ",", "\<\"l\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"g\"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"c\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"f\"\>", 
   ",", "\<\" \"\>", ",", "\<\"m\"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"s\"\>", ",", "\<\"w\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"e\"\>", ",", "\<\"t\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"s\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", 
   ",", "\<\"o\"\>", ",", "\<\"f\"\>", ",", "\<\" \"\>", ",", "\<\"c\"\>", 
   ",", "\<\"h\"\>", ",", "\<\"a\"\>", ",", "\<\"r\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"c\"\>", ",", "\<\"t\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", 
   ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"w\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"c\"\>", ",", "\<\"h\"\>", ",", "\<\" \"\>", 
   ",", "\<\"m\"\>", ",", "\<\"u\"\>", ",", "\<\"s\"\>", ",", "\<\"t\"\>", 
   ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"a\"\>", ",", "\<\"v\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"p\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"c\"\>", ",", "\<\"e\"\>", ",", "\<\"d\"\>", 
   ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", 
   ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"i\"\>", ",", "\<\"g\"\>", 
   ",", "\<\"h\"\>", ",", "\<\" \"\>", ",", "\<\"w\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"p\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"o\"\>", ",", "\<\"p\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"f\"\>", 
   ",", "\<\" \"\>", ",", "\<\"r\"\>", ",", "\<\"e\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"l\"\>", ",", "\<\" \"\>", ",", "\<\"u\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"d\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\"s\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"d\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\"g\"\>", ",", "\<\",\"\>", 
   ",", "\<\" \"\>", ",", "\<\"w\"\>", ",", "\<\"a\"\>", ",", "\<\"s\"\>", 
   ",", "\<\" \"\>", ",", "\<\"n\"\>", ",", "\<\"o\"\>", ",", "\<\"b\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"d\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", 
   ",", "\<\"w\"\>", ",", "\<\"i\"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", 
   ",", "\<\" \"\>", ",", "\<\"e\"\>", ",", "\<\"i\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\" \"\>", 
   ",", "\<\"f\"\>", ",", "\<\"a\"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", 
   ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"s\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"s\"\>", ",", "\<\"t\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", 
   ",", "\<\";\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"w\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"n\"\>", 
   ",", "\<\"o\"\>", ",", "\<\" \"\>", ",", "\<\"w\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"g\"\>", ",", "\<\"h\"\>", ",", "\<\"t\"\>", 
   ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"c\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"v\"\>", ",", "\<\"e\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"e\"\>", ",", "\<\"n\"\>", ",", "\<\"c\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"w\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"w\"\>", ",", "\<\"a\"\>", ",", "\<\"y\"\>", ",", "\<\"s\"\>", 
   ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"o\"\>", ",", "\<\" \"\>", 
   ",", "\<\"g\"\>", ",", "\<\"i\"\>", ",", "\<\"v\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"w\"\>", ",", "\<\"a\"\>", ",", "\<\"y\"\>", 
   ",", "\<\"-\"\>", ",", "\<\"-\"\>", ",", "\<\"s\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"w\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"A\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"n\"\>", ",", "\<\"e\"\>", ",", "\<\".\"\>", 
   ",", "\<\" \"\>", ",", "\<\"T\"\>", ",", "\<\"o\"\>", ",", "\<\" \"\>", 
   ",", "\<\"L\"\>", ",", "\<\"a\"\>", ",", "\<\"d\"\>", ",", "\<\"y\"\>", 
   ",", "\<\" \"\>", ",", "\<\"R\"\>", ",", "\<\"u\"\>", ",", "\<\"s\"\>", 
   ",", "\<\"s\"\>", ",", "\<\"e\"\>", ",", "\<\"l\"\>", ",", "\<\"l\"\>", 
   ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"d\"\>", ",", "\<\"e\"\>", ",", "\<\"e\"\>", ",", "\<\"d\"\>", 
   ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"s\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"w\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\" \"\>", 
   ",", "\<\"m\"\>", ",", "\<\"o\"\>", ",", "\<\"s\"\>", ",", "\<\"t\"\>", 
   ",", "\<\" \"\>", ",", "\<\"d\"\>", ",", "\<\"e\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"g\"\>", ",", "\<\"h\"\>", ",", "\<\"l\"\>", ",", "\<\"y\"\>", 
   ",", "\<\" \"\>", ",", "\<\"v\"\>", ",", "\<\"a\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"u\"\>", ",", "\<\"e\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", 
   ",", "\<\"g\"\>", ",", "\<\"o\"\>", ",", "\<\"d\"\>", ",", "\<\"-\"\>", 
   ",", "\<\"d\"\>", ",", "\<\"a\"\>", ",", "\<\"u\"\>", ",", "\<\"g\"\>", 
   ",", "\<\"h\"\>", ",", "\<\"t\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", 
   ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"f\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"v\"\>", ",", "\<\"o\"\>", ",", "\<\"u\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"t\"\>", ",", "\<\"e\"\>", ",", "\<\",\"\>", 
   ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"d\"\>", 
   ",", "\<\" \"\>", ",", "\<\"f\"\>", ",", "\<\"r\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"n\"\>", ",", "\<\"d\"\>", ",", "\<\".\"\>", 
   ",", "\<\" \"\>", ",", "\<\"L\"\>", ",", "\<\"a\"\>", ",", "\<\"d\"\>", 
   ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"R\"\>", ",", "\<\"u\"\>", 
   ",", "\<\"s\"\>", ",", "\<\"s\"\>", ",", "\<\"e\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"l\"\>", ",", "\<\" \"\>", ",", "\<\"l\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"v\"\>", ",", "\<\"e\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", 
   ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\"m\"\>", 
   ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"l\"\>", ",", "\<\"l\"\>", 
   ",", "\<\";\"\>", ",", "\<\" \"\>", ",", "\<\"b\"\>", ",", "\<\"u\"\>", 
   ",", "\<\"t\"\>", ",", "\<\" \"\>", ",", "\<\"i\"\>", ",", "\<\"t\"\>", 
   ",", "\<\" \"\>", ",", "\<\"w\"\>", ",", "\<\"a\"\>", ",", "\<\"s\"\>", 
   ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"n\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", 
   ",", "\<\" \"\>", ",", "\<\"A\"\>", ",", "\<\"n\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", ",", "\<\"s\"\>", 
   ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"c\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"u\"\>", ",", "\<\"l\"\>", ",", "\<\"d\"\>", 
   ",", "\<\" \"\>", ",", "\<\"f\"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"c\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", 
   ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"m\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"o\"\>", 
   ",", "\<\" \"\>", ",", "\<\"r\"\>", ",", "\<\"e\"\>", ",", "\<\"v\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"v\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"a\"\>", ",", "\<\"g\"\>", ",", "\<\"a\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"n\"\>", ",", "\<\".\"\>", ",", "\<\" \"\>", ",", "\<\"A\"\>", 
   ",", "\<\" \"\>", ",", "\<\"f\"\>", ",", "\<\"e\"\>", ",", "\<\"w\"\>", 
   ",", "\<\" \"\>", ",", "\<\"y\"\>", ",", "\<\"e\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"b\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"f\"\>", ",", "\<\"o\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"e\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"A\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"n\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"E\"\>", ",", "\<\"l\"\>", ",", "\<\"l\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"b\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"e\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", 
   ",", "\<\"a\"\>", ",", "\<\" \"\>", ",", "\<\"v\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"p\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"e\"\>", ",", "\<\"t\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"g\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"l\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", 
   ",", "\<\"b\"\>", ",", "\<\"u\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", 
   ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\" \"\>", 
   ",", "\<\"b\"\>", ",", "\<\"l\"\>", ",", "\<\"o\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"m\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"v\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"i\"\>", ",", "\<\"s\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"e\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"r\"\>", ",", "\<\"l\"\>", ",", "\<\"y\"\>", 
   ",", "\<\";\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"s\"\>", 
   ",", "\<\" \"\>", ",", "\<\"e\"\>", ",", "\<\"v\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", 
   ",", "\<\" \"\>", ",", "\<\"i\"\>", ",", "\<\"t\"\>", ",", "\<\"s\"\>", 
   ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"g\"\>", ",", "\<\"h\"\>", ",", "\<\"t\"\>", ",", "\<\",\"\>", 
   ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", 
   ",", "\<\" \"\>", ",", "\<\"f\"\>", ",", "\<\"a\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\" \"\>", 
   ",", "\<\"h\"\>", ",", "\<\"a\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", 
   ",", "\<\"f\"\>", ",", "\<\"o\"\>", ",", "\<\"u\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"l\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"t\"\>", ",", "\<\"l\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"o\"\>", ",", "\<\" \"\>", 
   ",", "\<\"a\"\>", ",", "\<\"d\"\>", ",", "\<\"m\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"i\"\>", 
   ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"r\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"(\"\>", 
   ",", "\<\"s\"\>", ",", "\<\"o\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"t\"\>", ",", "\<\"a\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"d\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"f\"\>", ",", "\<\"f\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"e\"\>", ",", "\<\"n\"\>", ",", "\<\"t\"\>", 
   ",", "\<\" \"\>", ",", "\<\"w\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"d\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"i\"\>", ",", "\<\"c\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"f\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"a\"\>", ",", "\<\"t\"\>", ",", "\<\"u\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"e\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", 
   ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", 
   ",", "\<\"m\"\>", ",", "\<\"i\"\>", ",", "\<\"l\"\>", ",", "\<\"d\"\>", 
   ",", "\<\" \"\>", ",", "\<\"d\"\>", ",", "\<\"a\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"k\"\>", ",", "\<\" \"\>", ",", "\<\"e\"\>", ",", "\<\"y\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"f\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"o\"\>", ",", "\<\"m\"\>", ",", "\<\" \"\>", 
   ",", "\<\"h\"\>", ",", "\<\"i\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", 
   ",", "\<\"o\"\>", ",", "\<\"w\"\>", ",", "\<\"n\"\>", ",", "\<\")\"\>", 
   ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"c\"\>", ",", "\<\"o\"\>", ",", "\<\"u\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"b\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"n\"\>", ",", "\<\"o\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"h\"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\"g\"\>", 
   ",", "\<\" \"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", 
   ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\"m\"\>", 
   ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"n\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"w\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", ",", "\<\"s\"\>", 
   ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"w\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"f\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"d\"\>", ",", "\<\"e\"\>", ",", "\<\"d\"\>", 
   ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"d\"\>", 
   ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"n\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", 
   ",", "\<\"o\"\>", ",", "\<\" \"\>", ",", "\<\"e\"\>", ",", "\<\"x\"\>", 
   ",", "\<\"c\"\>", ",", "\<\"i\"\>", ",", "\<\"t\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"i\"\>", ",", "\<\"s\"\>", 
   ",", "\<\" \"\>", ",", "\<\"e\"\>", ",", "\<\"s\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"e\"\>", ",", "\<\"m\"\>", ",", "\<\".\"\>", 
   ",", "\<\" \"\>", ",", "\<\"H\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"h\"\>", ",", "\<\"a\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", 
   ",", "\<\"n\"\>", ",", "\<\"e\"\>", ",", "\<\"v\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"d\"\>", ",", "\<\"u\"\>", ",", "\<\"l\"\>", ",", "\<\"g\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"m\"\>", 
   ",", "\<\"u\"\>", ",", "\<\"c\"\>", ",", "\<\"h\"\>", ",", "\<\" \"\>", 
   ",", "\<\"h\"\>", ",", "\<\"o\"\>", ",", "\<\"p\"\>", ",", "\<\"e\"\>", 
   ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"a\"\>", ",", "\<\"d\"\>", 
   ",", "\<\" \"\>", ",", "\<\"n\"\>", ",", "\<\"o\"\>", ",", "\<\"w\"\>", 
   ",", "\<\" \"\>", ",", "\<\"n\"\>", ",", "\<\"o\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"e\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", 
   ",", "\<\"f\"\>", ",", "\<\" \"\>", ",", "\<\"e\"\>", ",", "\<\"v\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"r\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"a\"\>", ",", "\<\"d\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"g\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"n\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"m\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", 
   ",", "\<\" \"\>", ",", "\<\"p\"\>", ",", "\<\"a\"\>", ",", "\<\"g\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"f\"\>", 
   ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"i\"\>", ",", "\<\"s\"\>", 
   ",", "\<\" \"\>", ",", "\<\"f\"\>", ",", "\<\"a\"\>", ",", "\<\"v\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"u\"\>", ",", "\<\"r\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"w\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"r\"\>", ",", "\<\"k\"\>", ",", "\<\".\"\>", 
   ",", "\<\" \"\>", ",", "\<\"A\"\>", ",", "\<\"l\"\>", ",", "\<\"l\"\>", 
   ",", "\<\" \"\>", ",", "\<\"e\"\>", ",", "\<\"q\"\>", ",", "\<\"u\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"l\"\>", ",", "\<\"i\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"f\"\>", 
   ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"l\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"c\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"m\"\>", ",", "\<\"u\"\>", 
   ",", "\<\"s\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", ",", "\<\"r\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"s\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", 
   ",", "\<\"w\"\>", ",", "\<\"i\"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", 
   ",", "\<\" \"\>", ",", "\<\"E\"\>", ",", "\<\"l\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"z\"\>", ",", "\<\"a\"\>", ",", "\<\"b\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", 
   ",", "\<\"f\"\>", ",", "\<\"o\"\>", ",", "\<\"r\"\>", ",", "\<\" \"\>", 
   ",", "\<\"M\"\>", ",", "\<\"a\"\>", ",", "\<\"r\"\>", ",", "\<\"y\"\>", 
   ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"a\"\>", ",", "\<\"d\"\>", 
   ",", "\<\" \"\>", ",", "\<\"m\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"l\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", 
   ",", "\<\"c\"\>", ",", "\<\"o\"\>", ",", "\<\"n\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"c\"\>", ",", "\<\"t\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"s\"\>", ",", "\<\"e\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"f\"\>", ",", "\<\" \"\>", ",", "\<\"w\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", 
   ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"c\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"u\"\>", ",", "\<\"n\"\>", ",", "\<\"t\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"f\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"m\"\>", ",", "\<\"i\"\>", ",", "\<\"l\"\>", ",", "\<\"y\"\>", 
   ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"f\"\>", ",", "\<\" \"\>", 
   ",", "\<\"r\"\>", ",", "\<\"e\"\>", ",", "\<\"s\"\>", ",", "\<\"p\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"c\"\>", ",", "\<\"t\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"b\"\>", ",", "\<\"i\"\>", ",", "\<\"l\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"l\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"r\"\>", ",", "\<\"g\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"f\"\>", ",", "\<\"o\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"u\"\>", ",", "\<\"n\"\>", ",", "\<\"e\"\>", 
   ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\"e\"\>", ",", "\<\"f\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"r\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"g\"\>", ",", "\<\"i\"\>", ",", "\<\"v\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"l\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"o\"\>", ",", "\<\"u\"\>", ",", "\<\"r\"\>", 
   ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"d\"\>", 
   ",", "\<\" \"\>", ",", "\<\"r\"\>", ",", "\<\"e\"\>", ",", "\<\"c\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"i\"\>", ",", "\<\"v\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"n\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"e\"\>", ",", "\<\":\"\>", ",", "\<\" \"\>", 
   ",", "\<\"E\"\>", ",", "\<\"l\"\>", ",", "\<\"i\"\>", ",", "\<\"z\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"b\"\>", ",", "\<\"e\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"h\"\>", ",", "\<\" \"\>", ",", "\<\"w\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"u\"\>", ",", "\<\"l\"\>", ",", "\<\"d\"\>", ",", "\<\",\"\>", 
   ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"n\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"d\"\>", ",", "\<\"a\"\>", ",", "\<\"y\"\>", 
   ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"r\"\>", ",", "\<\" \"\>", 
   ",", "\<\"o\"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"r\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"m\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"r\"\>", ",", "\<\"r\"\>", ",", "\<\"y\"\>", 
   ",", "\<\" \"\>", ",", "\<\"s\"\>", ",", "\<\"u\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"a\"\>", ",", "\<\"b\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"y\"\>", ",", "\<\".\"\>", ",", "\<\" \"\>", ",", "\<\"I\"\>", 
   ",", "\<\"t\"\>", ",", "\<\" \"\>", ",", "\<\"s\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"m\"\>", ",", "\<\"e\"\>", ",", "\<\"t\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"m\"\>", ",", "\<\"e\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", 
   ",", "\<\"h\"\>", ",", "\<\"a\"\>", ",", "\<\"p\"\>", ",", "\<\"p\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"n\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", 
   ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"a\"\>", ",", "\<\"t\"\>", 
   ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\" \"\>", ",", "\<\"w\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"m\"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", 
   ",", "\<\" \"\>", ",", "\<\"i\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", 
   ",", "\<\"h\"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"d\"\>", 
   ",", "\<\"s\"\>", ",", "\<\"o\"\>", ",", "\<\"m\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"t\"\>", 
   ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"w\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"t\"\>", ",", "\<\"y\"\>", ",", "\<\"-\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"s\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"w\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"y\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"r\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", 
   ",", "\<\"b\"\>", ",", "\<\"e\"\>", ",", "\<\"f\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"e\"\>", ",", "\<\";\"\>", ",", "\<\" \"\>", 
   ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"d\"\>", ",", "\<\",\"\>", 
   ",", "\<\" \"\>", ",", "\<\"g\"\>", ",", "\<\"e\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\"a\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"s\"\>", 
   ",", "\<\"p\"\>", ",", "\<\"e\"\>", ",", "\<\"a\"\>", ",", "\<\"k\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\"g\"\>", ",", "\<\",\"\>", 
   ",", "\<\" \"\>", ",", "\<\"i\"\>", ",", "\<\"f\"\>", ",", "\<\" \"\>", 
   ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"b\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"n\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"i\"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"i\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"l\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"a\"\>", ",", "\<\"l\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"h\"\>", ",", "\<\" \"\>", ",", "\<\"n\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"x\"\>", ",", "\<\"i\"\>", ",", "\<\"e\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"y\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"i\"\>", 
   ",", "\<\"t\"\>", ",", "\<\" \"\>", ",", "\<\"i\"\>", ",", "\<\"s\"\>", 
   ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"m\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"o\"\>", ",", "\<\"f\"\>", ",", "\<\" \"\>", ",", "\<\"l\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"f\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"a\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", ",", "\<\"w\"\>", 
   ",", "\<\"h\"\>", ",", "\<\"i\"\>", ",", "\<\"c\"\>", ",", "\<\"h\"\>", 
   ",", "\<\" \"\>", ",", "\<\"s\"\>", ",", "\<\"c\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"c\"\>", ",", "\<\"e\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"c\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"r\"\>", ",", "\<\"m\"\>", ",", "\<\" \"\>", 
   ",", "\<\"i\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"l\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"s\"\>", ",", "\<\"t\"\>", ",", "\<\".\"\>", 
   ",", "\<\" \"\>", ",", "\<\"I\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", 
   ",", "\<\"w\"\>", ",", "\<\"a\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", 
   ",", "\<\"s\"\>", ",", "\<\"o\"\>", ",", "\<\" \"\>", ",", "\<\"w\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\" \"\>", 
   ",", "\<\"E\"\>", ",", "\<\"l\"\>", ",", "\<\"i\"\>", ",", "\<\"z\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"b\"\>", ",", "\<\"e\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"h\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"s\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"i\"\>", ",", "\<\"l\"\>", ",", "\<\"l\"\>", 
   ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"s\"\>", ",", "\<\"a\"\>", ",", "\<\"m\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"d\"\>", ",", "\<\"s\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"m\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"M\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"s\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", 
   ",", "\<\"E\"\>", ",", "\<\"l\"\>", ",", "\<\"l\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", 
   ",", "\<\"h\"\>", ",", "\<\"a\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", 
   ",", "\<\"s\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"h\"\>", ",", "\<\"a\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", 
   ",", "\<\"b\"\>", ",", "\<\"e\"\>", ",", "\<\"g\"\>", ",", "\<\"u\"\>", 
   ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"o\"\>", 
   ",", "\<\" \"\>", ",", "\<\"b\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"i\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"e\"\>", ",", "\<\"e\"\>", ",", "\<\"n\"\>", 
   ",", "\<\" \"\>", ",", "\<\"y\"\>", ",", "\<\"e\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", 
   ",", "\<\"g\"\>", ",", "\<\"o\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", 
   ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", 
   ",", "\<\"S\"\>", ",", "\<\"i\"\>", ",", "\<\"r\"\>", ",", "\<\" \"\>", 
   ",", "\<\"W\"\>", ",", "\<\"a\"\>", ",", "\<\"l\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"m\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"g\"\>", ",", "\<\"h\"\>", ",", "\<\"t\"\>", 
   ",", "\<\" \"\>", ",", "\<\"b\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"e\"\>", ",", "\<\"x\"\>", ",", "\<\"c\"\>", ",", "\<\"u\"\>", 
   ",", "\<\"s\"\>", ",", "\<\"e\"\>", ",", "\<\"d\"\>", ",", "\<\",\"\>", 
   ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"e\"\>", ",", "\<\"f\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"e\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", 
   ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"f\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"r\"\>", ",", "\<\"g\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"t\"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"g\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"g\"\>", 
   ",", "\<\"e\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", 
   ",", "\<\"r\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", 
   ",", "\<\"t\"\>", ",", "\<\" \"\>", ",", "\<\"l\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"s\"\>", ",", "\<\"t\"\>", ",", "\<\",\"\>", 
   ",", "\<\" \"\>", ",", "\<\"b\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"d\"\>", ",", "\<\"e\"\>", ",", "\<\"e\"\>", ",", "\<\"m\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"l\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", 
   ",", "\<\"h\"\>", ",", "\<\"a\"\>", ",", "\<\"l\"\>", ",", "\<\"f\"\>", 
   ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\" \"\>", ",", "\<\"f\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"o\"\>", ",", "\<\"l\"\>", ",", "\<\",\"\>", 
   ",", "\<\" \"\>", ",", "\<\"f\"\>", ",", "\<\"o\"\>", ",", "\<\"r\"\>", 
   ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"k\"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"g\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"m\"\>", ",", "\<\"s\"\>", ",", "\<\"e\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"f\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"E\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"z\"\>", ",", "\<\"a\"\>", ",", "\<\"b\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\" \"\>", 
   ",", "\<\"a\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"b\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"o\"\>", ",", "\<\"o\"\>", ",", "\<\"m\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\"g\"\>", ",", "\<\" \"\>", 
   ",", "\<\"a\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"e\"\>", 
   ",", "\<\"v\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\",\"\>", 
   ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"m\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"d\"\>", ",", "\<\"s\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", 
   ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"w\"\>", ",", "\<\"r\"\>", ",", "\<\"e\"\>", ",", "\<\"c\"\>", 
   ",", "\<\"k\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"f\"\>", 
   ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"g\"\>", ",", "\<\"o\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"l\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"k\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", 
   ",", "\<\"o\"\>", ",", "\<\"f\"\>", ",", "\<\" \"\>", ",", "\<\"e\"\>", 
   ",", "\<\"v\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\"y\"\>", 
   ",", "\<\"b\"\>", ",", "\<\"o\"\>", ",", "\<\"d\"\>", ",", "\<\"y\"\>", 
   ",", "\<\" \"\>", ",", "\<\"e\"\>", ",", "\<\"l\"\>", ",", "\<\"s\"\>", 
   ",", "\<\"e\"\>", ",", "\<\";\"\>", ",", "\<\" \"\>", ",", "\<\"f\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"c\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"u\"\>", ",", "\<\"l\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", 
   ",", "\<\"p\"\>", ",", "\<\"l\"\>", ",", "\<\"a\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"l\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", 
   ",", "\<\"s\"\>", ",", "\<\"e\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"h\"\>", ",", "\<\"o\"\>", ",", "\<\"w\"\>", ",", "\<\" \"\>", 
   ",", "\<\"o\"\>", ",", "\<\"l\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", 
   ",", "\<\"a\"\>", ",", "\<\"l\"\>", ",", "\<\"l\"\>", ",", "\<\" \"\>", 
   ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"r\"\>", ",", "\<\"e\"\>", ",", "\<\"s\"\>", ",", "\<\"t\"\>", 
   ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"f\"\>", ",", "\<\" \"\>", 
   ",", "\<\"h\"\>", ",", "\<\"i\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", 
   ",", "\<\"f\"\>", ",", "\<\"a\"\>", ",", "\<\"m\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", 
   ",", "\<\"c\"\>", ",", "\<\"q\"\>", ",", "\<\"u\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\"t\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"c\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"w\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"g\"\>", ",", "\<\"r\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"w\"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\"g\"\>", 
   ",", "\<\".\"\>", ",", "\<\" \"\>", ",", "\<\"A\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"g\"\>", ",", "\<\"g\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"d\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", 
   ",", "\<\"M\"\>", ",", "\<\"a\"\>", ",", "\<\"r\"\>", ",", "\<\"y\"\>", 
   ",", "\<\" \"\>", ",", "\<\"c\"\>", ",", "\<\"o\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"s\"\>", ",", "\<\"e\"\>", ",", "\<\",\"\>", 
   ",", "\<\" \"\>", ",", "\<\"e\"\>", ",", "\<\"v\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"f\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"c\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", 
   ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"n\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"i\"\>", ",", "\<\"g\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"b\"\>", ",", "\<\"o\"\>", ",", "\<\"u\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"h\"\>", ",", "\<\"o\"\>", ",", "\<\"o\"\>", ",", "\<\"d\"\>", 
   ",", "\<\" \"\>", ",", "\<\"w\"\>", ",", "\<\"o\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"s\"\>", ",", "\<\"t\"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"g\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", 
   ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"r\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"p\"\>", ",", "\<\"i\"\>", ",", "\<\"d\"\>", 
   ",", "\<\" \"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\"c\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"e\"\>", ",", "\<\"a\"\>", ",", "\<\"s\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"f\"\>", 
   ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"c\"\>", ",", "\<\"r\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"w\"\>", ",", "\<\"'\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", 
   ",", "\<\"f\"\>", ",", "\<\"o\"\>", ",", "\<\"o\"\>", ",", "\<\"t\"\>", 
   ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"b\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"u\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", ",", "\<\"L\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"d\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", 
   ",", "\<\"R\"\>", ",", "\<\"u\"\>", ",", "\<\"s\"\>", ",", "\<\"s\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"l\"\>", ",", "\<\"l\"\>", ",", "\<\"'\"\>", 
   ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"m\"\>", ",", "\<\"p\"\>", ",", "\<\"l\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"l\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"g\"\>", ",", "\<\" \"\>", ",", "\<\"b\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"e\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", 
   ",", "\<\"a\"\>", ",", "\<\" \"\>", ",", "\<\"d\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"s\"\>", ",", "\<\"t\"\>", ",", "\<\"r\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"s\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", 
   ",", "\<\"o\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"m\"\>", ",", "\<\".\"\>", ",", "\<\" \"\>", ",", "\<\"E\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"i\"\>", ",", "\<\"z\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"b\"\>", ",", "\<\"e\"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", 
   ",", "\<\" \"\>", ",", "\<\"d\"\>", ",", "\<\"i\"\>", ",", "\<\"d\"\>", 
   ",", "\<\" \"\>", ",", "\<\"n\"\>", ",", "\<\"o\"\>", ",", "\<\"t\"\>", 
   ",", "\<\" \"\>", ",", "\<\"q\"\>", ",", "\<\"u\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"e\"\>", 
   ",", "\<\"q\"\>", ",", "\<\"u\"\>", ",", "\<\"a\"\>", ",", "\<\"l\"\>", 
   ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", 
   ",", "\<\" \"\>", ",", "\<\"f\"\>", ",", "\<\"a\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\" \"\>", 
   ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"p\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\"s\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"a\"\>", ",", "\<\"l\"\>", ",", "\<\" \"\>", 
   ",", "\<\"c\"\>", ",", "\<\"o\"\>", ",", "\<\"n\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"n\"\>", ",", "\<\"t\"\>", ",", "\<\"m\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"n\"\>", ",", "\<\"t\"\>", ",", "\<\".\"\>", 
   ",", "\<\" \"\>", ",", "\<\"T\"\>", ",", "\<\"h\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"t\"\>", ",", "\<\"e\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"y\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"r\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", 
   ",", "\<\"h\"\>", ",", "\<\"a\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", 
   ",", "\<\"s\"\>", ",", "\<\"e\"\>", ",", "\<\"e\"\>", ",", "\<\"n\"\>", 
   ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", 
   ",", "\<\" \"\>", ",", "\<\"m\"\>", ",", "\<\"i\"\>", ",", "\<\"s\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"r\"\>", ",", "\<\"e\"\>", ",", "\<\"s\"\>", 
   ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"f\"\>", 
   ",", "\<\" \"\>", ",", "\<\"K\"\>", ",", "\<\"e\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"y\"\>", ",", "\<\"n\"\>", ",", "\<\"c\"\>", 
   ",", "\<\"h\"\>", ",", "\<\" \"\>", ",", "\<\"H\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"l\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", 
   ",", "\<\"p\"\>", ",", "\<\"r\"\>", ",", "\<\"e\"\>", ",", "\<\"s\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"d\"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"g\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"d\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"e\"\>", ",", "\<\"c\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\"g\"\>", ",", "\<\" \"\>", 
   ",", "\<\"w\"\>", ",", "\<\"i\"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", 
   ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\" \"\>", ",", "\<\"s\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"l\"\>", ",", "\<\"f\"\>", ",", "\<\"-\"\>", 
   ",", "\<\"p\"\>", ",", "\<\"o\"\>", ",", "\<\"s\"\>", ",", "\<\"s\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"s\"\>", ",", "\<\"s\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"d\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"c\"\>", ",", "\<\"i\"\>", ",", "\<\"s\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"o\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", 
   ",", "\<\"w\"\>", ",", "\<\"h\"\>", ",", "\<\"i\"\>", ",", "\<\"c\"\>", 
   ",", "\<\"h\"\>", ",", "\<\" \"\>", ",", "\<\"c\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"u\"\>", ",", "\<\"l\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", 
   ",", "\<\"n\"\>", ",", "\<\"e\"\>", ",", "\<\"v\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"v\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"g\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"v\"\>", ",", "\<\"e\"\>", ",", "\<\"n\"\>", 
   ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"i\"\>", ",", "\<\"d\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"a\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"f\"\>", 
   ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", 
   ",", "\<\" \"\>", ",", "\<\"b\"\>", ",", "\<\"e\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"g\"\>", ",", "\<\" \"\>", ",", "\<\"y\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"u\"\>", ",", "\<\"n\"\>", ",", "\<\"g\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", 
   ",", "\<\"h\"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", 
   ",", "\<\"s\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"w\"\>", ",", "\<\"a\"\>", ",", "\<\"s\"\>", ",", "\<\".\"\>", 
   ",", "\<\" \"\>", ",", "\<\"F\"\>", ",", "\<\"o\"\>", ",", "\<\"r\"\>", 
   ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"t\"\>", ",", "\<\"e\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"y\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"r\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", 
   ",", "\<\"h\"\>", ",", "\<\"a\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", 
   ",", "\<\"s\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"b\"\>", ",", "\<\"e\"\>", ",", "\<\"e\"\>", ",", "\<\"n\"\>", 
   ",", "\<\" \"\>", ",", "\<\"d\"\>", ",", "\<\"o\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"g\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", 
   ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"n\"\>", ",", "\<\"o\"\>", ",", "\<\"u\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"s\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", 
   ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", 
   ",", "\<\"l\"\>", ",", "\<\"a\"\>", ",", "\<\"y\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"g\"\>", ",", "\<\" \"\>", ",", "\<\"d\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"w\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", 
   ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"d\"\>", ",", "\<\"o\"\>", ",", "\<\"m\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"s\"\>", ",", "\<\"t\"\>", ",", "\<\"i\"\>", ",", "\<\"c\"\>", 
   ",", "\<\" \"\>", ",", "\<\"l\"\>", ",", "\<\"a\"\>", ",", "\<\"w\"\>", 
   ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", 
   ",", "\<\"h\"\>", ",", "\<\"o\"\>", ",", "\<\"m\"\>", ",", "\<\"e\"\>", 
   ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"l\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"d\"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"g\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"w\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"o\"\>", 
   ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"c\"\>", ",", "\<\"h\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"s\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", 
   ",", "\<\"f\"\>", ",", "\<\"o\"\>", ",", "\<\"u\"\>", ",", "\<\"r\"\>", 
   ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"w\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"k\"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"g\"\>", ",", "\<\" \"\>", ",", "\<\"i\"\>", ",", "\<\"m\"\>", 
   ",", "\<\"m\"\>", ",", "\<\"e\"\>", ",", "\<\"d\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"t\"\>", ",", "\<\"e\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"f\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\" \"\>", 
   ",", "\<\"L\"\>", ",", "\<\"a\"\>", ",", "\<\"d\"\>", ",", "\<\"y\"\>", 
   ",", "\<\" \"\>", ",", "\<\"R\"\>", ",", "\<\"u\"\>", ",", "\<\"s\"\>", 
   ",", "\<\"s\"\>", ",", "\<\"e\"\>", ",", "\<\"l\"\>", ",", "\<\"l\"\>", 
   ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"u\"\>", ",", "\<\"t\"\>", 
   ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"f\"\>", ",", "\<\" \"\>", 
   ",", "\<\"a\"\>", ",", "\<\"l\"\>", ",", "\<\"l\"\>", ",", "\<\" \"\>", 
   ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"d\"\>", ",", "\<\"r\"\>", ",", "\<\"a\"\>", ",", "\<\"w\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\"g\"\>", ",", "\<\"-\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"o\"\>", ",", "\<\"o\"\>", ",", "\<\"m\"\>", 
   ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"d\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\"g\"\>", 
   ",", "\<\"-\"\>", ",", "\<\"r\"\>", ",", "\<\"o\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"m\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"i\"\>", 
   ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"c\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"u\"\>", ",", "\<\"n\"\>", ",", "\<\"t\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"y\"\>", ",", "\<\".\"\>", ",", "\<\" \"\>", ",", "\<\"T\"\>", 
   ",", "\<\"h\"\>", ",", "\<\"i\"\>", ",", "\<\"r\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"e\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", 
   ",", "\<\"w\"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\"s\"\>", ",", "\<\"'\"\>", 
   ",", "\<\" \"\>", ",", "\<\"r\"\>", ",", "\<\"e\"\>", ",", "\<\"v\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"l\"\>", ",", "\<\"v\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"g\"\>", ",", "\<\" \"\>", ",", "\<\"f\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"o\"\>", ",", "\<\"s\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"s\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", 
   ",", "\<\"p\"\>", ",", "\<\"e\"\>", ",", "\<\"n\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"g\"\>", ",", "\<\" \"\>", ",", "\<\"e\"\>", 
   ",", "\<\"v\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\"y\"\>", 
   ",", "\<\" \"\>", ",", "\<\"b\"\>", ",", "\<\"a\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"l\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"f\"\>", 
   ",", "\<\" \"\>", ",", "\<\"c\"\>", ",", "\<\"r\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"d\"\>", ",", "\<\"i\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", 
   ",", "\<\"w\"\>", ",", "\<\"h\"\>", ",", "\<\"i\"\>", ",", "\<\"c\"\>", 
   ",", "\<\"h\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\" \"\>", 
   ",", "\<\"s\"\>", ",", "\<\"c\"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"n\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"i\"\>", ",", "\<\"g\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"b\"\>", ",", "\<\"o\"\>", ",", "\<\"u\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"h\"\>", ",", "\<\"o\"\>", ",", "\<\"o\"\>", ",", "\<\"d\"\>", 
   ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"f\"\>", ",", "\<\"f\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"r\"\>", ",", "\<\"d\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"d\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", 
   ",", "\<\"h\"\>", ",", "\<\"i\"\>", ",", "\<\"r\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"e\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", 
   ",", "\<\"s\"\>", ",", "\<\"p\"\>", ",", "\<\"r\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"g\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", 
   ",", "\<\"s\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\"w\"\>", 
   ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"i\"\>", ",", "\<\"r\"\>", ",", "\<\" \"\>", 
   ",", "\<\"b\"\>", ",", "\<\"l\"\>", ",", "\<\"o\"\>", ",", "\<\"s\"\>", 
   ",", "\<\"s\"\>", ",", "\<\"o\"\>", ",", "\<\"m\"\>", ",", "\<\"s\"\>", 
   ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"s\"\>", 
   ",", "\<\" \"\>", ",", "\<\"s\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"r\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"v\"\>", ",", "\<\"e\"\>", ",", "\<\"l\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"u\"\>", 
   ",", "\<\"p\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"o\"\>", 
   ",", "\<\" \"\>", ",", "\<\"L\"\>", ",", "\<\"o\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"d\"\>", ",", "\<\"o\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", 
   ",", "\<\"w\"\>", ",", "\<\"i\"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", 
   ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", 
   ",", "\<\" \"\>", ",", "\<\"f\"\>", ",", "\<\"a\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\",\"\>", 
   ",", "\<\" \"\>", ",", "\<\"f\"\>", ",", "\<\"o\"\>", ",", "\<\"r\"\>", 
   ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\" \"\>", ",", "\<\"f\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"w\"\>", ",", "\<\" \"\>", ",", "\<\"w\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"e\"\>", ",", "\<\"k\"\>", ",", "\<\"s\"\>", 
   ",", "\<\"'\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"u\"\>", ",", "\<\"a\"\>", ",", "\<\"l\"\>", 
   ",", "\<\" \"\>", ",", "\<\"e\"\>", ",", "\<\"n\"\>", ",", "\<\"j\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"y\"\>", ",", "\<\"m\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", 
   ",", "\<\"f\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"g\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"a\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", 
   ",", "\<\"w\"\>", ",", "\<\"o\"\>", ",", "\<\"r\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"d\"\>", ",", "\<\".\"\>", ",", "\<\" \"\>", ",", "\<\"S\"\>", 
   ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", 
   ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"r\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"m\"\>", ",", "\<\"e\"\>", ",", "\<\"m\"\>", 
   ",", "\<\"b\"\>", ",", "\<\"r\"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"c\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", 
   ",", "\<\"f\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"l\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"s\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", 
   ",", "\<\"s\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"h\"\>", ",", "\<\"a\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", 
   ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"c\"\>", ",", "\<\"o\"\>", ",", "\<\"n\"\>", ",", "\<\"s\"\>", 
   ",", "\<\"c\"\>", ",", "\<\"i\"\>", ",", "\<\"o\"\>", ",", "\<\"u\"\>", 
   ",", "\<\"s\"\>", ",", "\<\"n\"\>", ",", "\<\"e\"\>", ",", "\<\"s\"\>", 
   ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"f\"\>", 
   ",", "\<\" \"\>", ",", "\<\"b\"\>", ",", "\<\"e\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"g\"\>", ",", "\<\" \"\>", ",", "\<\"n\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\"e\"\>", ",", "\<\"-\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"d\"\>", ",", "\<\"-\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"w\"\>", ",", "\<\"e\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", 
   ",", "\<\"o\"\>", ",", "\<\" \"\>", ",", "\<\"g\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"v\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"s\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"m\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"r\"\>", ",", "\<\"e\"\>", ",", "\<\"g\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"t\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", 
   ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", 
   ",", "\<\"s\"\>", ",", "\<\"o\"\>", ",", "\<\"m\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"p\"\>", ",", "\<\"p\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"e\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"s\"\>", ",", "\<\"i\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"s\"\>", ",", "\<\";\"\>", ",", "\<\" \"\>", 
   ",", "\<\"s\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"w\"\>", ",", "\<\"a\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", 
   ",", "\<\"f\"\>", ",", "\<\"u\"\>", ",", "\<\"l\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"s\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"i\"\>", ",", "\<\"s\"\>", ",", "\<\"f\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"e\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", 
   ",", "\<\"o\"\>", ",", "\<\"f\"\>", ",", "\<\" \"\>", ",", "\<\"b\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\"g\"\>", 
   ",", "\<\" \"\>", ",", "\<\"s\"\>", ",", "\<\"t\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"l\"\>", ",", "\<\" \"\>", ",", "\<\"q\"\>", 
   ",", "\<\"u\"\>", ",", "\<\"i\"\>", ",", "\<\"t\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", 
   ",", "\<\"h\"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"d\"\>", 
   ",", "\<\"s\"\>", ",", "\<\"o\"\>", ",", "\<\"m\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", 
   ",", "\<\"e\"\>", ",", "\<\"v\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", 
   ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"b\"\>", ",", "\<\"u\"\>", 
   ",", "\<\"t\"\>", ",", "\<\" \"\>", ",", "\<\"s\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"f\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", 
   ",", "\<\"p\"\>", ",", "\<\"p\"\>", ",", "\<\"r\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"c\"\>", ",", "\<\"h\"\>", ",", "\<\" \"\>", 
   ",", "\<\"t\"\>", ",", "\<\"o\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", 
   ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"y\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"a\"\>", ",", "\<\"r\"\>", ",", "\<\"s\"\>", 
   ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"f\"\>", ",", "\<\" \"\>", 
   ",", "\<\"d\"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"g\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", 
   ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", 
   ",", "\<\"w\"\>", ",", "\<\"o\"\>", ",", "\<\"u\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"v\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"r\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"j\"\>", ",", "\<\"o\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"c\"\>", ",", "\<\"e\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", 
   ",", "\<\"t\"\>", ",", "\<\"o\"\>", ",", "\<\" \"\>", ",", "\<\"b\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"c\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"t\"\>", ",", "\<\"a\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"f\"\>", 
   ",", "\<\" \"\>", ",", "\<\"b\"\>", ",", "\<\"e\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"g\"\>", ",", "\<\" \"\>", ",", "\<\"p\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"o\"\>", ",", "\<\"p\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"l\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", 
   ",", "\<\"s\"\>", ",", "\<\"o\"\>", ",", "\<\"l\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"c\"\>", ",", "\<\"i\"\>", ",", "\<\"t\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"b\"\>", ",", "\<\"y\"\>", 
   ",", "\<\" \"\>", ",", "\<\"b\"\>", ",", "\<\"a\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"n\"\>", ",", "\<\"e\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"-\"\>", ",", "\<\"b\"\>", ",", "\<\"l\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"w\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"n\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"x\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", 
   ",", "\<\"w\"\>", ",", "\<\"e\"\>", ",", "\<\"l\"\>", ",", "\<\"v\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"m\"\>", ",", "\<\"o\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", 
   ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"w\"\>", 
   ",", "\<\"o\"\>", ",", "\<\".\"\>", ",", "\<\" \"\>", ",", "\<\"T\"\>", 
   ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", 
   ",", "\<\"m\"\>", ",", "\<\"i\"\>", ",", "\<\"g\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"t\"\>", ",", "\<\" \"\>", ",", "\<\"s\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"g\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", 
   ",", "\<\"t\"\>", ",", "\<\"a\"\>", ",", "\<\"k\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"u\"\>", ",", "\<\"p\"\>", ",", "\<\" \"\>", 
   ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"b\"\>", ",", "\<\"o\"\>", ",", "\<\"o\"\>", ",", "\<\"k\"\>", 
   ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"f\"\>", ",", "\<\" \"\>", 
   ",", "\<\"b\"\>", ",", "\<\"o\"\>", ",", "\<\"o\"\>", ",", "\<\"k\"\>", 
   ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"w\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", 
   ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"m\"\>", ",", "\<\"u\"\>", 
   ",", "\<\"c\"\>", ",", "\<\"h\"\>", ",", "\<\" \"\>", ",", "\<\"e\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"j\"\>", ",", "\<\"o\"\>", ",", "\<\"y\"\>", 
   ",", "\<\"m\"\>", ",", "\<\"e\"\>", ",", "\<\"n\"\>", ",", "\<\"t\"\>", 
   ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", 
   ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"e\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"r\"\>", ",", "\<\"l\"\>", ",", "\<\"y\"\>", 
   ",", "\<\" \"\>", ",", "\<\"y\"\>", ",", "\<\"o\"\>", ",", "\<\"u\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", 
   ",", "\<\"b\"\>", ",", "\<\"u\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", 
   ",", "\<\"n\"\>", ",", "\<\"o\"\>", ",", "\<\"w\"\>", ",", "\<\" \"\>", 
   ",", "\<\"s\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"l\"\>", ",", "\<\"i\"\>", ",", "\<\"k\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"i\"\>", ",", "\<\"t\"\>", 
   ",", "\<\" \"\>", ",", "\<\"n\"\>", ",", "\<\"o\"\>", ",", "\<\"t\"\>", 
   ",", "\<\".\"\>", ",", "\<\" \"\>", ",", "\<\"A\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"w\"\>", ",", "\<\"a\"\>", ",", "\<\"y\"\>", ",", "\<\"s\"\>", 
   ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"o\"\>", ",", "\<\" \"\>", 
   ",", "\<\"b\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"p\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"e\"\>", ",", "\<\"s\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"t\"\>", ",", "\<\"e\"\>", ",", "\<\"d\"\>", 
   ",", "\<\" \"\>", ",", "\<\"w\"\>", ",", "\<\"i\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"h\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"d\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", 
   ",", "\<\"f\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"w\"\>", 
   ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"b\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\" \"\>", 
   ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", 
   ",", "\<\"s\"\>", ",", "\<\"e\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"n\"\>", ",", "\<\"o\"\>", ",", "\<\" \"\>", ",", "\<\"m\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"r\"\>", ",", "\<\"r\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"g\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"f\"\>", ",", "\<\"o\"\>", ",", "\<\"l\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"w\"\>", ",", "\<\" \"\>", ",", "\<\"b\"\>", 
   ",", "\<\"u\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", 
   ",", "\<\"h\"\>", ",", "\<\"a\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", 
   ",", "\<\"o\"\>", ",", "\<\"f\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", 
   ",", "\<\" \"\>", ",", "\<\"y\"\>", ",", "\<\"o\"\>", ",", "\<\"u\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"g\"\>", ",", "\<\"e\"\>", ",", "\<\"s\"\>", 
   ",", "\<\"t\"\>", ",", "\<\" \"\>", ",", "\<\"s\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"s\"\>", ",", "\<\"t\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", 
   ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"m\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"d\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", 
   ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"b\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"o\"\>", ",", "\<\"k\"\>", ",", "\<\" \"\>", 
   ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"e\"\>", 
   ",", "\<\"v\"\>", ",", "\<\"i\"\>", ",", "\<\"l\"\>", ",", "\<\";\"\>", 
   ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"d\"\>", 
   ",", "\<\" \"\>", ",", "\<\"m\"\>", ",", "\<\"o\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"c\"\>", ",", "\<\"e\"\>", ",", "\<\",\"\>", 
   ",", "\<\" \"\>", ",", "\<\"w\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"f\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", 
   ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"a\"\>", ",", "\<\"d\"\>", 
   ",", "\<\" \"\>", ",", "\<\"l\"\>", ",", "\<\"e\"\>", ",", "\<\"f\"\>", 
   ",", "\<\"t\"\>", ",", "\<\" \"\>", ",", "\<\"i\"\>", ",", "\<\"t\"\>", 
   ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"p\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"n\"\>", 
   ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"a\"\>", ",", "\<\"b\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"n\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"a\"\>", ",", "\<\"r\"\>", ",", "\<\" \"\>", 
   ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\",\"\>", 
   ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"a\"\>", ",", "\<\"d\"\>", 
   ",", "\<\" \"\>", ",", "\<\"s\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"c\"\>", ",", "\<\"l\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"s\"\>", ",", "\<\"e\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", 
   ",", "\<\"i\"\>", ",", "\<\"t\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", 
   ",", "\<\"w\"\>", ",", "\<\"i\"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", 
   ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"v\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"t\"\>", ",", "\<\"e\"\>", ",", "\<\"d\"\>", 
   ",", "\<\" \"\>", ",", "\<\"e\"\>", ",", "\<\"y\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"s\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"p\"\>", 
   ",", "\<\"u\"\>", ",", "\<\"s\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"i\"\>", ",", "\<\"t\"\>", 
   ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"w\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"y\"\>", ",", "\<\".\"\>", ",", "\<\" \"\>", ",", "\<\"S\"\>", 
   ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", 
   ",", "\<\" \"\>", ",", "\<\"d\"\>", ",", "\<\"i\"\>", ",", "\<\"s\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"p\"\>", ",", "\<\"p\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\"t\"\>", ",", "\<\"m\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"n\"\>", ",", "\<\"t\"\>", ",", "\<\",\"\>", 
   ",", "\<\" \"\>", ",", "\<\"m\"\>", ",", "\<\"o\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"o\"\>", ",", "\<\"v\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"r\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"w\"\>", 
   ",", "\<\"h\"\>", ",", "\<\"i\"\>", ",", "\<\"c\"\>", ",", "\<\"h\"\>", 
   ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"t\"\>", ",", "\<\" \"\>", ",", "\<\"b\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"k\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", 
   ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", 
   ",", "\<\"e\"\>", ",", "\<\"s\"\>", ",", "\<\"p\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"c\"\>", ",", "\<\"i\"\>", ",", "\<\"a\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", 
   ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"s\"\>", ",", "\<\"t\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", 
   ",", "\<\"f\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"w\"\>", 
   ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"f\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"m\"\>", ",", "\<\"i\"\>", ",", "\<\"l\"\>", ",", "\<\"y\"\>", 
   ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"m\"\>", ",", "\<\"u\"\>", 
   ",", "\<\"s\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", ",", "\<\"e\"\>", 
   ",", "\<\"v\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\" \"\>", 
   ",", "\<\"p\"\>", ",", "\<\"r\"\>", ",", "\<\"e\"\>", ",", "\<\"s\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"n\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", 
   ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"r\"\>", ",", "\<\"e\"\>", ",", "\<\"m\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"m\"\>", ",", "\<\"b\"\>", ",", "\<\"r\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"c\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"o\"\>", ",", "\<\"f\"\>", ",", "\<\".\"\>", ",", "\<\" \"\>", 
   ",", "\<\"T\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\"i\"\>", ",", "\<\"r\"\>", 
   ",", "\<\" \"\>", ",", "\<\"p\"\>", ",", "\<\"r\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"s\"\>", ",", "\<\"u\"\>", ",", "\<\"m\"\>", ",", "\<\"p\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"i\"\>", ",", "\<\"v\"\>", ",", "\<\"e\"\>", 
   ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"v\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"W\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"l\"\>", ",", "\<\"l\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"m\"\>", ",", "\<\" \"\>", ",", "\<\"W\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"l\"\>", ",", "\<\"t\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"E\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"i\"\>", ",", "\<\"o\"\>", ",", "\<\"t\"\>", 
   ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"E\"\>", ",", "\<\"s\"\>", 
   ",", "\<\"q\"\>", ",", "\<\".\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", 
   ",", "\<\"w\"\>", ",", "\<\"h\"\>", ",", "\<\"o\"\>", ",", "\<\"s\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"r\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"g\"\>", ",", "\<\"h\"\>", ",", "\<\"t\"\>", ",", "\<\"s\"\>", 
   ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"a\"\>", ",", "\<\"d\"\>", 
   ",", "\<\" \"\>", ",", "\<\"b\"\>", ",", "\<\"e\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"s\"\>", ",", "\<\"o\"\>", 
   ",", "\<\" \"\>", ",", "\<\"g\"\>", ",", "\<\"e\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\"o\"\>", ",", "\<\"u\"\>", 
   ",", "\<\"s\"\>", ",", "\<\"l\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", 
   ",", "\<\"s\"\>", ",", "\<\"u\"\>", ",", "\<\"p\"\>", ",", "\<\"p\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"r\"\>", ",", "\<\"t\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"b\"\>", ",", "\<\"y\"\>", 
   ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", 
   ",", "\<\" \"\>", ",", "\<\"f\"\>", ",", "\<\"a\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\",\"\>", 
   ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"a\"\>", ",", "\<\"d\"\>", 
   ",", "\<\" \"\>", ",", "\<\"d\"\>", ",", "\<\"i\"\>", ",", "\<\"s\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"p\"\>", ",", "\<\"p\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\"t\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"r\"\>", ",", "\<\".\"\>", ",", "\<\" \"\>", ",", "\<\"S\"\>", 
   ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"d\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", 
   ",", "\<\"w\"\>", ",", "\<\"h\"\>", ",", "\<\"i\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\" \"\>", 
   ",", "\<\"v\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\"y\"\>", 
   ",", "\<\" \"\>", ",", "\<\"y\"\>", ",", "\<\"o\"\>", ",", "\<\"u\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"g\"\>", ",", "\<\" \"\>", ",", "\<\"g\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"r\"\>", ",", "\<\"l\"\>", ",", "\<\",\"\>", 
   ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", 
   ",", "\<\"s\"\>", ",", "\<\"o\"\>", ",", "\<\"o\"\>", ",", "\<\"n\"\>", 
   ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", 
   ",", "\<\"s\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"h\"\>", ",", "\<\"a\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", 
   ",", "\<\"k\"\>", ",", "\<\"n\"\>", ",", "\<\"o\"\>", ",", "\<\"w\"\>", 
   ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"m\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"o\"\>", 
   ",", "\<\" \"\>", ",", "\<\"b\"\>", ",", "\<\"e\"\>", ",", "\<\",\"\>", 
   ",", "\<\" \"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", 
   ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"e\"\>", ",", "\<\"v\"\>", ",", "\<\"e\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"t\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"f\"\>", 
   ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", 
   ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"a\"\>", ",", "\<\"v\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\"g\"\>", ",", "\<\" \"\>", 
   ",", "\<\"n\"\>", ",", "\<\"o\"\>", ",", "\<\" \"\>", ",", "\<\"b\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"o\"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", 
   ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"f\"\>", ",", "\<\"u\"\>", ",", "\<\"t\"\>", ",", "\<\"u\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"b\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"r\"\>", ",", "\<\"o\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"t\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", 
   ",", "\<\"m\"\>", ",", "\<\"e\"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"t\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"o\"\>", 
   ",", "\<\" \"\>", ",", "\<\"m\"\>", ",", "\<\"a\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"m\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", 
   ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", 
   ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\" \"\>", 
   ",", "\<\"f\"\>", ",", "\<\"a\"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"w\"\>", ",", "\<\"a\"\>", ",", "\<\"y\"\>", 
   ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"m\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", 
   ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"a\"\>", ",", "\<\"t\"\>", 
   ",", "\<\" \"\>", ",", "\<\"s\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"s\"\>", ",", "\<\"h\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"u\"\>", ",", "\<\"l\"\>", ",", "\<\"d\"\>", ",", "\<\".\"\>", 
   ",", "\<\" \"\>", ",", "\<\"H\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"h\"\>", ",", "\<\"a\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", 
   ",", "\<\"n\"\>", ",", "\<\"o\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", 
   ",", "\<\"b\"\>", ",", "\<\"e\"\>", ",", "\<\"e\"\>", ",", "\<\"n\"\>", 
   ",", "\<\" \"\>", ",", "\<\"k\"\>", ",", "\<\"n\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"w\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", 
   ",", "\<\"o\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"m\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", 
   ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\" \"\>", 
   ",", "\<\"b\"\>", ",", "\<\"o\"\>", ",", "\<\"y\"\>", ",", "\<\";\"\>", 
   ",", "\<\" \"\>", ",", "\<\"b\"\>", ",", "\<\"u\"\>", ",", "\<\"t\"\>", 
   ",", "\<\" \"\>", ",", "\<\"s\"\>", ",", "\<\"o\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"f\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\" \"\>", 
   ",", "\<\"L\"\>", ",", "\<\"a\"\>", ",", "\<\"d\"\>", ",", "\<\"y\"\>", 
   ",", "\<\" \"\>", ",", "\<\"E\"\>", ",", "\<\"l\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"o\"\>", ",", "\<\"t\"\>", ",", "\<\"'\"\>", 
   ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"d\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\",\"\>", 
   ",", "\<\" \"\>", ",", "\<\"S\"\>", ",", "\<\"i\"\>", ",", "\<\"r\"\>", 
   ",", "\<\" \"\>", ",", "\<\"W\"\>", ",", "\<\"a\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\" \"\>", 
   ",", "\<\"h\"\>", ",", "\<\"a\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", 
   ",", "\<\"s\"\>", ",", "\<\"o\"\>", ",", "\<\"u\"\>", ",", "\<\"g\"\>", 
   ",", "\<\"h\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", 
   ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", 
   ",", "\<\"c\"\>", ",", "\<\"q\"\>", ",", "\<\"u\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\"t\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"c\"\>", ",", "\<\"e\"\>", ",", "\<\",\"\>", 
   ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"d\"\>", 
   ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"u\"\>", ",", "\<\"g\"\>", ",", "\<\"h\"\>", ",", "\<\" \"\>", 
   ",", "\<\"h\"\>", ",", "\<\"i\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", 
   ",", "\<\"o\"\>", ",", "\<\"v\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"u\"\>", ",", "\<\"r\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"n\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"t\"\>", ",", "\<\" \"\>", ",", "\<\"b\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"m\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", ",", "\<\"w\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\" \"\>", 
   ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", 
   ",", "\<\"w\"\>", ",", "\<\"a\"\>", ",", "\<\"r\"\>", ",", "\<\"m\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", 
   ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"p\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\"s\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"v\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", 
   ",", "\<\" \"\>", ",", "\<\"s\"\>", ",", "\<\"e\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"k\"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\"g\"\>", 
   ",", "\<\" \"\>", ",", "\<\"i\"\>", ",", "\<\"t\"\>", ",", "\<\",\"\>", 
   ",", "\<\" \"\>", ",", "\<\"m\"\>", ",", "\<\"a\"\>", ",", "\<\"k\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\"g\"\>", ",", "\<\" \"\>", 
   ",", "\<\"a\"\>", ",", "\<\"l\"\>", ",", "\<\"l\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"w\"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"c\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"f\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"m\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"d\"\>", ",", "\<\"e\"\>", ",", "\<\"s\"\>", ",", "\<\"t\"\>", 
   ",", "\<\" \"\>", ",", "\<\"d\"\>", ",", "\<\"r\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"w\"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\"g\"\>", 
   ",", "\<\"-\"\>", ",", "\<\"b\"\>", ",", "\<\"a\"\>", ",", "\<\"c\"\>", 
   ",", "\<\"k\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"f\"\>", 
   ",", "\<\" \"\>", ",", "\<\"y\"\>", ",", "\<\"o\"\>", ",", "\<\"u\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\";\"\>", ",", "\<\" \"\>", 
   ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"d\"\>", ",", "\<\",\"\>", 
   ",", "\<\" \"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", 
   ",", "\<\"o\"\>", ",", "\<\"n\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"o\"\>", ",", "\<\"f\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", 
   ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\"i\"\>", ",", "\<\"r\"\>", 
   ",", "\<\" \"\>", ",", "\<\"s\"\>", ",", "\<\"p\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\"g\"\>", ",", "\<\" \"\>", 
   ",", "\<\"e\"\>", ",", "\<\"x\"\>", ",", "\<\"c\"\>", ",", "\<\"u\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"s\"\>", ",", "\<\"i\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", 
   ",", "\<\"o\"\>", ",", "\<\" \"\>", ",", "\<\"L\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"d\"\>", ",", "\<\"o\"\>", ",", "\<\"n\"\>", 
   ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"w\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"E\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"i\"\>", ",", "\<\"z\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"b\"\>", ",", "\<\"e\"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", 
   ",", "\<\" \"\>", ",", "\<\"w\"\>", ",", "\<\"a\"\>", ",", "\<\"s\"\>", 
   ",", "\<\" \"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", 
   ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\" \"\>", 
   ",", "\<\"f\"\>", ",", "\<\"i\"\>", ",", "\<\"r\"\>", ",", "\<\"s\"\>", 
   ",", "\<\"t\"\>", ",", "\<\" \"\>", ",", "\<\"b\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"o\"\>", ",", "\<\"m\"\>", ",", "\<\",\"\>", 
   ",", "\<\" \"\>", ",", "\<\"M\"\>", ",", "\<\"r\"\>", ",", "\<\" \"\>", 
   ",", "\<\"E\"\>", ",", "\<\"l\"\>", ",", "\<\"l\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"b\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"e\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", 
   ",", "\<\"f\"\>", ",", "\<\"o\"\>", ",", "\<\"r\"\>", ",", "\<\"c\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"i\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"t\"\>", ",", "\<\"o\"\>", ",", "\<\" \"\>", 
   ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\"t\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"d\"\>", ",", "\<\"u\"\>", ",", "\<\"c\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"i\"\>", ",", "\<\"o\"\>", ",", "\<\"n\"\>", 
   ",", "\<\".\"\>", ",", "\<\" \"\>", ",", "\<\"H\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"w\"\>", ",", "\<\"a\"\>", ",", "\<\"s\"\>", 
   ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", 
   ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"a\"\>", ",", "\<\"t\"\>", 
   ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"i\"\>", ",", "\<\"m\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\" \"\>", 
   ",", "\<\"v\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\"y\"\>", 
   ",", "\<\" \"\>", ",", "\<\"y\"\>", ",", "\<\"o\"\>", ",", "\<\"u\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"g\"\>", ",", "\<\" \"\>", ",", "\<\"m\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", 
   ",", "\<\"j\"\>", ",", "\<\"u\"\>", ",", "\<\"s\"\>", ",", "\<\"t\"\>", 
   ",", "\<\" \"\>", ",", "\<\"e\"\>", ",", "\<\"n\"\>", ",", "\<\"g\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"g\"\>", ",", "\<\"e\"\>", ",", "\<\"d\"\>", 
   ",", "\<\" \"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", 
   ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"s\"\>", ",", "\<\"t\"\>", ",", "\<\"u\"\>", ",", "\<\"d\"\>", 
   ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"f\"\>", 
   ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"l\"\>", ",", "\<\"a\"\>", ",", "\<\"w\"\>", 
   ",", "\<\";\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"E\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"z\"\>", ",", "\<\"a\"\>", ",", "\<\"b\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\" \"\>", 
   ",", "\<\"f\"\>", ",", "\<\"o\"\>", ",", "\<\"u\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"m\"\>", ",", "\<\" \"\>", ",", "\<\"e\"\>", ",", "\<\"x\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"r\"\>", ",", "\<\"e\"\>", ",", "\<\"m\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"l\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", 
   ",", "\<\"a\"\>", ",", "\<\"g\"\>", ",", "\<\"r\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"a\"\>", ",", "\<\"b\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"e\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"e\"\>", 
   ",", "\<\"v\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\"y\"\>", 
   ",", "\<\" \"\>", ",", "\<\"p\"\>", ",", "\<\"l\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", 
   ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"i\"\>", ",", "\<\"s\"\>", 
   ",", "\<\" \"\>", ",", "\<\"f\"\>", ",", "\<\"a\"\>", ",", "\<\"v\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"u\"\>", ",", "\<\"r\"\>", ",", "\<\" \"\>", 
   ",", "\<\"w\"\>", ",", "\<\"a\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", 
   ",", "\<\"c\"\>", ",", "\<\"o\"\>", ",", "\<\"n\"\>", ",", "\<\"f\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"r\"\>", ",", "\<\"m\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"d\"\>", ",", "\<\".\"\>", ",", "\<\" \"\>", ",", "\<\"H\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"w\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"v\"\>", ",", "\<\"i\"\>", ",", "\<\"t\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"o\"\>", 
   ",", "\<\" \"\>", ",", "\<\"K\"\>", ",", "\<\"e\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"y\"\>", ",", "\<\"n\"\>", ",", "\<\"c\"\>", 
   ",", "\<\"h\"\>", ",", "\<\" \"\>", ",", "\<\"H\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"l\"\>", ",", "\<\";\"\>", ",", "\<\" \"\>", 
   ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"w\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"l\"\>", ",", "\<\"k\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"f\"\>", 
   ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"d\"\>", 
   ",", "\<\" \"\>", ",", "\<\"e\"\>", ",", "\<\"x\"\>", ",", "\<\"p\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"c\"\>", ",", "\<\"t\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"l\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"r\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"s\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", 
   ",", "\<\"f\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"y\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"r\"\>", ",", "\<\";\"\>", ",", "\<\" \"\>", 
   ",", "\<\"b\"\>", ",", "\<\"u\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", 
   ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"n\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"v\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", 
   ",", "\<\" \"\>", ",", "\<\"c\"\>", ",", "\<\"a\"\>", ",", "\<\"m\"\>", 
   ",", "\<\"e\"\>", ",", "\<\".\"\>", ",", "\<\" \"\>", ",", "\<\"T\"\>", 
   ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"f\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"l\"\>", ",", "\<\"l\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"w\"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\"g\"\>", 
   ",", "\<\" \"\>", ",", "\<\"s\"\>", ",", "\<\"p\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\"g\"\>", ",", "\<\" \"\>", 
   ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"w\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"s\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"e\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", 
   ",", "\<\"a\"\>", ",", "\<\"g\"\>", ",", "\<\"a\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", 
   ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"o\"\>", ",", "\<\"w\"\>", 
   ",", "\<\"n\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"f\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"u\"\>", ",", "\<\"n\"\>", ",", "\<\"d\"\>", 
   ",", "\<\" \"\>", ",", "\<\"e\"\>", ",", "\<\"q\"\>", ",", "\<\"u\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"l\"\>", ",", "\<\"l\"\>", ",", "\<\"y\"\>", 
   ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"g\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"e\"\>", ",", "\<\"a\"\>", ",", "\<\"b\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"e\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", 
   ",", "\<\"a\"\>", ",", "\<\"g\"\>", ",", "\<\"a\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"e\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"c\"\>", ",", "\<\"o\"\>", ",", "\<\"u\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"g\"\>", ",", "\<\"e\"\>", ",", "\<\"d\"\>", 
   ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"v\"\>", ",", "\<\"i\"\>", ",", "\<\"t\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"d\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"e\"\>", 
   ",", "\<\"x\"\>", ",", "\<\"p\"\>", ",", "\<\"e\"\>", ",", "\<\"c\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"e\"\>", ",", "\<\"d\"\>", ",", "\<\",\"\>", 
   ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"d\"\>", 
   ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"g\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"d\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"n\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"t\"\>", ",", "\<\" \"\>", ",", "\<\"c\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"m\"\>", ",", "\<\"e\"\>", ",", "\<\";\"\>", ",", "\<\" \"\>", 
   ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", 
   ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"n\"\>", ",", "\<\"e\"\>", ",", "\<\"x\"\>", ",", "\<\"t\"\>", 
   ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"i\"\>", ",", "\<\"d\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\"g\"\>", ",", "\<\"s\"\>", 
   ",", "\<\" \"\>", ",", "\<\"w\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"w\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"m\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"r\"\>", ",", "\<\"i\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"d\"\>", ",", "\<\".\"\>", ",", "\<\" \"\>", ",", "\<\"I\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"s\"\>", ",", "\<\"t\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", 
   ",", "\<\"f\"\>", ",", "\<\" \"\>", ",", "\<\"p\"\>", ",", "\<\"u\"\>", 
   ",", "\<\"s\"\>", ",", "\<\"h\"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"g\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"f\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"t\"\>", ",", "\<\"u\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", 
   ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"l\"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"m\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"k\"\>", ",", "\<\"e\"\>", ",", "\<\"d\"\>", 
   ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"u\"\>", ",", "\<\"t\"\>", 
   ",", "\<\" \"\>", ",", "\<\"f\"\>", ",", "\<\"o\"\>", ",", "\<\"r\"\>", 
   ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"f\"\>", 
   ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"o\"\>", ",", "\<\"u\"\>", 
   ",", "\<\"s\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", 
   ",", "\<\"f\"\>", ",", "\<\" \"\>", ",", "\<\"E\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"i\"\>", ",", "\<\"o\"\>", ",", "\<\"t\"\>", 
   ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"a\"\>", ",", "\<\"d\"\>", 
   ",", "\<\" \"\>", ",", "\<\"p\"\>", ",", "\<\"u\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"c\"\>", ",", "\<\"h\"\>", ",", "\<\"a\"\>", ",", "\<\"s\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"i\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"d\"\>", ",", "\<\"e\"\>", ",", "\<\"p\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"n\"\>", ",", "\<\"d\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"c\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"b\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"u\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"i\"\>", ",", "\<\"t\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"g\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"m\"\>", ",", "\<\"s\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"f\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", 
   ",", "\<\"o\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\" \"\>", 
   ",", "\<\"r\"\>", ",", "\<\"i\"\>", ",", "\<\"c\"\>", ",", "\<\"h\"\>", 
   ",", "\<\" \"\>", ",", "\<\"w\"\>", ",", "\<\"o\"\>", ",", "\<\"m\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", 
   ",", "\<\"f\"\>", ",", "\<\" \"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"f\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"b\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"r\"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", 
   ",", "\<\".\"\>", ",", "\<\" \"\>", ",", "\<\"S\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"W\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"t\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", 
   ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"a\"\>", ",", "\<\"d\"\>", 
   ",", "\<\" \"\>", ",", "\<\"r\"\>", ",", "\<\"e\"\>", ",", "\<\"s\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"n\"\>", ",", "\<\"t\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"i\"\>", ",", "\<\"t\"\>", 
   ",", "\<\".\"\>", ",", "\<\" \"\>", ",", "\<\"A\"\>", ",", "\<\"s\"\>", 
   ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"f\"\>", 
   ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"o\"\>", ",", "\<\"u\"\>", 
   ",", "\<\"s\"\>", ",", "\<\"e\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", 
   ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"f\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"l\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", 
   ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"a\"\>", ",", "\<\"t\"\>", 
   ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"o\"\>", ",", "\<\"u\"\>", ",", "\<\"g\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"t\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"o\"\>", 
   ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"a\"\>", ",", "\<\"v\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"b\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"c\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"n\"\>", ",", "\<\"s\"\>", ",", "\<\"u\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"t\"\>", ",", "\<\"e\"\>", ",", "\<\"d\"\>", 
   ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"e\"\>", ",", "\<\"s\"\>", 
   ",", "\<\"p\"\>", ",", "\<\"e\"\>", ",", "\<\"c\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"l\"\>", ",", "\<\"l\"\>", ",", "\<\"y\"\>", 
   ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"f\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"k\"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"g\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"y\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"u\"\>", ",", "\<\"n\"\>", ",", "\<\"g\"\>", ",", "\<\" \"\>", 
   ",", "\<\"m\"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", 
   ",", "\<\"s\"\>", ",", "\<\"o\"\>", ",", "\<\" \"\>", ",", "\<\"p\"\>", 
   ",", "\<\"u\"\>", ",", "\<\"b\"\>", ",", "\<\"l\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"c\"\>", ",", "\<\"l\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", 
   ",", "\<\"b\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", 
   ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"d\"\>", ",", "\<\";\"\>", 
   ",", "\<\" \"\>", ",", "\<\"\\\"\"\>", ",", "\<\"F\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"m\"\>", 
   ",", "\<\"u\"\>", ",", "\<\"s\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", 
   ",", "\<\"h\"\>", ",", "\<\"a\"\>", ",", "\<\"v\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"b\"\>", ",", "\<\"e\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"s\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"g\"\>", ",", "\<\"e\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\",\"\>", 
   ",", "\<\"\\\"\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"b\"\>", ",", "\<\"s\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\"v\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"d\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"\\\"\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"n\"\>", ",", "\<\"c\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", 
   ",", "\<\"T\"\>", ",", "\<\"a\"\>", ",", "\<\"t\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\"s\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"l\"\>", ",", "\<\"'\"\>", ",", "\<\"s\"\>", 
   ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"w\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"c\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", 
   ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"l\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"b\"\>", ",", "\<\"b\"\>", ",", "\<\"y\"\>", 
   ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"f\"\>", ",", "\<\" \"\>", 
   ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"H\"\>", ",", "\<\"o\"\>", ",", "\<\"u\"\>", ",", "\<\"s\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"f\"\>", 
   ",", "\<\" \"\>", ",", "\<\"C\"\>", ",", "\<\"o\"\>", ",", "\<\"m\"\>", 
   ",", "\<\"m\"\>", ",", "\<\"o\"\>", ",", "\<\"n\"\>", ",", "\<\"s\"\>", 
   ",", "\<\".\"\>", ",", "\<\"\\\"\"\>", ",", "\<\" \"\>", ",", "\<\"H\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"d\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"s\"\>", ",", "\<\"a\"\>", ",", "\<\"p\"\>", 
   ",", "\<\"p\"\>", ",", "\<\"r\"\>", ",", "\<\"o\"\>", ",", "\<\"b\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"t\"\>", ",", "\<\"i\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"w\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"e\"\>", ",", "\<\"x\"\>", 
   ",", "\<\"p\"\>", ",", "\<\"r\"\>", ",", "\<\"e\"\>", ",", "\<\"s\"\>", 
   ",", "\<\"s\"\>", ",", "\<\"e\"\>", ",", "\<\"d\"\>", ",", "\<\",\"\>", 
   ",", "\<\" \"\>", ",", "\<\"b\"\>", ",", "\<\"u\"\>", ",", "\<\"t\"\>", 
   ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"p\"\>", ",", "\<\"p\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"r\"\>", ",", "\<\"e\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"l\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", 
   ",", "\<\"v\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\"y\"\>", 
   ",", "\<\" \"\>", ",", "\<\"l\"\>", ",", "\<\"i\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"l\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"r\"\>", ",", "\<\"e\"\>", ",", "\<\"g\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"d\"\>", ",", "\<\"e\"\>", ",", "\<\"d\"\>", 
   ",", "\<\".\"\>", ",", "\<\" \"\>", ",", "\<\"M\"\>", ",", "\<\"r\"\>", 
   ",", "\<\" \"\>", ",", "\<\"E\"\>", ",", "\<\"l\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"o\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", 
   ",", "\<\"h\"\>", ",", "\<\"a\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", 
   ",", "\<\"a\"\>", ",", "\<\"t\"\>", ",", "\<\"t\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"m\"\>", ",", "\<\"p\"\>", ",", "\<\"t\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"n\"\>", ",", "\<\"o\"\>", 
   ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"p\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"o\"\>", ",", "\<\"g\"\>", ",", "\<\"y\"\>", 
   ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"s\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"w\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", 
   ",", "\<\"h\"\>", ",", "\<\"i\"\>", ",", "\<\"m\"\>", ",", "\<\"s\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"l\"\>", ",", "\<\"f\"\>", ",", "\<\" \"\>", 
   ",", "\<\"a\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"u\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"s\"\>", ",", "\<\"o\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"c\"\>", ",", "\<\"i\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"u\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", 
   ",", "\<\"o\"\>", ",", "\<\"f\"\>", ",", "\<\" \"\>", ",", "\<\"b\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\"g\"\>", 
   ",", "\<\" \"\>", ",", "\<\"l\"\>", ",", "\<\"o\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"g\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\" \"\>", 
   ",", "\<\"n\"\>", ",", "\<\"o\"\>", ",", "\<\"t\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"c\"\>", ",", "\<\"e\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", 
   ",", "\<\"b\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", 
   ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"f\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"m\"\>", ",", "\<\"i\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"y\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", 
   ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"S\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"W\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"t\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", 
   ",", "\<\" \"\>", ",", "\<\"c\"\>", ",", "\<\"o\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"s\"\>", ",", "\<\"i\"\>", ",", "\<\"d\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"e\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", 
   ",", "\<\"h\"\>", ",", "\<\"i\"\>", ",", "\<\"m\"\>", ",", "\<\" \"\>", 
   ",", "\<\"u\"\>", ",", "\<\"n\"\>", ",", "\<\"w\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"y\"\>", 
   ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"f\"\>", ",", "\<\" \"\>", 
   ",", "\<\"i\"\>", ",", "\<\"t\"\>", ",", "\<\":\"\>", ",", "\<\" \"\>", 
   ",", "\<\"a\"\>", ",", "\<\"l\"\>", ",", "\<\"l\"\>", ",", "\<\" \"\>", 
   ",", "\<\"a\"\>", ",", "\<\"c\"\>", ",", "\<\"q\"\>", ",", "\<\"u\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"c\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"b\"\>", ",", "\<\"e\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"w\"\>", ",", "\<\"e\"\>", ",", "\<\"e\"\>", ",", "\<\"n\"\>", 
   ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"m\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"c\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"s\"\>", ",", "\<\"e\"\>", ",", "\<\"d\"\>", 
   ",", "\<\".\"\>", ",", "\<\" \"\>", ",", "\<\"T\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"v\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", 
   ",", "\<\"a\"\>", ",", "\<\"w\"\>", ",", "\<\"k\"\>", ",", "\<\"w\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"r\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", 
   ",", "\<\"h\"\>", ",", "\<\"i\"\>", ",", "\<\"s\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"r\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", 
   ",", "\<\"o\"\>", ",", "\<\"f\"\>", ",", "\<\" \"\>", ",", "\<\"M\"\>", 
   ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"E\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"i\"\>", ",", "\<\"o\"\>", ",", "\<\"t\"\>", 
   ",", "\<\" \"\>", ",", "\<\"w\"\>", ",", "\<\"a\"\>", ",", "\<\"s\"\>", 
   ",", "\<\" \"\>", ",", "\<\"s\"\>", ",", "\<\"t\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"l\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", 
   ",", "\<\"a\"\>", ",", "\<\"f\"\>", ",", "\<\"t\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", 
   ",", "\<\" \"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\"v\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"l\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"f\"\>", 
   ",", "\<\" \"\>", ",", "\<\"s\"\>", ",", "\<\"e\"\>", ",", "\<\"v\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\"a\"\>", ",", "\<\"l\"\>", 
   ",", "\<\" \"\>", ",", "\<\"y\"\>", ",", "\<\"e\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"s\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", 
   ",", "\<\"f\"\>", ",", "\<\"e\"\>", ",", "\<\"l\"\>", ",", "\<\"t\"\>", 
   ",", "\<\" \"\>", ",", "\<\"w\"\>", ",", "\<\"i\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"h\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"g\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\" \"\>", 
   ",", "\<\"b\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"E\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"i\"\>", ",", "\<\"z\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"b\"\>", ",", "\<\"e\"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", 
   ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"w\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"o\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"l\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"k\"\>", ",", "\<\"e\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", 
   ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"m\"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", 
   ",", "\<\"f\"\>", ",", "\<\"o\"\>", ",", "\<\"r\"\>", ",", "\<\" \"\>", 
   ",", "\<\"h\"\>", ",", "\<\"i\"\>", ",", "\<\"m\"\>", ",", "\<\"s\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"l\"\>", ",", "\<\"f\"\>", ",", "\<\",\"\>", 
   ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"d\"\>", 
   ",", "\<\" \"\>", ",", "\<\"s\"\>", ",", "\<\"t\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"l\"\>", ",", "\<\" \"\>", ",", "\<\"m\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"r\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"f\"\>", ",", "\<\"o\"\>", ",", "\<\"r\"\>", ",", "\<\" \"\>", 
   ",", "\<\"b\"\>", ",", "\<\"e\"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"g\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"f\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"'\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"i\"\>", ",", "\<\"r\"\>", ",", "\<\",\"\>", 
   ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"d\"\>", 
   ",", "\<\" \"\>", ",", "\<\"w\"\>", ",", "\<\"h\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"s\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"s\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"r\"\>", ",", "\<\"o\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"g\"\>", ",", "\<\" \"\>", ",", "\<\"f\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"m\"\>", ",", "\<\"i\"\>", ",", "\<\"l\"\>", ",", "\<\"y\"\>", 
   ",", "\<\" \"\>", ",", "\<\"p\"\>", ",", "\<\"r\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"d\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"c\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"u\"\>", ",", "\<\"l\"\>", ",", "\<\"d\"\>", 
   ",", "\<\" \"\>", ",", "\<\"s\"\>", ",", "\<\"e\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"n\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", 
   ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"i\"\>", ",", "\<\"m\"\>", 
   ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\" \"\>", ",", "\<\"p\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"o\"\>", ",", "\<\"p\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"m\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"c\"\>", ",", "\<\"h\"\>", ",", "\<\" \"\>", 
   ",", "\<\"f\"\>", ",", "\<\"o\"\>", ",", "\<\"r\"\>", ",", "\<\" \"\>", 
   ",", "\<\"S\"\>", ",", "\<\"i\"\>", ",", "\<\"r\"\>", ",", "\<\" \"\>", 
   ",", "\<\"W\"\>", ",", "\<\"a\"\>", ",", "\<\"l\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"E\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"l\"\>", ",", "\<\"i\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"'\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", 
   ",", "\<\"e\"\>", ",", "\<\"l\"\>", ",", "\<\"d\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"s\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", ",", "\<\"d\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"u\"\>", ",", "\<\"g\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\".\"\>", 
   ",", "\<\" \"\>", ",", "\<\"T\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"w\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"n\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", 
   ",", "\<\" \"\>", ",", "\<\"b\"\>", ",", "\<\"a\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"n\"\>", ",", "\<\"e\"\>", ",", "\<\"t\"\>", 
   ",", "\<\" \"\>", ",", "\<\"f\"\>", ",", "\<\"r\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"m\"\>", ",", "\<\" \"\>", ",", "\<\"A\"\>", ",", "\<\" \"\>", 
   ",", "\<\"t\"\>", ",", "\<\"o\"\>", ",", "\<\" \"\>", ",", "\<\"Z\"\>", 
   ",", "\<\" \"\>", ",", "\<\"w\"\>", ",", "\<\"h\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"m\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"f\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"l\"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"g\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"c\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"u\"\>", ",", "\<\"l\"\>", ",", "\<\"d\"\>", 
   ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"a\"\>", ",", "\<\"v\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"s\"\>", ",", "\<\"o\"\>", 
   ",", "\<\" \"\>", ",", "\<\"w\"\>", ",", "\<\"i\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\"g\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", 
   ",", "\<\"c\"\>", ",", "\<\"k\"\>", ",", "\<\"n\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"w\"\>", ",", "\<\"l\"\>", ",", "\<\"e\"\>", ",", "\<\"d\"\>", 
   ",", "\<\"g\"\>", ",", "\<\"e\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", 
   ",", "\<\"a\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", 
   ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"e\"\>", ",", "\<\"q\"\>", 
   ",", "\<\"u\"\>", ",", "\<\"a\"\>", ",", "\<\"l\"\>", ",", "\<\".\"\>", 
   ",", "\<\" \"\>", ",", "\<\"Y\"\>", ",", "\<\"e\"\>", ",", "\<\"t\"\>", 
   ",", "\<\" \"\>", ",", "\<\"s\"\>", ",", "\<\"o\"\>", ",", "\<\" \"\>", 
   ",", "\<\"m\"\>", ",", "\<\"i\"\>", ",", "\<\"s\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"a\"\>", ",", "\<\"b\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"c\"\>", ",", "\<\"o\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"d\"\>", ",", "\<\"u\"\>", ",", "\<\"c\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"m\"\>", ",", "\<\"s\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"f\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", 
   ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"a\"\>", ",", "\<\"t\"\>", 
   ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"u\"\>", ",", "\<\"g\"\>", ",", "\<\"h\"\>", ",", "\<\" \"\>", 
   ",", "\<\"s\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"w\"\>", ",", "\<\"a\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", 
   ",", "\<\"a\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", 
   ",", "\<\"h\"\>", ",", "\<\"i\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", 
   ",", "\<\"p\"\>", ",", "\<\"r\"\>", ",", "\<\"e\"\>", ",", "\<\"s\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"n\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", 
   ",", "\<\"t\"\>", ",", "\<\"i\"\>", ",", "\<\"m\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"(\"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"s\"\>", ",", "\<\"u\"\>", 
   ",", "\<\"m\"\>", ",", "\<\"m\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", 
   ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"f\"\>", ",", "\<\" \"\>", 
   ",", "\<\"1\"\>", ",", "\<\"8\"\>", ",", "\<\"1\"\>", ",", "\<\"4\"\>", 
   ",", "\<\")\"\>", ",", "\<\" \"\>", ",", "\<\"w\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"r\"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"g\"\>", ",", "\<\" \"\>", ",", "\<\"b\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"c\"\>", ",", "\<\"k\"\>", ",", "\<\" \"\>", 
   ",", "\<\"r\"\>", ",", "\<\"i\"\>", ",", "\<\"b\"\>", ",", "\<\"b\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"n\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", 
   ",", "\<\"f\"\>", ",", "\<\"o\"\>", ",", "\<\"r\"\>", ",", "\<\" \"\>", 
   ",", "\<\"h\"\>", ",", "\<\"i\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", 
   ",", "\<\"w\"\>", ",", "\<\"i\"\>", ",", "\<\"f\"\>", ",", "\<\"e\"\>", 
   ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"s\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"c\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"u\"\>", ",", "\<\"l\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", 
   ",", "\<\"n\"\>", ",", "\<\"o\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", 
   ",", "\<\"a\"\>", ",", "\<\"d\"\>", ",", "\<\"m\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"t\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"m\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"o\"\>", 
   ",", "\<\" \"\>", ",", "\<\"b\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"w\"\>", ",", "\<\"o\"\>", ",", "\<\"r\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"h\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\"k\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"g\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", 
   ",", "\<\"f\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"g\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\".\"\>", 
   ",", "\<\" \"\>", ",", "\<\"T\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"d\"\>", ",", "\<\"i\"\>", ",", "\<\"s\"\>", 
   ",", "\<\"g\"\>", ",", "\<\"r\"\>", ",", "\<\"a\"\>", ",", "\<\"c\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"f\"\>", 
   ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"i\"\>", ",", "\<\"s\"\>", 
   ",", "\<\" \"\>", ",", "\<\"f\"\>", ",", "\<\"i\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"s\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", ",", "\<\"m\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"r\"\>", ",", "\<\"r\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"g\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"m\"\>", ",", "\<\"i\"\>", ",", "\<\"g\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"t\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"p\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\"h\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"p\"\>", ",", "\<\"s\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", 
   ",", "\<\"a\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", 
   ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"w\"\>", ",", "\<\"a\"\>", ",", "\<\"s\"\>", 
   ",", "\<\" \"\>", ",", "\<\"n\"\>", ",", "\<\"o\"\>", ",", "\<\" \"\>", 
   ",", "\<\"r\"\>", ",", "\<\"e\"\>", ",", "\<\"a\"\>", ",", "\<\"s\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", 
   ",", "\<\"o\"\>", ",", "\<\" \"\>", ",", "\<\"s\"\>", ",", "\<\"u\"\>", 
   ",", "\<\"p\"\>", ",", "\<\"p\"\>", ",", "\<\"o\"\>", ",", "\<\"s\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"i\"\>", ",", "\<\"t\"\>", 
   ",", "\<\" \"\>", ",", "\<\"p\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", 
   ",", "\<\"p\"\>", ",", "\<\"e\"\>", ",", "\<\"t\"\>", ",", "\<\"u\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"t\"\>", ",", "\<\"e\"\>", ",", "\<\"d\"\>", 
   ",", "\<\" \"\>", ",", "\<\"b\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", 
   ",", "\<\"o\"\>", ",", "\<\"f\"\>", ",", "\<\"f\"\>", ",", "\<\"s\"\>", 
   ",", "\<\"p\"\>", ",", "\<\"r\"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"g\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"v\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"b\"\>", ",", "\<\"e\"\>", ",", "\<\"e\"\>", ",", "\<\"n\"\>", 
   ",", "\<\" \"\>", ",", "\<\"g\"\>", ",", "\<\"o\"\>", ",", "\<\"t\"\>", 
   ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"v\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"r\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"n\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"t\"\>", ",", "\<\" \"\>", ",", "\<\"d\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"w\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"r\"\>", ",", "\<\"s\"\>", ",", "\<\"e\"\>", 
   ",", "\<\";\"\>", ",", "\<\" \"\>", ",", "\<\"b\"\>", ",", "\<\"u\"\>", 
   ",", "\<\"t\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"a\"\>", ",", "\<\"d\"\>", 
   ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"s\"\>", 
   ",", "\<\" \"\>", ",", "\<\"b\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", 
   ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"a\"\>", ",", "\<\"c\"\>", ",", "\<\"c\"\>", ",", "\<\"u\"\>", 
   ",", "\<\"s\"\>", ",", "\<\"t\"\>", ",", "\<\"o\"\>", ",", "\<\"m\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"r\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", 
   ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\"t\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"v\"\>", ",", "\<\"e\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"t\"\>", ",", "\<\"i\"\>", ",", "\<\"o\"\>", ",", "\<\"n\"\>", 
   ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"f\"\>", ",", "\<\" \"\>", 
   ",", "\<\"k\"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\"d\"\>", 
   ",", "\<\" \"\>", ",", "\<\"f\"\>", ",", "\<\"r\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"n\"\>", ",", "\<\"d\"\>", ",", "\<\"s\"\>", 
   ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"h\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", ",", "\<\"b\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"e\"\>", ",", "\<\"n\"\>", ",", "\<\" \"\>", 
   ",", "\<\"i\"\>", ",", "\<\"n\"\>", ",", "\<\"f\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"m\"\>", ",", "\<\"e\"\>", ",", "\<\"d\"\>", 
   ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"s\"\>", ",", "\<\"p\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"k\"\>", ",", "\<\"e\"\>", ",", "\<\"n\"\>", 
   ",", "\<\" \"\>", ",", "\<\"m\"\>", ",", "\<\"o\"\>", ",", "\<\"s\"\>", 
   ",", "\<\"t\"\>", ",", "\<\" \"\>", ",", "\<\"d\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"s\"\>", ",", "\<\"r\"\>", ",", "\<\"e\"\>", ",", "\<\"s\"\>", 
   ",", "\<\"p\"\>", ",", "\<\"e\"\>", ",", "\<\"c\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"f\"\>", ",", "\<\"u\"\>", ",", "\<\"l\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", ",", "\<\"f\"\>", 
   ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"m\"\>", ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"l\"\>", ",", "\<\",\"\>", ",", "\<\" \"\>", ",", "\<\"m\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"s\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", 
   ",", "\<\"s\"\>", ",", "\<\"l\"\>", ",", "\<\"i\"\>", ",", "\<\"g\"\>", 
   ",", "\<\"h\"\>", ",", "\<\"t\"\>", ",", "\<\"i\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"g\"\>", ",", "\<\"l\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", 
   ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", 
   ",", "\<\"c\"\>", ",", "\<\"o\"\>", ",", "\<\"n\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"m\"\>", ",", "\<\"p\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"u\"\>", ",", "\<\"o\"\>", ",", "\<\"u\"\>", ",", "\<\"s\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"o\"\>", 
   ",", "\<\"f\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"v\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"r\"\>", ",", "\<\"y\"\>", ",", "\<\" \"\>", ",", "\<\"b\"\>", 
   ",", "\<\"l\"\>", ",", "\<\"o\"\>", ",", "\<\"o\"\>", ",", "\<\"d\"\>", 
   ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"b\"\>", ",", "\<\"e\"\>", ",", "\<\"l\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"g\"\>", ",", "\<\"e\"\>", ",", "\<\"d\"\>", 
   ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"o\"\>", ",", "\<\",\"\>", 
   ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\"n\"\>", ",", "\<\"d\"\>", 
   ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"h\"\>", ",", "\<\"e\"\>", 
   ",", "\<\" \"\>", ",", "\<\"h\"\>", ",", "\<\"o\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"u\"\>", ",", "\<\"r\"\>", ",", "\<\"s\"\>", 
   ",", "\<\" \"\>", ",", "\<\"w\"\>", ",", "\<\"h\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"c\"\>", ",", "\<\"h\"\>", ",", "\<\" \"\>", ",", "\<\"w\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"h\"\>", ",", "\<\"e\"\>", ",", "\<\"r\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"f\"\>", ",", "\<\"t\"\>", ",", "\<\"e\"\>", 
   ",", "\<\"r\"\>", ",", "\<\" \"\>", ",", "\<\"t\"\>", ",", "\<\"o\"\>", 
   ",", "\<\" \"\>", ",", "\<\"b\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", 
   ",", "\<\"h\"\>", ",", "\<\"i\"\>", ",", "\<\"s\"\>", ",", "\<\" \"\>", 
   ",", "\<\"o\"\>", ",", "\<\"w\"\>", ",", "\<\"n\"\>", ",", "\<\".\"\>", 
   ",", "\<\" \"\>", ",", "\<\"T\"\>", ",", "\<\"h\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"s\"\>", ",", "\<\" \"\>", ",", "\<\"c\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"u\"\>", ",", "\<\"l\"\>", ",", "\<\"d\"\>", ",", "\<\" \"\>", 
   ",", "\<\"n\"\>", ",", "\<\"o\"\>", ",", "\<\"t\"\>", ",", "\<\" \"\>", 
   ",", "\<\"b\"\>", ",", "\<\"e\"\>", ",", "\<\" \"\>", ",", "\<\"p\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"r\"\>", ",", "\<\"d\"\>", ",", "\<\"o\"\>", 
   ",", "\<\"n\"\>", ",", "\<\"e\"\>", ",", "\<\"d\"\>", ",", "\<\".\"\>"}], 
  "]"}]], "Output",
 CellChangeTimes->{{3.781249689390984*^9, 3.781249709913043*^9}, 
   3.782308630364532*^9},
 CellLabel->
  "Out[195]=",ExpressionUUID->"f6c48cf3-7839-487f-bf4b-34fbdda35ea4"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ASCII Encoding", "Subsection",
 CellChangeTimes->{{3.781250923743353*^9, 3.781250927220389*^9}, 
   3.781251014473727*^9},ExpressionUUID->"f7f255d1-6fe3-40c6-a3d0-\
2df12765de91"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"8", "*", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Characters", "[", "Austen", "]"}], "//", "Length"}], ")"}]}], 
   ",", 
   RowBox[{"AustenHuffmanEncoded", "//", "Length"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.777188249763895*^9, 3.7771882591690493`*^9}, {
  3.7771884385181007`*^9, 3.7771884440712357`*^9}, {3.777188498263218*^9, 
  3.7771884999907217`*^9}},
 CellLabel->
  "In[196]:=",ExpressionUUID->"b01f43d8-0263-4457-93ca-08bf970421e4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"8", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{
  3.777188255914494*^9, 3.777188444460505*^9, {3.777188475974008*^9, 
   3.777188500254863*^9}, 3.7783489179254093`*^9, 3.778504468745143*^9, 
   3.778865595123921*^9, 3.779631172840444*^9, 3.779690587245986*^9, 
   3.779691050869719*^9, {3.779691317474366*^9, 3.779691340978634*^9}, 
   3.779691460222003*^9, 3.780157593451477*^9, 3.780215626933712*^9, 
   3.7802301872202473`*^9, {3.780230289803555*^9, 3.780230313970612*^9}, 
   3.780230344145454*^9, 3.7802307024850483`*^9, 3.780414298174045*^9, 
   3.7805820156517878`*^9, 3.780894788910037*^9, 3.781245309912066*^9, 
   3.781249658627002*^9, 3.782308630755685*^9},
 CellLabel->
  "Out[196]=",ExpressionUUID->"813c28b8-78e4-4e84-9e53-62136278a2c1"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"CharacterToASCII", "[", "c_", "]"}], ":=", 
  RowBox[{"ToBinary", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"ToCharacterCode", "[", "c", "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], ",", "8"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.749807802414331*^9, 3.749807868837906*^9}, {
  3.749807950469593*^9, 3.749807951481634*^9}, {3.781249891805418*^9, 
  3.781249895761973*^9}},
 CellLabel->
  "In[197]:=",ExpressionUUID->"b89248d6-ad4b-4475-b3e4-3cd96d1cce43"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"c", ",", 
      RowBox[{
       RowBox[{"ToCharacterCode", "[", "c", "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}], ",", 
      RowBox[{"CharacterToASCII", "[", "c", "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"c", ",", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "\"\< \>\"", ",", "\"\<.\>\"", ",", "\"\<,\>\"", ",", "\"\<;\>\""}], 
        "}"}], "~", "Join", "~", 
       RowBox[{"CharacterRange", "[", 
        RowBox[{"\"\<A\>\"", ",", "\"\<E\>\""}], "]"}], "~", "Join", "~", 
       RowBox[{"CharacterRange", "[", 
        RowBox[{"\"\<a\>\"", ",", "\"\<e\>\""}], "]"}], "~", "Join", "~", 
       RowBox[{"{", "\"\<p,z\>\"", "}"}]}]}], "}"}]}], "]"}], "//", 
  "TF"}]], "Input",
 CellChangeTimes->{{3.749807815619893*^9, 3.749807839174074*^9}, {
  3.749807885822249*^9, 3.749807889588352*^9}, {3.7498079546107616`*^9, 
  3.749807955630142*^9}, {3.750248247050068*^9, 3.750248348631024*^9}, {
  3.75024854433115*^9, 3.750248549213098*^9}, {3.751041997525556*^9, 
  3.7510420154519367`*^9}, {3.751043040817678*^9, 3.75104304104712*^9}, {
  3.751286769722312*^9, 3.751286769845872*^9}, {3.751452144359498*^9, 
  3.751452144439777*^9}},
 CellLabel->
  "In[198]:=",ExpressionUUID->"6dc2969e-b417-4f1e-98e0-3446ad410521"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\" \"\>", "32", 
     RowBox[{"ToBinary", "[", 
      RowBox[{"32", ",", "8"}], "]"}]},
    {"\<\".\"\>", "46", 
     RowBox[{"ToBinary", "[", 
      RowBox[{"46", ",", "8"}], "]"}]},
    {"\<\",\"\>", "44", 
     RowBox[{"ToBinary", "[", 
      RowBox[{"44", ",", "8"}], "]"}]},
    {"\<\";\"\>", "59", 
     RowBox[{"ToBinary", "[", 
      RowBox[{"59", ",", "8"}], "]"}]},
    {"\<\"A\"\>", "65", 
     RowBox[{"ToBinary", "[", 
      RowBox[{"65", ",", "8"}], "]"}]},
    {"\<\"B\"\>", "66", 
     RowBox[{"ToBinary", "[", 
      RowBox[{"66", ",", "8"}], "]"}]},
    {"\<\"C\"\>", "67", 
     RowBox[{"ToBinary", "[", 
      RowBox[{"67", ",", "8"}], "]"}]},
    {"\<\"D\"\>", "68", 
     RowBox[{"ToBinary", "[", 
      RowBox[{"68", ",", "8"}], "]"}]},
    {"\<\"E\"\>", "69", 
     RowBox[{"ToBinary", "[", 
      RowBox[{"69", ",", "8"}], "]"}]},
    {"\<\"a\"\>", "97", 
     RowBox[{"ToBinary", "[", 
      RowBox[{"97", ",", "8"}], "]"}]},
    {"\<\"b\"\>", "98", 
     RowBox[{"ToBinary", "[", 
      RowBox[{"98", ",", "8"}], "]"}]},
    {"\<\"c\"\>", "99", 
     RowBox[{"ToBinary", "[", 
      RowBox[{"99", ",", "8"}], "]"}]},
    {"\<\"d\"\>", "100", 
     RowBox[{"ToBinary", "[", 
      RowBox[{"100", ",", "8"}], "]"}]},
    {"\<\"e\"\>", "101", 
     RowBox[{"ToBinary", "[", 
      RowBox[{"101", ",", "8"}], "]"}]},
    {"\<\"p,z\"\>", "112", 
     RowBox[{"ToBinary", "[", 
      RowBox[{"112", ",", "8"}], "]"}]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$, TableDepth -> 2]]]], "Output",
 CellChangeTimes->{{3.750248304193478*^9, 3.750248317963942*^9}, 
   3.750248349411231*^9, 3.7502485545108433`*^9, 3.7503431505868187`*^9, 
   3.7507717079933643`*^9, {3.751042003148902*^9, 3.751042016117793*^9}, 
   3.7510430414438868`*^9, 3.7512713249735823`*^9, 3.7512867709084873`*^9, 
   3.751312605873796*^9, 3.751312660885002*^9, 3.751452128686022*^9, 
   3.751452187996818*^9, {3.751466075660329*^9, 3.75146613153771*^9}, 
   3.7516537640972643`*^9, 3.751654254877557*^9, 3.751794578895362*^9, 
   3.7523322723418694`*^9, 3.752339863055532*^9, 3.7523909118146677`*^9, 
   3.75251374641444*^9, 3.752513874779766*^9, 3.752513920328043*^9, 
   3.752596478748136*^9, 3.7528410188935328`*^9, 3.7528410648887997`*^9, 
   3.75284591186028*^9, 3.7528460200040817`*^9, 3.7532674244324703`*^9, 
   3.765797181638154*^9, 3.765797402886538*^9, 3.765809520742044*^9, 
   3.7756379064980907`*^9, 3.775663901400074*^9, 3.7757194937281322`*^9, 
   3.775720123654985*^9, 3.7757236029981537`*^9, 3.775723654602469*^9, 
   3.775723687306319*^9, 3.775723804365856*^9, 3.7757238873670197`*^9, 
   3.7758943672794037`*^9, 3.775907532846304*^9, 3.7770296903876963`*^9, 
   3.7771883270670233`*^9, 3.77756762131124*^9, 3.777568130415147*^9, 
   3.777568278903248*^9, 3.7776204228196907`*^9, 3.781096116418872*^9, 
   3.781249902083722*^9, 3.7823086308303623`*^9},
 CellLabel->
  "Out[198]//TableForm=",ExpressionUUID->"3cad125e-d599-4c4c-9ba7-\
7651e7991502"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"StringToASCIIBytes", "[", "str_", "]"}], ":=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"CharacterToASCII", "[", 
     RowBox[{"StringTake", "[", 
      RowBox[{"str", ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "j"}], "}"}]}], "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "1", ",", 
      RowBox[{"StringLength", "[", "str", "]"}]}], "}"}]}], "]"}]}]], "Input",\

 CellChangeTimes->{{3.749807975852521*^9, 3.74980804004381*^9}, {
  3.7502485083245287`*^9, 3.750248508671074*^9}, {3.750340432897299*^9, 
  3.750340433750786*^9}, {3.750340568547821*^9, 3.750340589994907*^9}},
 CellLabel->
  "In[199]:=",ExpressionUUID->"a6ec28a8-660c-4dc0-b6f8-077b9d2d3e38"],

Cell[BoxData[
 RowBox[{
  RowBox[{"StringToASCIIBits", "[", "str_", "]"}], ":=", 
  RowBox[{"Join", "@@", 
   RowBox[{"StringToASCIIBytes", "[", "str", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.7503409422009*^9, 3.7503409549375877`*^9}, {
  3.750341013817608*^9, 3.7503410368568373`*^9}},
 CellLabel->
  "In[200]:=",ExpressionUUID->"d49c62ea-2791-43a1-b058-5363acb3a0ea"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AustenExtendedASCIIEncoded", "=", 
  RowBox[{"StringToASCIIBits", "[", "AustenExtended", "]"}]}]], "Input",
 CellChangeTimes->{{3.7812499588684196`*^9, 3.781249969262905*^9}, {
  3.781250930498665*^9, 3.781250933841216*^9}},
 CellLabel->
  "In[201]:=",ExpressionUUID->"e8dca939-1b29-4991-97ca-c3fffd9ee4ed"],

Cell[BoxData[
 InterpretationBox[
  TagBox[
   FrameBox[GridBox[{
      {
       ItemBox[
        TagBox[
         RowBox[{"ToBinary", "[", 
          RowBox[{
          "83", ",", "8", ",", "105", ",", "8", ",", "114", ",", "8", ",", 
           "32", ",", "8", ",", "87", ",", "8", ",", "97", ",", "8", ",", 
           "108", ",", "8", ",", "116", ",", "8", ",", "101", ",", "8", ",", 
           "114", ",", "8", ",", "32", ",", "8", ",", "69", ",", "8", ",", 
           "108", ",", "8", ",", "108", ",", "8", ",", "105", ",", "8", ",", 
           "111", ",", "8", ",", "116", ",", "8", ",", "44", ",", "8", ",", 
           "32", ",", "8", ",", "111", ",", "8", ",", "102", ",", "8", ",", 
           "32", ",", "8", ",", "75", ",", "8", ",", "101", ",", "8", ",", 
           "108", ",", "8", ",", "108", ",", "8", ",", "121", ",", "8", ",", 
           TemplateBox[{"23668"},
            "OutputSizeLimit`Skeleton"], ",", "84", ",", "8", ",", "104", ",",
            "8", ",", "105", ",", "8", ",", "115", ",", "8", ",", "32", ",", 
           "8", ",", "99", ",", "8", ",", "111", ",", "8", ",", "117", ",", 
           "8", ",", "108", ",", "8", ",", "100", ",", "8", ",", "32", ",", 
           "8", ",", "110", ",", "8", ",", "111", ",", "8", ",", "116", ",", 
           "8", ",", "32", ",", "8", ",", "98", ",", "8", ",", "101", ",", 
           "8", ",", "32", ",", "8", ",", "112", ",", "8", ",", "97", ",", 
           "8", ",", "114", ",", "8", ",", "100", ",", "8", ",", "111", ",", 
           "8", ",", "110", ",", "8", ",", "101", ",", "8", ",", "100", ",", 
           "8", ",", "46", ",", "8"}], "]"}],
         Short[#, 5]& ],
        BaseStyle->{Deployed -> False},
        StripOnInput->False]},
      {GridBox[{
         {
          TagBox[
           TooltipBox[
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource[
                "FEStrings", "sizeBriefExplanation"], StandardForm],
               ImageSizeCache->{58., {2., 8.}}],
              StripOnInput->False,
              DynamicUpdating->True], "OSLText",
             StripOnInput->False],
            StyleBox[
             DynamicBox[
              ToBoxes[
               FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
               StandardForm]], DynamicUpdating -> True, StripOnInput -> 
             False]],
           Annotation[#, 
            Style[
             Dynamic[
              FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"]], 
             DynamicUpdating -> True], "Tooltip"]& ], 
          ButtonBox[
           PaneSelectorBox[{False->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
                StandardForm],
               ImageSizeCache->{50., {0., 8.}}],
              StripOnInput->False,
              DynamicUpdating->True], "OSLControl",
             StripOnInput->False], True->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
                StandardForm],
               ImageSizeCache->{50., {0., 8.}}],
              StripOnInput->False,
              DynamicUpdating->True], "OSLControlActive",
             StripOnInput->False]}, Dynamic[
             CurrentValue["MouseOver"]],
            Alignment->Center,
            FrameMargins->0,
            ImageSize->{Automatic, 25}],
           Appearance->None,
           BaselinePosition->Baseline,
           
           ButtonFunction:>OutputSizeLimit`ButtonFunction[
            OutputSizeLimit`Defer, 201, 28836946431688567634, 5/2],
           Enabled->True,
           Evaluator->Automatic,
           Method->"Queued"], 
          ButtonBox[
           PaneSelectorBox[{False->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
                StandardForm],
               ImageSizeCache->{56., {0., 8.}}],
              StripOnInput->False,
              DynamicUpdating->True], "OSLControl",
             StripOnInput->False], True->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
                StandardForm],
               ImageSizeCache->{56., {0., 8.}}],
              StripOnInput->False,
              DynamicUpdating->True], "OSLControlActive",
             StripOnInput->False]}, Dynamic[
             CurrentValue["MouseOver"]],
            Alignment->Center,
            FrameMargins->0,
            ImageSize->{Automatic, 25}],
           Appearance->None,
           BaselinePosition->Baseline,
           
           ButtonFunction:>OutputSizeLimit`ButtonFunction[
            OutputSizeLimit`Defer, 201, 28836946431688567634, 5 2],
           Enabled->True,
           Evaluator->Automatic,
           Method->"Queued"], 
          ButtonBox[
           PaneSelectorBox[{False->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
                StandardForm],
               ImageSizeCache->{42., {0., 8.}}],
              StripOnInput->False,
              DynamicUpdating->True], "OSLControl",
             StripOnInput->False], True->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
                StandardForm]],
              StripOnInput->False,
              DynamicUpdating->True], "OSLControlActive",
             StripOnInput->False]}, Dynamic[
             CurrentValue["MouseOver"]],
            Alignment->Center,
            FrameMargins->0,
            ImageSize->{Automatic, 25}],
           Appearance->None,
           BaselinePosition->Baseline,
           
           ButtonFunction:>OutputSizeLimit`ButtonFunction[
            OutputSizeLimit`Defer, 201, 28836946431688567634, Infinity],
           Enabled->True,
           Evaluator->Automatic,
           Method->"Queued"], 
          ButtonBox[
           PaneSelectorBox[{False->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
                StandardForm],
               ImageSizeCache->{74., {0., 8.}}],
              StripOnInput->False,
              DynamicUpdating->True], "OSLControl",
             StripOnInput->False], True->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
                StandardForm]],
              StripOnInput->False,
              DynamicUpdating->True], "OSLControlActive",
             StripOnInput->False]}, Dynamic[
             CurrentValue["MouseOver"]],
            Alignment->Center,
            FrameMargins->0,
            ImageSize->{Automatic, 25}],
           Appearance->None,
           BaselinePosition->Baseline,
           ButtonFunction:>FrontEndExecute[{
              FrontEnd`SetOptions[
              FrontEnd`$FrontEnd, 
               FrontEnd`PreferencesSettings -> {"Page" -> "Advanced"}], 
              FrontEnd`FrontEndToken["PreferencesDialog"]}],
           Evaluator->None,
           Method->"Preemptive"]}
        },
        AutoDelete->False,
        FrameStyle->GrayLevel[0.85],
        GridBoxDividers->{"Columns" -> {False, {True}}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{"Columns" -> {{2}}}]}
     },
     DefaultBaseStyle->"Column",
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
       "RowsIndexed" -> {}},
     GridBoxItemSize->{
      "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], 
         Offset[1.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    BaseStyle->"OutputSizeLimit",
    FrameMargins->{{12, 12}, {0, 15}},
    FrameStyle->GrayLevel[0.85],
    RoundingRadius->5,
    StripOnInput->False],
   Deploy,
   DefaultBaseStyle->"Deploy"],
  If[28836946431688567634 === $SessionID, 
   Out[201], Message[
     MessageName[Syntax, "noinfoker"]]; Missing["NotAvailable"]; 
   Null]]], "Output",
 CellChangeTimes->{3.781249971441236*^9, 3.781250934460722*^9, 
  3.782308630966762*^9},
 CellLabel->
  "Out[201]=",ExpressionUUID->"fe857b48-7d37-48d7-bea4-8c516671d661"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Comparison", "Subsection",
 CellChangeTimes->{{3.781251017650312*^9, 
  3.78125101862999*^9}},ExpressionUUID->"c934d26f-0419-48a1-85c1-\
09a3d85dff64"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"m", ",", 
      RowBox[{"SubwordFrequencies", "[", 
       RowBox[{"AustenExtendedHuffmanEncoded", ",", "m"}], "]"}]}], "}"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"m", ",", "1", ",", "6"}], "}"}]}], "]"}], "//", "TF"}]], "Input",\

 CellChangeTimes->{{3.7812490369333763`*^9, 3.781249089508657*^9}, {
  3.7812497253503513`*^9, 3.781249726614491*^9}},
 CellLabel->
  "In[202]:=",ExpressionUUID->"0bd93a3e-956f-4291-ac3a-60e21e0adea2"],

Cell[BoxData[
 InterpretationBox[
  TagBox[
   FrameBox[GridBox[{
      {
       ItemBox[
        TagBox[
         TagBox[
          TemplateBox[{"1"},
           "OutputSizeLimit`Skeleton"],
          Function[BoxForm`e$, 
           TableForm[BoxForm`e$, TableDepth -> 2]]],
         Short[#, 5]& ],
        BaseStyle->{Deployed -> False},
        StripOnInput->False]},
      {GridBox[{
         {
          TagBox[
           TooltipBox[
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource[
                "FEStrings", "sizeBriefExplanation"], StandardForm],
               ImageSizeCache->{58., {2., 8.}}],
              StripOnInput->False,
              DynamicUpdating->True], "OSLText",
             StripOnInput->False],
            StyleBox[
             DynamicBox[
              ToBoxes[
               FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
               StandardForm]], DynamicUpdating -> True, StripOnInput -> 
             False]],
           Annotation[#, 
            Style[
             Dynamic[
              FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"]], 
             DynamicUpdating -> True], "Tooltip"]& ], 
          ButtonBox[
           PaneSelectorBox[{False->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
                StandardForm],
               ImageSizeCache->{50., {0., 8.}}],
              StripOnInput->False,
              DynamicUpdating->True], "OSLControl",
             StripOnInput->False], True->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
                StandardForm]],
              StripOnInput->False,
              DynamicUpdating->True], "OSLControlActive",
             StripOnInput->False]}, Dynamic[
             CurrentValue["MouseOver"]],
            Alignment->Center,
            FrameMargins->0,
            ImageSize->{Automatic, 25}],
           Appearance->None,
           BaselinePosition->Baseline,
           ButtonFunction:>OutputSizeLimit`ButtonFunction[
             Composition[OutputSizeLimit`Defer, 
              Function[{OutputSizeLimit`Dump`x$}, 
               TableForm[OutputSizeLimit`Dump`x$, TableDepth -> 2]]], 202, 
             28836946431688567634, 5/2],
           Enabled->True,
           Evaluator->Automatic,
           Method->"Queued"], 
          ButtonBox[
           PaneSelectorBox[{False->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
                StandardForm],
               ImageSizeCache->{56., {0., 8.}}],
              StripOnInput->False,
              DynamicUpdating->True], "OSLControl",
             StripOnInput->False], True->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
                StandardForm],
               ImageSizeCache->{56., {0., 8.}}],
              StripOnInput->False,
              DynamicUpdating->True], "OSLControlActive",
             StripOnInput->False]}, Dynamic[
             CurrentValue["MouseOver"]],
            Alignment->Center,
            FrameMargins->0,
            ImageSize->{Automatic, 25}],
           Appearance->None,
           BaselinePosition->Baseline,
           ButtonFunction:>OutputSizeLimit`ButtonFunction[
             Composition[OutputSizeLimit`Defer, 
              Function[{OutputSizeLimit`Dump`x$}, 
               TableForm[OutputSizeLimit`Dump`x$, TableDepth -> 2]]], 202, 
             28836946431688567634, 5 2],
           Enabled->True,
           Evaluator->Automatic,
           Method->"Queued"], 
          ButtonBox[
           PaneSelectorBox[{False->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
                StandardForm],
               ImageSizeCache->{42., {0., 8.}}],
              StripOnInput->False,
              DynamicUpdating->True], "OSLControl",
             StripOnInput->False], True->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
                StandardForm]],
              StripOnInput->False,
              DynamicUpdating->True], "OSLControlActive",
             StripOnInput->False]}, Dynamic[
             CurrentValue["MouseOver"]],
            Alignment->Center,
            FrameMargins->0,
            ImageSize->{Automatic, 25}],
           Appearance->None,
           BaselinePosition->Baseline,
           ButtonFunction:>OutputSizeLimit`ButtonFunction[
             Composition[OutputSizeLimit`Defer, 
              Function[{OutputSizeLimit`Dump`x$}, 
               TableForm[OutputSizeLimit`Dump`x$, TableDepth -> 2]]], 202, 
             28836946431688567634, Infinity],
           Enabled->True,
           Evaluator->Automatic,
           Method->"Queued"], 
          ButtonBox[
           PaneSelectorBox[{False->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
                StandardForm],
               ImageSizeCache->{74., {0., 8.}}],
              StripOnInput->False,
              DynamicUpdating->True], "OSLControl",
             StripOnInput->False], True->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
                StandardForm]],
              StripOnInput->False,
              DynamicUpdating->True], "OSLControlActive",
             StripOnInput->False]}, Dynamic[
             CurrentValue["MouseOver"]],
            Alignment->Center,
            FrameMargins->0,
            ImageSize->{Automatic, 25}],
           Appearance->None,
           BaselinePosition->Baseline,
           ButtonFunction:>FrontEndExecute[{
              FrontEnd`SetOptions[
              FrontEnd`$FrontEnd, 
               FrontEnd`PreferencesSettings -> {"Page" -> "Advanced"}], 
              FrontEnd`FrontEndToken["PreferencesDialog"]}],
           Evaluator->None,
           Method->"Preemptive"]}
        },
        AutoDelete->False,
        FrameStyle->GrayLevel[0.85],
        GridBoxDividers->{"Columns" -> {False, {True}}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{"Columns" -> {{2}}}]}
     },
     DefaultBaseStyle->"Column",
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
       "RowsIndexed" -> {}},
     GridBoxItemSize->{
      "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], 
         Offset[1.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    BaseStyle->"OutputSizeLimit",
    FrameMargins->{{12, 12}, {0, 15}},
    FrameStyle->GrayLevel[0.85],
    RoundingRadius->5,
    StripOnInput->False],
   Deploy,
   DefaultBaseStyle->"Deploy"],
  If[28836946431688567634 === $SessionID, 
   Out[202], Message[
     MessageName[Syntax, "noinfoker"]]; Missing["NotAvailable"]; 
   Null]]], "Output",
 CellChangeTimes->{{3.781249047787065*^9, 3.7812490930628977`*^9}, 
   3.781249666971981*^9, 3.781249740023595*^9, 3.781251033173594*^9, 
   3.782308631048085*^9},
 CellLabel->
  "Out[202]//TableForm=",ExpressionUUID->"461c8940-8c2f-4119-82ad-\
45d2f9e4b5ad"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"#", "[", 
     RowBox[{"[", "2", "]"}], "]"}], "&"}], "/@", 
   RowBox[{"SubwordFrequencies", "[", 
    RowBox[{"AustenExtendedHuffmanEncoded", ",", "6"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.781249271362336*^9, 3.781249291443509*^9}, {
  3.781249759082094*^9, 3.781249771000868*^9}},
 CellLabel->
  "In[203]:=",ExpressionUUID->"3272823c-67c6-4013-a34b-64181c531c1a"],

Cell[BoxData[
 TemplateBox[{
  "Part","partd",
   "\"Part specification \\!\\(\\*RowBox[{\\\"6\\\", \\\"\[LeftDoubleBracket]\
\\\", \\\"2\\\", \\\"\[RightDoubleBracket]\\\"}]\\) is longer than depth of \
object.\"",2,203,6,28836946431688567634,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.782308631119355*^9},
 CellLabel->
  "During evaluation of \
In[203]:=",ExpressionUUID->"477ae27f-1bca-4455-b0e0-e6307725646f"],

Cell[BoxData[
 TemplateBox[{
  "Part","partd",
   "\"Part specification \\!\\(\\*RowBox[{\\\"6.`16.\\\", \\\"\
\[LeftDoubleBracket]\\\", \\\"2\\\", \\\"\[RightDoubleBracket]\\\"}]\\) is \
longer than depth of object.\"",2,203,7,28836946431688567634,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.782308631210581*^9},
 CellLabel->
  "During evaluation of \
In[203]:=",ExpressionUUID->"62142a22-f1a5-468e-9dd4-897f4692e58e"],

Cell[BoxData[
 TemplateBox[{
  "Part","partd",
   "\"Part specification \\!\\(\\*RowBox[{\\\"6.`\\\", \\\"\
\[LeftDoubleBracket]\\\", \\\"2\\\", \\\"\[RightDoubleBracket]\\\"}]\\) is \
longer than depth of object.\"",2,203,8,28836946431688567634,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.782308631230727*^9},
 CellLabel->
  "During evaluation of \
In[203]:=",ExpressionUUID->"98737f95-ad3d-45ec-b566-45097d8bdfdf"],

Cell[BoxData[
 TemplateBox[{
  "General","stop",
   "\"Further output of \\!\\(\\*StyleBox[RowBox[{\\\"Part\\\", \\\"::\\\", \
\\\"partd\\\"}], \\\"MessageName\\\"]\\) will be suppressed during this \
calculation.\"",2,203,9,28836946431688567634,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.782308631250786*^9},
 CellLabel->
  "During evaluation of \
In[203]:=",ExpressionUUID->"22865c3c-e68c-402f-b3ce-f4f590c90f53"],

Cell[BoxData[
 TemplateBox[{
  "ListPlot","lpn",
   "\"\\!\\(\\*RowBox[{\\\"SubwordFrequencies\\\", \\\"[\\\", \
RowBox[{\\\"\\\\\\\"i\\\\\\\"\\\", \\\",\\\", RowBox[{\\\"6.`\\\", \\\"\
\[LeftDoubleBracket]\\\", \\\"2\\\", \\\"\[RightDoubleBracket]\\\"}]}], \\\"]\
\\\"}]\\) is not a list of numbers or pairs of numbers.\"",2,203,10,
   28836946431688567634,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.782308631321619*^9},
 CellLabel->
  "During evaluation of \
In[203]:=",ExpressionUUID->"1c1a6546-bba9-471e-8e66-8408043df072"],

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{"SubwordFrequencies", "[", 
   RowBox[{"\<\"i\"\>", ",", 
    RowBox[{"6", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
   "]"}], "]"}]], "Output",
 CellChangeTimes->{{3.781249273620173*^9, 3.781249292703442*^9}, {
   3.7812497637070427`*^9, 3.781249778362417*^9}, 3.782308631343396*^9},
 CellLabel->
  "Out[203]=",ExpressionUUID->"6ed4285c-23de-4684-8e08-d73f813c89d4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"m", ",", 
      RowBox[{"SubwordFrequencies", "[", 
       RowBox[{"AustenExtendedASCIIEncoded", ",", "m"}], "]"}]}], "}"}], ",", 
    
    RowBox[{"{", 
     RowBox[{"m", ",", "1", ",", "6"}], "}"}]}], "]"}], "//", "TF"}]], "Input",\

 CellChangeTimes->{{3.781249985048633*^9, 3.781249986629923*^9}, {
  3.781250958153606*^9, 3.781250959149199*^9}},
 CellLabel->
  "In[204]:=",ExpressionUUID->"58dc16c1-81c2-4484-9369-87ca92bb7e6e"],

Cell[BoxData[
 InterpretationBox[
  TagBox[
   FrameBox[GridBox[{
      {
       ItemBox[
        TagBox[
         TagBox[
          TemplateBox[{"1"},
           "OutputSizeLimit`Skeleton"],
          Function[BoxForm`e$, 
           TableForm[BoxForm`e$, TableDepth -> 2]]],
         Short[#, 5]& ],
        BaseStyle->{Deployed -> False},
        StripOnInput->False]},
      {GridBox[{
         {
          TagBox[
           TooltipBox[
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource[
                "FEStrings", "sizeBriefExplanation"], StandardForm],
               ImageSizeCache->{58., {2., 8.}}],
              StripOnInput->False,
              DynamicUpdating->True], "OSLText",
             StripOnInput->False],
            StyleBox[
             DynamicBox[
              ToBoxes[
               FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
               StandardForm]], DynamicUpdating -> True, StripOnInput -> 
             False]],
           Annotation[#, 
            Style[
             Dynamic[
              FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"]], 
             DynamicUpdating -> True], "Tooltip"]& ], 
          ButtonBox[
           PaneSelectorBox[{False->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
                StandardForm],
               ImageSizeCache->{50., {0., 8.}}],
              StripOnInput->False,
              DynamicUpdating->True], "OSLControl",
             StripOnInput->False], True->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
                StandardForm]],
              StripOnInput->False,
              DynamicUpdating->True], "OSLControlActive",
             StripOnInput->False]}, Dynamic[
             CurrentValue["MouseOver"]],
            Alignment->Center,
            FrameMargins->0,
            ImageSize->{Automatic, 25}],
           Appearance->None,
           BaselinePosition->Baseline,
           ButtonFunction:>OutputSizeLimit`ButtonFunction[
             Composition[OutputSizeLimit`Defer, 
              Function[{OutputSizeLimit`Dump`x$}, 
               TableForm[OutputSizeLimit`Dump`x$, TableDepth -> 2]]], 204, 
             28836946431688567634, 5/2],
           Enabled->True,
           Evaluator->Automatic,
           Method->"Queued"], 
          ButtonBox[
           PaneSelectorBox[{False->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
                StandardForm],
               ImageSizeCache->{56., {0., 8.}}],
              StripOnInput->False,
              DynamicUpdating->True], "OSLControl",
             StripOnInput->False], True->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
                StandardForm]],
              StripOnInput->False,
              DynamicUpdating->True], "OSLControlActive",
             StripOnInput->False]}, Dynamic[
             CurrentValue["MouseOver"]],
            Alignment->Center,
            FrameMargins->0,
            ImageSize->{Automatic, 25}],
           Appearance->None,
           BaselinePosition->Baseline,
           ButtonFunction:>OutputSizeLimit`ButtonFunction[
             Composition[OutputSizeLimit`Defer, 
              Function[{OutputSizeLimit`Dump`x$}, 
               TableForm[OutputSizeLimit`Dump`x$, TableDepth -> 2]]], 204, 
             28836946431688567634, 5 2],
           Enabled->True,
           Evaluator->Automatic,
           Method->"Queued"], 
          ButtonBox[
           PaneSelectorBox[{False->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
                StandardForm],
               ImageSizeCache->{42., {0., 8.}}],
              StripOnInput->False,
              DynamicUpdating->True], "OSLControl",
             StripOnInput->False], True->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
                StandardForm]],
              StripOnInput->False,
              DynamicUpdating->True], "OSLControlActive",
             StripOnInput->False]}, Dynamic[
             CurrentValue["MouseOver"]],
            Alignment->Center,
            FrameMargins->0,
            ImageSize->{Automatic, 25}],
           Appearance->None,
           BaselinePosition->Baseline,
           ButtonFunction:>OutputSizeLimit`ButtonFunction[
             Composition[OutputSizeLimit`Defer, 
              Function[{OutputSizeLimit`Dump`x$}, 
               TableForm[OutputSizeLimit`Dump`x$, TableDepth -> 2]]], 204, 
             28836946431688567634, Infinity],
           Enabled->True,
           Evaluator->Automatic,
           Method->"Queued"], 
          ButtonBox[
           PaneSelectorBox[{False->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
                StandardForm],
               ImageSizeCache->{74., {0., 8.}}],
              StripOnInput->False,
              DynamicUpdating->True], "OSLControl",
             StripOnInput->False], True->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
                StandardForm]],
              StripOnInput->False,
              DynamicUpdating->True], "OSLControlActive",
             StripOnInput->False]}, Dynamic[
             CurrentValue["MouseOver"]],
            Alignment->Center,
            FrameMargins->0,
            ImageSize->{Automatic, 25}],
           Appearance->None,
           BaselinePosition->Baseline,
           ButtonFunction:>FrontEndExecute[{
              FrontEnd`SetOptions[
              FrontEnd`$FrontEnd, 
               FrontEnd`PreferencesSettings -> {"Page" -> "Advanced"}], 
              FrontEnd`FrontEndToken["PreferencesDialog"]}],
           Evaluator->None,
           Method->"Preemptive"]}
        },
        AutoDelete->False,
        FrameStyle->GrayLevel[0.85],
        GridBoxDividers->{"Columns" -> {False, {True}}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{"Columns" -> {{2}}}]}
     },
     DefaultBaseStyle->"Column",
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
       "RowsIndexed" -> {}},
     GridBoxItemSize->{
      "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], 
         Offset[1.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    BaseStyle->"OutputSizeLimit",
    FrameMargins->{{12, 12}, {0, 15}},
    FrameStyle->GrayLevel[0.85],
    RoundingRadius->5,
    StripOnInput->False],
   Deploy,
   DefaultBaseStyle->"Deploy"],
  If[28836946431688567634 === $SessionID, 
   Out[204], Message[
     MessageName[Syntax, "noinfoker"]]; Missing["NotAvailable"]; 
   Null]]], "Output",
 CellChangeTimes->{3.7812499938804626`*^9, 3.781250986251402*^9, 
  3.7823086315212097`*^9},
 CellLabel->
  "Out[204]//TableForm=",ExpressionUUID->"0ffa69f7-1da6-410c-8dca-\
f1e828768c76"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"#", "[", 
       RowBox[{"[", "2", "]"}], "]"}], "&"}], "/@", 
     RowBox[{"SubwordFrequencies", "[", 
      RowBox[{"AustenHuffmanEncoded", ",", "5"}], "]"}]}], "]"}], ",", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"#", "[", 
       RowBox[{"[", "2", "]"}], "]"}], "&"}], "/@", 
     RowBox[{"SubwordFrequencies", "[", 
      RowBox[{"AustenExtendedHuffmanEncoded", ",", "5"}], "]"}]}], "]"}], ",", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"#", "[", 
       RowBox[{"[", "2", "]"}], "]"}], "&"}], "/@", 
     RowBox[{"SubwordFrequencies", "[", 
      RowBox[{"AustenExtendedASCIIEncoded", ",", "5"}], "]"}]}], "]"}]}], 
  "}"}]], "Input",
 CellChangeTimes->{{3.781249271362336*^9, 3.781249291443509*^9}, {
  3.781249999933469*^9, 3.781250008440029*^9}, {3.781250944607182*^9, 
  3.781250979491235*^9}},
 CellLabel->
  "In[205]:=",ExpressionUUID->"5e336d92-9841-4235-8ee9-a0cad0baa95f"],

Cell[BoxData[
 TemplateBox[{
  "Part","partd",
   "\"Part specification \\!\\(\\*RowBox[{\\\"AustenHuffmanEncoded\\\", \\\"\
\[LeftDoubleBracket]\\\", \\\"2\\\", \\\"\[RightDoubleBracket]\\\"}]\\) is \
longer than depth of object.\"",2,205,11,28836946431688567634,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.7823086315845346`*^9},
 CellLabel->
  "During evaluation of \
In[205]:=",ExpressionUUID->"2d4b2586-e521-4a47-8030-f50477860d05"],

Cell[BoxData[
 TemplateBox[{
  "Part","partd",
   "\"Part specification \\!\\(\\*RowBox[{\\\"5\\\", \\\"\[LeftDoubleBracket]\
\\\", \\\"2\\\", \\\"\[RightDoubleBracket]\\\"}]\\) is longer than depth of \
object.\"",2,205,12,28836946431688567634,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.782308631660684*^9},
 CellLabel->
  "During evaluation of \
In[205]:=",ExpressionUUID->"11c6529a-ac49-4b67-9429-f3fe58608f45"],

Cell[BoxData[
 TemplateBox[{
  "Part","partd",
   "\"Part specification \\!\\(\\*RowBox[{\\\"5.`16.\\\", \\\"\
\[LeftDoubleBracket]\\\", \\\"2\\\", \\\"\[RightDoubleBracket]\\\"}]\\) is \
longer than depth of object.\"",2,205,13,28836946431688567634,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.782308631741724*^9},
 CellLabel->
  "During evaluation of \
In[205]:=",ExpressionUUID->"fe749c9b-5f4d-46d3-af30-5b5ba7320368"],

Cell[BoxData[
 TemplateBox[{
  "General","stop",
   "\"Further output of \\!\\(\\*StyleBox[RowBox[{\\\"Part\\\", \\\"::\\\", \
\\\"partd\\\"}], \\\"MessageName\\\"]\\) will be suppressed during this \
calculation.\"",2,205,14,28836946431688567634,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.782308631761547*^9},
 CellLabel->
  "During evaluation of \
In[205]:=",ExpressionUUID->"d9ca3ac6-b550-444c-ab3d-a196aadedca8"],

Cell[BoxData[
 TemplateBox[{
  "ListPlot","lpn",
   "\"\\!\\(\\*RowBox[{\\\"SubwordFrequencies\\\", \\\"[\\\", \
RowBox[{RowBox[{\\\"AustenHuffmanEncoded\\\", \\\"\[LeftDoubleBracket]\\\", \
\\\"2\\\", \\\"\[RightDoubleBracket]\\\"}], \\\",\\\", RowBox[{\\\"5.`\\\", \
\\\"\[LeftDoubleBracket]\\\", \\\"2\\\", \\\"\[RightDoubleBracket]\\\"}]}], \
\\\"]\\\"}]\\) is not a list of numbers or pairs of numbers.\"",2,205,15,
   28836946431688567634,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.782308631832369*^9},
 CellLabel->
  "During evaluation of \
In[205]:=",ExpressionUUID->"5b63c080-4cf0-4de3-abb1-a1fa0b8d140b"],

Cell[BoxData[
 TemplateBox[{
  "ListPlot","lpn",
   "\"\\!\\(\\*RowBox[{\\\"SubwordFrequencies\\\", \\\"[\\\", \
RowBox[{\\\"\\\\\\\"i\\\\\\\"\\\", \\\",\\\", RowBox[{\\\"5.`\\\", \\\"\
\[LeftDoubleBracket]\\\", \\\"2\\\", \\\"\[RightDoubleBracket]\\\"}]}], \\\"]\
\\\"}]\\) is not a list of numbers or pairs of numbers.\"",2,205,16,
   28836946431688567634,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.782308631918762*^9},
 CellLabel->
  "During evaluation of \
In[205]:=",ExpressionUUID->"6fadab83-664a-4728-a1dc-45ed6bd6f40a"],

Cell[BoxData[
 TemplateBox[{
  "ListPlot","lpn",
   "\"\\!\\(\\*RowBox[{\\\"SubwordFrequencies\\\", \\\"[\\\", RowBox[{\\\"8.`\
\\\", \\\",\\\", RowBox[{\\\"5.`\\\", \\\"\[LeftDoubleBracket]\\\", \
\\\"2\\\", \\\"\[RightDoubleBracket]\\\"}]}], \\\"]\\\"}]\\) is not a list of \
numbers or pairs of numbers.\"",2,205,17,28836946431688567634,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.782308632011292*^9},
 CellLabel->
  "During evaluation of \
In[205]:=",ExpressionUUID->"b4d4f3d4-e611-47a8-b4e3-0c8ecfed448c"],

Cell[BoxData[
 TemplateBox[{
  "General","stop",
   "\"Further output of \\!\\(\\*StyleBox[RowBox[{\\\"ListPlot\\\", \
\\\"::\\\", \\\"lpn\\\"}], \\\"MessageName\\\"]\\) will be suppressed during \
this calculation.\"",2,205,18,28836946431688567634,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.782308632031704*^9},
 CellLabel->
  "During evaluation of \
In[205]:=",ExpressionUUID->"24162467-f1a7-4e69-a0c7-a78f1c0e14a8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"ListPlot", "[", 
    RowBox[{"SubwordFrequencies", "[", 
     RowBox[{
      RowBox[{
      "AustenHuffmanEncoded", "\[LeftDoubleBracket]", "2", 
       "\[RightDoubleBracket]"}], ",", 
      RowBox[{"5", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
     "]"}], "]"}], ",", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"SubwordFrequencies", "[", 
     RowBox[{"\<\"i\"\>", ",", 
      RowBox[{"5", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
     "]"}], "]"}], ",", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"SubwordFrequencies", "[", 
     RowBox[{"8", ",", 
      RowBox[{"5", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
     "]"}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.781249273620173*^9, 3.781249292703442*^9}, 
   3.7812500122108*^9, 3.781250958026967*^9, 3.781250998071361*^9, 
   3.7823086320519133`*^9},
 CellLabel->
  "Out[205]=",ExpressionUUID->"883c10e5-ccf1-406f-aa47-5f12a6c70751"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"#", "[", 
       RowBox[{"[", "2", "]"}], "]"}], "&"}], "/@", 
     RowBox[{"SubwordFrequencies", "[", 
      RowBox[{"AustenHuffmanEncoded", ",", "6"}], "]"}]}], "]"}], ",", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"#", "[", 
       RowBox[{"[", "2", "]"}], "]"}], "&"}], "/@", 
     RowBox[{"SubwordFrequencies", "[", 
      RowBox[{"AustenExtendedHuffmanEncoded", ",", "6"}], "]"}]}], "]"}], ",", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"#", "[", 
       RowBox[{"[", "2", "]"}], "]"}], "&"}], "/@", 
     RowBox[{"SubwordFrequencies", "[", 
      RowBox[{"AustenExtendedASCIIEncoded", ",", "6"}], "]"}]}], "]"}]}], 
  "}"}]], "Input",
 CellChangeTimes->{{3.781249271362336*^9, 3.781249291443509*^9}, {
  3.781249999933469*^9, 3.781250008440029*^9}, {3.781250944607182*^9, 
  3.781250979491235*^9}, {3.7812510414579573`*^9, 3.781251044332415*^9}},
 CellLabel->
  "In[206]:=",ExpressionUUID->"c2777b66-eb2e-4fba-ada4-04d24fa6fbde"],

Cell[BoxData[
 TemplateBox[{
  "Part","partd",
   "\"Part specification \\!\\(\\*RowBox[{\\\"AustenHuffmanEncoded\\\", \\\"\
\[LeftDoubleBracket]\\\", \\\"2\\\", \\\"\[RightDoubleBracket]\\\"}]\\) is \
longer than depth of object.\"",2,206,19,28836946431688567634,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.782308632105771*^9},
 CellLabel->
  "During evaluation of \
In[206]:=",ExpressionUUID->"c02dedb7-3883-4efc-adb9-0478970fe512"],

Cell[BoxData[
 TemplateBox[{
  "Part","partd",
   "\"Part specification \\!\\(\\*RowBox[{\\\"6\\\", \\\"\[LeftDoubleBracket]\
\\\", \\\"2\\\", \\\"\[RightDoubleBracket]\\\"}]\\) is longer than depth of \
object.\"",2,206,20,28836946431688567634,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.782308632130507*^9},
 CellLabel->
  "During evaluation of \
In[206]:=",ExpressionUUID->"48228b20-39ab-45d7-9ad7-5bc40adfda3b"],

Cell[BoxData[
 TemplateBox[{
  "Part","partd",
   "\"Part specification \\!\\(\\*RowBox[{\\\"6.`\\\", \\\"\
\[LeftDoubleBracket]\\\", \\\"2\\\", \\\"\[RightDoubleBracket]\\\"}]\\) is \
longer than depth of object.\"",2,206,21,28836946431688567634,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.782308632210289*^9},
 CellLabel->
  "During evaluation of \
In[206]:=",ExpressionUUID->"3bbbc06f-02be-4c00-94bd-10c9bdbc156b"],

Cell[BoxData[
 TemplateBox[{
  "General","stop",
   "\"Further output of \\!\\(\\*StyleBox[RowBox[{\\\"Part\\\", \\\"::\\\", \
\\\"partd\\\"}], \\\"MessageName\\\"]\\) will be suppressed during this \
calculation.\"",2,206,22,28836946431688567634,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.7823086322349663`*^9},
 CellLabel->
  "During evaluation of \
In[206]:=",ExpressionUUID->"e783e4a5-fdd1-41f3-ac29-a33291bc11fd"],

Cell[BoxData[
 TemplateBox[{
  "ListPlot","lpn",
   "\"\\!\\(\\*RowBox[{\\\"SubwordFrequencies\\\", \\\"[\\\", \
RowBox[{RowBox[{\\\"AustenHuffmanEncoded\\\", \\\"\[LeftDoubleBracket]\\\", \
\\\"2\\\", \\\"\[RightDoubleBracket]\\\"}], \\\",\\\", RowBox[{\\\"6.`\\\", \
\\\"\[LeftDoubleBracket]\\\", \\\"2\\\", \\\"\[RightDoubleBracket]\\\"}]}], \
\\\"]\\\"}]\\) is not a list of numbers or pairs of numbers.\"",2,206,23,
   28836946431688567634,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.782308632262473*^9},
 CellLabel->
  "During evaluation of \
In[206]:=",ExpressionUUID->"42fb5bc7-d4e4-4ccb-947e-36068ed2c149"],

Cell[BoxData[
 TemplateBox[{
  "ListPlot","lpn",
   "\"\\!\\(\\*RowBox[{\\\"SubwordFrequencies\\\", \\\"[\\\", \
RowBox[{\\\"\\\\\\\"i\\\\\\\"\\\", \\\",\\\", RowBox[{\\\"6.`\\\", \\\"\
\[LeftDoubleBracket]\\\", \\\"2\\\", \\\"\[RightDoubleBracket]\\\"}]}], \\\"]\
\\\"}]\\) is not a list of numbers or pairs of numbers.\"",2,206,24,
   28836946431688567634,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.7823086323165293`*^9},
 CellLabel->
  "During evaluation of \
In[206]:=",ExpressionUUID->"dfa12583-f4e9-4a2b-b891-7707fa84dcea"],

Cell[BoxData[
 TemplateBox[{
  "ListPlot","lpn",
   "\"\\!\\(\\*RowBox[{\\\"SubwordFrequencies\\\", \\\"[\\\", RowBox[{\\\"8.`\
\\\", \\\",\\\", RowBox[{\\\"6.`\\\", \\\"\[LeftDoubleBracket]\\\", \
\\\"2\\\", \\\"\[RightDoubleBracket]\\\"}]}], \\\"]\\\"}]\\) is not a list of \
numbers or pairs of numbers.\"",2,206,25,28836946431688567634,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.782308632369054*^9},
 CellLabel->
  "During evaluation of \
In[206]:=",ExpressionUUID->"c2d03b81-bb5a-4761-b7e5-a383b04cb36e"],

Cell[BoxData[
 TemplateBox[{
  "General","stop",
   "\"Further output of \\!\\(\\*StyleBox[RowBox[{\\\"ListPlot\\\", \
\\\"::\\\", \\\"lpn\\\"}], \\\"MessageName\\\"]\\) will be suppressed during \
this calculation.\"",2,206,26,28836946431688567634,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.782308632393853*^9},
 CellLabel->
  "During evaluation of \
In[206]:=",ExpressionUUID->"9be160ea-82e7-46e4-8b88-c154127b0d52"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"ListPlot", "[", 
    RowBox[{"SubwordFrequencies", "[", 
     RowBox[{
      RowBox[{
      "AustenHuffmanEncoded", "\[LeftDoubleBracket]", "2", 
       "\[RightDoubleBracket]"}], ",", 
      RowBox[{"6", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
     "]"}], "]"}], ",", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"SubwordFrequencies", "[", 
     RowBox[{"\<\"i\"\>", ",", 
      RowBox[{"6", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
     "]"}], "]"}], ",", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"SubwordFrequencies", "[", 
     RowBox[{"8", ",", 
      RowBox[{"6", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
     "]"}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.781249273620173*^9, 3.781249292703442*^9}, 
   3.7812500122108*^9, 3.781250958026967*^9, 3.781250998071361*^9, 
   3.781251066513084*^9, 3.782308632415992*^9},
 CellLabel->
  "Out[206]=",ExpressionUUID->"b7f6c846-a553-43b3-ac11-d64968834a69"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{808, 755},
WindowMargins->{{Automatic, 101}, {Automatic, 0}},
FrontEndVersion->"11.3 for Mac OS X x86 (32-bit, 64-bit Kernel) (March 5, \
2018)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 12520, 164, 3517, "Input",ExpressionUUID->"ca43ca79-3cbf-492d-a91a-2d6676f17e21"],
Cell[CellGroupData[{
Cell[13103, 188, 680, 16, 30, "Input",ExpressionUUID->"055b2af6-c91e-4396-bcc4-2606540ba4bf"],
Cell[13786, 206, 5251, 148, 161, "Output",ExpressionUUID->"d61eda2e-afe9-44b8-a639-31b931ddb359"]
}, Open  ]],
Cell[CellGroupData[{
Cell[19074, 359, 969, 25, 52, "Input",ExpressionUUID->"8e8a74dc-09f6-4a3b-8b54-0faed7229f8b"],
Cell[20046, 386, 6584, 150, 329, "Output",ExpressionUUID->"5bfc31ed-e6d4-48d1-9e98-24adb395135c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[26667, 541, 774, 20, 52, "Input",ExpressionUUID->"cd7bfc99-319a-4f76-8c86-f656467f0087"],
Cell[27444, 563, 4610, 72, 308, "Output",ExpressionUUID->"8c4d314e-e590-450c-9775-2bdaa431c900"]
}, Open  ]],
Cell[CellGroupData[{
Cell[32091, 640, 495, 9, 30, "Input",ExpressionUUID->"e810dc29-2d40-4d10-9301-f88c5a06e3fa"],
Cell[32589, 651, 229986, 3037, 9359, "Output",ExpressionUUID->"f6c48cf3-7839-487f-bf4b-34fbdda35ea4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[262612, 3693, 185, 3, 54, "Subsection",ExpressionUUID->"f7f255d1-6fe3-40c6-a3d0-2df12765de91"],
Cell[CellGroupData[{
Cell[262822, 3700, 507, 13, 30, "Input",ExpressionUUID->"b01f43d8-0263-4457-93ca-08bf970421e4"],
Cell[263332, 3715, 797, 14, 34, "Output",ExpressionUUID->"813c28b8-78e4-4e84-9e53-62136278a2c1"]
}, Open  ]],
Cell[264144, 3732, 501, 12, 30, "Input",ExpressionUUID->"b89248d6-ad4b-4475-b3e4-3cd96d1cce43"],
Cell[CellGroupData[{
Cell[264670, 3748, 1346, 31, 73, "Input",ExpressionUUID->"6dc2969e-b417-4f1e-98e0-3446ad410521"],
Cell[266019, 3781, 3411, 81, 296, "Output",ExpressionUUID->"3cad125e-d599-4c4c-9ba7-7651e7991502"]
}, Open  ]],
Cell[269445, 3865, 727, 18, 52, "Input",ExpressionUUID->"a6ec28a8-660c-4dc0-b6f8-077b9d2d3e38"],
Cell[270175, 3885, 372, 8, 30, "Input",ExpressionUUID->"d49c62ea-2791-43a1-b058-5363acb3a0ea"],
Cell[CellGroupData[{
Cell[270572, 3897, 331, 6, 30, "Input",ExpressionUUID->"e8dca939-1b29-4991-97ca-c3fffd9ee4ed"],
Cell[270906, 3905, 9030, 222, 182, "Output",ExpressionUUID->"fe857b48-7d37-48d7-bea4-8c516671d661"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[279985, 4133, 157, 3, 54, "Subsection",ExpressionUUID->"c934d26f-0419-48a1-85c1-09a3d85dff64"],
Cell[CellGroupData[{
Cell[280167, 4140, 532, 15, 52, "Input",ExpressionUUID->"0bd93a3e-956f-4291-ac3a-60e21e0adea2"],
Cell[280702, 4157, 8130, 212, 104, "Output",ExpressionUUID->"461c8940-8c2f-4119-82ad-45d2f9e4b5ad"]
}, Open  ]],
Cell[CellGroupData[{
Cell[288869, 4374, 459, 12, 30, "Input",ExpressionUUID->"3272823c-67c6-4013-a34b-64181c531c1a"],
Cell[289331, 4388, 442, 10, 24, "Message",ExpressionUUID->"477ae27f-1bca-4455-b0e0-e6307725646f"],
Cell[289776, 4400, 447, 10, 24, "Message",ExpressionUUID->"62142a22-f1a5-468e-9dd4-897f4692e58e"],
Cell[290226, 4412, 444, 10, 24, "Message",ExpressionUUID->"98737f95-ad3d-45ec-b566-45097d8bdfdf"],
Cell[290673, 4424, 444, 10, 24, "Message",ExpressionUUID->"22865c3c-e68c-402f-b3ce-f4f590c90f53"],
Cell[291120, 4436, 556, 12, 24, "Message",ExpressionUUID->"1c1a6546-bba9-471e-8e66-8408043df072"],
Cell[291679, 4450, 435, 9, 34, "Output",ExpressionUUID->"6ed4285c-23de-4684-8e08-d73f813c89d4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[292151, 4464, 526, 15, 30, "Input",ExpressionUUID->"58dc16c1-81c2-4484-9369-87ca92bb7e6e"],
Cell[292680, 4481, 8011, 210, 104, "Output",ExpressionUUID->"0ffa69f7-1da6-410c-8dca-f1e828768c76"]
}, Open  ]],
Cell[CellGroupData[{
Cell[300728, 4696, 1057, 29, 73, "Input",ExpressionUUID->"5e336d92-9841-4235-8ee9-a0cad0baa95f"],
Cell[301788, 4727, 464, 10, 24, "Message",ExpressionUUID->"2d4b2586-e521-4a47-8030-f50477860d05"],
Cell[302255, 4739, 443, 10, 24, "Message",ExpressionUUID->"11c6529a-ac49-4b67-9429-f3fe58608f45"],
Cell[302701, 4751, 448, 10, 24, "Message",ExpressionUUID->"fe749c9b-5f4d-46d3-af30-5b5ba7320368"],
Cell[303152, 4763, 445, 10, 24, "Message",ExpressionUUID->"d9ca3ac6-b550-444c-ab3d-a196aadedca8"],
Cell[303600, 4775, 643, 13, 24, "Message",ExpressionUUID->"5b63c080-4cf0-4de3-abb1-a1fa0b8d140b"],
Cell[304246, 4790, 556, 12, 24, "Message",ExpressionUUID->"6fadab83-664a-4728-a1dc-45ed6bd6f40a"],
Cell[304805, 4804, 538, 11, 24, "Message",ExpressionUUID->"b4d4f3d4-e611-47a8-b4e3-0c8ecfed448c"],
Cell[305346, 4817, 447, 10, 24, "Message",ExpressionUUID->"24162467-f1a7-4e69-a0c7-a78f1c0e14a8"],
Cell[305796, 4829, 999, 25, 56, "Output",ExpressionUUID->"883c10e5-ccf1-406f-aa47-5f12a6c70751"]
}, Open  ]],
Cell[CellGroupData[{
Cell[306832, 4859, 1105, 29, 73, "Input",ExpressionUUID->"c2777b66-eb2e-4fba-ada4-04d24fa6fbde"],
Cell[307940, 4890, 462, 10, 24, "Message",ExpressionUUID->"c02dedb7-3883-4efc-adb9-0478970fe512"],
Cell[308405, 4902, 443, 10, 24, "Message",ExpressionUUID->"48228b20-39ab-45d7-9ad7-5bc40adfda3b"],
Cell[308851, 4914, 445, 10, 24, "Message",ExpressionUUID->"3bbbc06f-02be-4c00-94bd-10c9bdbc156b"],
Cell[309299, 4926, 447, 10, 24, "Message",ExpressionUUID->"e783e4a5-fdd1-41f3-ac29-a33291bc11fd"],
Cell[309749, 4938, 643, 13, 24, "Message",ExpressionUUID->"42fb5bc7-d4e4-4ccb-947e-36068ed2c149"],
Cell[310395, 4953, 558, 12, 24, "Message",ExpressionUUID->"dfa12583-f4e9-4a2b-b891-7707fa84dcea"],
Cell[310956, 4967, 538, 11, 24, "Message",ExpressionUUID->"c2d03b81-bb5a-4761-b7e5-a383b04cb36e"],
Cell[311497, 4980, 447, 10, 24, "Message",ExpressionUUID->"9be160ea-82e7-46e4-8b88-c154127b0d52"],
Cell[311947, 4992, 1019, 25, 56, "Output",ExpressionUUID->"b7f6c846-a553-43b3-ac11-d64968834a69"]
}, Open  ]]
}, Open  ]]
}
]
*)

